Class AbstractPayloadSection<T>
java.lang.Object
org.refcodes.serial.AbstractPayloadSection<T>
- Type Parameters:
T- The type of the body's payload.
- All Implemented Interfaces:
Serializable, org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.LengthAccessor, org.refcodes.mixin.PayloadAccessor<T>, org.refcodes.mixin.PayloadAccessor.PayloadBuilder<T, PayloadTransmission<T>>, org.refcodes.mixin.PayloadAccessor.PayloadMutator<T>, org.refcodes.mixin.PayloadAccessor.PayloadProperty<T>, org.refcodes.mixin.Resetable, org.refcodes.schema.Schemable, PayloadSection<T>, PayloadTransmission<T>, Section, Section.SectionMixin, Transmission, Transmission.TransmissionMixin
- Direct Known Subclasses:
BooleanArraySection, ByteArraySection, CharArraySection, CharSection, DoubleArraySection, FileSection, FloatArraySection, IntArraySection, LongArraySection, PropertiesSection, ShortArraySection, StringSection
public abstract class AbstractPayloadSection<T>
extends Object
implements PayloadSection<T>, Section.SectionMixin
An abstract implementation of a
Section with payload.- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.LengthAccessor
org.refcodes.mixin.LengthAccessor.LengthBuilder<B>, org.refcodes.mixin.LengthAccessor.LengthMutator, org.refcodes.mixin.LengthAccessor.LengthPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.PayloadAccessor
org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P,B>, org.refcodes.mixin.PayloadAccessor.PayloadMutator<P>, org.refcodes.mixin.PayloadAccessor.PayloadProperty<P> Nested classes/interfaces inherited from interface Section
Section.SectionMixinNested classes/interfaces inherited from interface Transmission
Transmission.TransmissionMixin -
Field Summary
Fields -
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedEmpty constructor fur sub-classes.AbstractPayloadSection(String aAlias) Constructs an emptySectionto be initialized viaSection.fromTransmission(Sequence, int)orSection.fromTransmission(Sequence, int, int).AbstractPayloadSection(String aAlias, T aValue) Constructs aSectioninstance with the given value. -
Method Summary
Modifier and TypeMethodDescriptionbooleangetAlias()inthashCode()voidreset()Resets any dynamic data (e.g. values such as payloads or checksums) and must not(!)voidsetPayload(T aValue) org.refcodes.struct.SimpleTypeMapReturns theSimpleTypeMaprepresentation of thisTransmission.toString()Methods inherited from interface org.refcodes.mixin.PayloadAccessor
getPayloadOrMethods inherited from interface org.refcodes.mixin.PayloadAccessor.PayloadBuilder
withPayloadMethods inherited from interface org.refcodes.mixin.PayloadAccessor.PayloadProperty
letPayloadMethods inherited from interface Section
fromTransmission, fromTransmission, fromTransmission, fromTransmission, receiveFrom, receiveFromMethods inherited from interface Section.SectionMixin
receiveFromMethods inherited from interface Transmission
getLength, toSchema, toSequence, transmitTo, transmitToMethods inherited from interface Transmission.TransmissionMixin
transmitTo
-
Field Details
-
_payload
-
_alias
-
-
Constructor Details
-
AbstractPayloadSection
protected AbstractPayloadSection()Empty constructor fur sub-classes. -
AbstractPayloadSection
Constructs an emptySectionto be initialized viaSection.fromTransmission(Sequence, int)orSection.fromTransmission(Sequence, int, int).- Parameters:
aAlias- The alias which identifies the content of this segment.
-
AbstractPayloadSection
-
-
Method Details
-
setPayload
-
getPayload
-
getAlias
- Specified by:
getAliasin interfaceorg.refcodes.mixin.AliasAccessor
-
reset
public void reset()Resets any dynamic data (e.g. values such as payloads or checksums) and must not(!) reset any configurations or settings required to produce the dynamic data (e.g. theTransmissionMetrics).- Specified by:
resetin interfaceorg.refcodes.mixin.Resetable- Specified by:
resetin interfaceTransmission
-
toString
-
hashCode
-
equals
-
toSimpleTypeMap
public org.refcodes.struct.SimpleTypeMap toSimpleTypeMap()Returns theSimpleTypeMaprepresentation of thisTransmission. In case this Transmission hasTransmissionchildren, then the children are queried as well and contained in the resultingSimpleTypeMap. The aliases of the accordingTransmissioninstances represent the resulting path to aTransmission's final simple type.- Specified by:
toSimpleTypeMapin interfaceTransmission- Returns:
- The
SimpleTypeMaprepresenting thisTransmissionand (if any) its children, with the according aliases forming the paths to theTransmission's values.
-