Class AbstractReferenceeLengthSegment<REFERENCEE extends Transmission>

java.lang.Object
org.refcodes.serial.AbstractReferenceeLengthSegment<REFERENCEE>
Type Parameters:
REFERENCEE - the generic type
All Implemented Interfaces:
Serializable, LengthAccessor, Resetable, EndianessAccessor, Diagnosable, Schemable<DiagnosticOptions>, AllocLengthAccessor, LengthWidthAccessor, Segment, Transmission, Transmission.TransmissionMixin
Direct Known Subclasses:
AbstractLengthDecoratorSegment, AllocSegmentHead, LengthSegment

public abstract class AbstractReferenceeLengthSegment<REFERENCEE extends Transmission> extends Object implements Segment, Transmission.TransmissionMixin, LengthWidthAccessor, EndianessAccessor, AllocLengthAccessor
The AbstractReferenceeLengthSegment represents a allocated length value as of the referenced Transmission element's length.
See Also:
  • Field Details

    • _endianess

      protected Endianess _endianess
    • _lengthWidth

      protected int _lengthWidth
    • _allocLength

      protected int _allocLength
    • _referencee

      protected REFERENCEE extends Transmission _referencee
  • Constructor Details

    • AbstractReferenceeLengthSegment

      public AbstractReferenceeLengthSegment(TransmissionMetrics aTransmissionMetrics)
      Constructs an according instance. The configuration attributes are taken from the TransmissionMetrics configuration object, though only those attributes are supported which are also supported by the other constructors!
      Parameters:
      aTransmissionMetrics - The TransmissionMetrics to be used for configuring this instance.
    • AbstractReferenceeLengthSegment

      public AbstractReferenceeLengthSegment(REFERENCEE aReferencee, TransmissionMetrics aTransmissionMetrics)
      Constructs an according instance. The configuration attributes are taken from the TransmissionMetrics configuration object, though only those attributes are supported which are also supported by the other constructors!
      Parameters:
      aReferencee - The referenced Transmission which's length is to be used.
      aTransmissionMetrics - The TransmissionMetrics to be used for configuring this instance.
    • AbstractReferenceeLengthSegment

      public AbstractReferenceeLengthSegment()
      Constructs an empty allocation value with a width of TransmissionMetrics.DEFAULT_LENGTH_WIDTH bytes used to specify the decoratee's length and a TransmissionMetrics.DEFAULT_ENDIANESS endian representation of the decoratee's length.
    • AbstractReferenceeLengthSegment

      public AbstractReferenceeLengthSegment(Endianess aEndianess)
      Constructs an empty allocation value with a width of TransmissionMetrics.DEFAULT_LENGTH_WIDTH bytes used to specify the decoratee's length and the provided Endianess representation of the decoratee's length.
      Parameters:
      aEndianess - The Endianess to be used for length values.
    • AbstractReferenceeLengthSegment

      public AbstractReferenceeLengthSegment(int aLengthWidth)
      Constructs an empty allocation value with the given number of bytes used to specify the decoratee's length and a TransmissionMetrics.DEFAULT_ENDIANESS endian representation of the decoratee's length.
      Parameters:
      aLengthWidth - The width (in bytes) to be used for length values.
    • AbstractReferenceeLengthSegment

      public AbstractReferenceeLengthSegment(int aLengthWidth, Endianess aEndianess)
      Constructs an empty allocation value with the given number of bytes used to specify the decoratee's length and the provided Endianess representation of the decoratee's length.
      Parameters:
      aLengthWidth - The width (in bytes) to be used for length values.
      aEndianess - The Endianess to be used for length values.
    • AbstractReferenceeLengthSegment

      public AbstractReferenceeLengthSegment(REFERENCEE aReferencee)
      Constructs the allocation value with the given decoratee and a width of TransmissionMetrics.DEFAULT_LENGTH_WIDTH bytes used to specify the decoratee's length a TransmissionMetrics.DEFAULT_ENDIANESS endian representation of the decoratee's length.
      Parameters:
      aReferencee - The decoratee used for this allocation value.
    • AbstractReferenceeLengthSegment

      public AbstractReferenceeLengthSegment(REFERENCEE aReferencee, Endianess aEndianess)
      Constructs the allocation value with the given decoratee and a width of TransmissionMetrics.DEFAULT_LENGTH_WIDTH bytes used to specify the decoratee's length and the provided Endianess representation of the decoratee's length.
      Parameters:
      aReferencee - The decoratee used for this allocation value.
      aEndianess - The Endianess to be used for length values.
    • AbstractReferenceeLengthSegment

      public AbstractReferenceeLengthSegment(REFERENCEE aReferencee, int aLengthWidth)
      Constructs the allocation value with the given decoratee and with the given number of bytes used to specify the decoratee's length and a TransmissionMetrics.DEFAULT_ENDIANESS endian representation of the decoratee's length.
      Parameters:
      aReferencee - The decoratee used for this allocation value.
      aLengthWidth - The width (in bytes) to be used for length values.
    • AbstractReferenceeLengthSegment

      public AbstractReferenceeLengthSegment(REFERENCEE aReferencee, int aLengthWidth, Endianess aEndianess)
      Constructs the allocation value with the given decoratee and with the given number of bytes used to specify the decoratee's length and the provided Endianess representation of the decoratee's length.
      Parameters:
      aReferencee - The decoratee used for this allocation value.
      aLengthWidth - The width (in bytes) to be used for length values.
      aEndianess - The Endianess to be used for length values.
  • Method Details