Interface ArraySegment<SEGMENT extends Segment>

Type Parameters:
SEGMENT - The type of the array Segment elements.
All Superinterfaces:
org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.ArrayAccessor<SEGMENT[]>, org.refcodes.mixin.ArrayAccessor.ArrayBuilder<SEGMENT[], ArrayTransmission<SEGMENT>>, org.refcodes.mixin.ArrayAccessor.ArrayMutator<SEGMENT[]>, org.refcodes.mixin.ArrayAccessor.ArrayProperty<SEGMENT[]>, ArrayTransmission<SEGMENT>, org.refcodes.mixin.LengthAccessor, org.refcodes.mixin.Resetable, org.refcodes.schema.Schemable, Segment, Segment.SegmentMixin, Serializable, Transmission, Transmission.TransmissionMixin

public interface ArraySegment<SEGMENT extends Segment> extends Segment.SegmentMixin, Segment, ArrayTransmission<SEGMENT>
A ArraySegment is a Segment with array Segment elements as of ArrayTransmission.
  • Nested Class Summary

    Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor

    org.refcodes.mixin.AliasAccessor.AliasBuilder<B>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasProperty

    Nested classes/interfaces inherited from interface org.refcodes.mixin.ArrayAccessor

    org.refcodes.mixin.ArrayAccessor.ArrayBuilder<T,B>, org.refcodes.mixin.ArrayAccessor.ArrayMutator<T>, org.refcodes.mixin.ArrayAccessor.ArrayProperty<T>

    Nested classes/interfaces inherited from interface org.refcodes.mixin.LengthAccessor

    org.refcodes.mixin.LengthAccessor.LengthBuilder<B>, org.refcodes.mixin.LengthAccessor.LengthMutator, org.refcodes.mixin.LengthAccessor.LengthProperty

    Nested classes/interfaces inherited from interface Segment

    Segment.SegmentMixin

    Nested classes/interfaces inherited from interface Transmission

    Transmission.TransmissionMixin
  • Method Summary

    Modifier and Type
    Method
    Description
    default int
    fromTransmission(Sequence aSequence, int aOffset)
    (Re-)initializes this instance with the the given Sequence data.
    default void
    receiveFrom(InputStream aInputStream, OutputStream aReturnStream)
    Default implementation harnessing the Segment.fromTransmission(Sequence) method.

    Methods inherited from interface org.refcodes.mixin.AliasAccessor

    getAlias

    Methods inherited from interface org.refcodes.mixin.ArrayAccessor

    getArray

    Methods inherited from interface org.refcodes.mixin.ArrayAccessor.ArrayBuilder

    withArray

    Methods inherited from interface org.refcodes.mixin.ArrayAccessor.ArrayMutator

    setArray

    Methods inherited from interface org.refcodes.mixin.ArrayAccessor.ArrayProperty

    letArray

    Methods inherited from interface ArrayTransmission

    getLength, toSchema, toSequence, toSimpleTypeMap

    Methods inherited from interface Transmission

    reset, transmitTo, transmitTo

    Methods inherited from interface Transmission.TransmissionMixin

    transmitTo
  • Method Details