Interface ArrayTransmission<ARRAY extends Transmission>
- Type Parameters:
ARRAY- The type of the arrayTransmissionelements.
- All Superinterfaces:
AliasAccessor, ArrayAccessor<ARRAY[]>, ArrayAccessor.ArrayBuilder<ARRAY[], ArrayTransmission<ARRAY>>, ArrayAccessor.ArrayMutator<ARRAY[]>, ArrayAccessor.ArrayProperty<ARRAY[]>, Diagnosable, LengthAccessor, Resetable, Schemable<DiagnosticOptions>, Serializable, Transmission
- All Known Subinterfaces:
ArraySection<ARRAY>, ArraySegment<SEGMENT>
- All Known Implementing Classes:
AbstractArrayTransmission, FixedSegmentArraySection, SegmentArraySection
public interface ArrayTransmission<ARRAY extends Transmission>
extends Transmission, ArrayAccessor.ArrayProperty<ARRAY[]>, ArrayAccessor.ArrayBuilder<ARRAY[], ArrayTransmission<ARRAY>>, AliasAccessor
A
ArrayTransmission is a Transmission with array
Transmission elements. When invoking toSimpleTypeTable() the
array nature is preserved by indexing each element of the array with the
array index.-
Nested Class Summary
Nested classes/interfaces inherited from interface AliasAccessor
AliasAccessor.AliasBuilder<B>, AliasAccessor.AliasMutator, AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface ArrayAccessor
ArrayAccessor.ArrayBuilder<T,B>, ArrayAccessor.ArrayMutator<T>, ArrayAccessor.ArrayProperty<T> Nested classes/interfaces inherited from interface LengthAccessor
LengthAccessor.LengthBuilder<B>, LengthAccessor.LengthMutator, LengthAccessor.LengthPropertyNested classes/interfaces inherited from interface Transmission
Transmission.TransmissionMixin -
Method Summary
Modifier and TypeMethodDescriptiondefault intDetermines the overall length of thisTransmission.default SchematoSchema()default SequenceProvides theSequencerepresentation of thisTransmission.default SimpleTypeTableReturns theImmutableSimpleTypeTablerepresentation of thisTransmission.Methods inherited from interface AliasAccessor
getAliasMethods inherited from interface ArrayAccessor
getArrayMethods inherited from interface ArrayAccessor.ArrayBuilder
withArrayMethods inherited from interface ArrayAccessor.ArrayMutator
setArrayMethods inherited from interface ArrayAccessor.ArrayProperty
letArrayMethods inherited from interface Transmission
reset, transmitTo, transmitTo, transmitTo
-
Method Details
-
toSequence
Provides theSequencerepresentation of thisTransmission. In case of nestedTransmissioninstances, allSequencerepresentations from all sub-segments are accumulated to the result as well. Caution, the Transmission (or its nestedTransmissioninstances) may be backed by the returnedSequence.- Specified by:
toSequencein interfaceTransmission- Returns:
- The according instance's
Sequence.
-
toSimpleTypeTable
Returns theImmutableSimpleTypeTablerepresentation of thisTransmission. In case this Transmission hasTransmissionchildren, then the children are queried as well and contained in the resultingImmutableSimpleTypeTable. The aliases of the accordingTransmissioninstances represent the resulting path to aTransmission's final simple type.- Specified by:
toSimpleTypeTablein interfaceTransmission- Returns:
- The
ImmutableSimpleTypeTablerepresenting thisTransmissionand (if any) its children, with the according aliases forming the paths to theTransmission's values.
-
toSchema
- Specified by:
toSchemain interfaceSchemable<ARRAY extends Transmission>
-
getLength
default int getLength()Determines the overall length of thisTransmission. In case of nestedTransmissioninstances, all length values from all sub-segments are accumulated to the result as well.- Specified by:
getLengthin interfaceLengthAccessor- Specified by:
getLengthin interfaceTransmission- Returns:
- The (overall) length of the
Transmission(including any sub-segments).
-