Class BooleanArraySection

java.lang.Object
org.refcodes.serial.AbstractPayloadSection<boolean[]>
org.refcodes.serial.BooleanArraySection
All Implemented Interfaces:
Serializable, org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.LengthAccessor, org.refcodes.mixin.PayloadAccessor<boolean[]>, org.refcodes.mixin.PayloadAccessor.PayloadBuilder<boolean[],PayloadTransmission<boolean[]>>, org.refcodes.mixin.PayloadAccessor.PayloadMutator<boolean[]>, org.refcodes.mixin.PayloadAccessor.PayloadProperty<boolean[]>, org.refcodes.mixin.Resetable, org.refcodes.schema.Schemable, PayloadSection<boolean[]>, PayloadTransmission<boolean[]>, Section, Section.SectionMixin, Transmission, Transmission.TransmissionMixin

public class BooleanArraySection extends AbstractPayloadSection<boolean[]>
The BooleanArraySection is an implementation of a Section carrying a boolean array as payload. As the boolean array is mapped as a bit field (and the boolean array's length is not necessarily a multiple of 8) into a byte array, we prefix the modulo 8 value of the length of the boolean array when working with binary representations as of the Section interface.
See Also: