Class BooleanSegment
- All Implemented Interfaces:
Serializable, org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.LengthAccessor, org.refcodes.mixin.PayloadAccessor<Boolean>, org.refcodes.mixin.PayloadAccessor.PayloadBuilder<Boolean, PayloadTransmission<Boolean>>, org.refcodes.mixin.PayloadAccessor.PayloadMutator<Boolean>, org.refcodes.mixin.PayloadAccessor.PayloadProperty<Boolean>, org.refcodes.mixin.Resetable, org.refcodes.schema.Schemable, PayloadSegment<Boolean>, PayloadTransmission<Boolean>, Segment, Segment.SegmentMixin, Transmission, Transmission.TransmissionMixin
The
BooleanSegment is an implementation of a Segment carrying
in boolean value as value.- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.LengthAccessor
org.refcodes.mixin.LengthAccessor.LengthBuilder<B>, org.refcodes.mixin.LengthAccessor.LengthMutator, org.refcodes.mixin.LengthAccessor.LengthPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.PayloadAccessor
org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P,B>, org.refcodes.mixin.PayloadAccessor.PayloadMutator<P>, org.refcodes.mixin.PayloadAccessor.PayloadProperty<P> Nested classes/interfaces inherited from interface Segment
Segment.SegmentMixinNested classes/interfaces inherited from interface Transmission
Transmission.TransmissionMixin -
Field Summary
FieldsFields inherited from class AbstractPayloadSegment
_alias, _payload -
Constructor Summary
ConstructorsConstructorDescriptionConstructs an emptyBooleanSegment.BooleanSegment(Boolean aValue) Constructs aBooleanSegmentwith the given boolean payload.BooleanSegment(String aAlias) Constructs an emptyBooleanSegment.BooleanSegment(String aAlias, Boolean aValue) Constructs aBooleanSegmentwith the given boolean payload. -
Method Summary
Modifier and TypeMethodDescriptionintfromTransmission(Sequence aSequence, int aOffset) (Re-)initializes this instance with the the givenSequencedata.intDetermines the overall length of thisTransmission.voidreset()Resets any dynamic data (e.g. values such as payloads or checksums) and must not(!)toSchema()Provides theSequencerepresentation of thisTransmission.withPayload(Boolean aValue) Methods inherited from class AbstractPayloadSegment
equals, getAlias, getPayload, hashCode, setPayload, toSimpleTypeMap, toStringMethods inherited from interface org.refcodes.mixin.PayloadAccessor
getPayloadOrMethods inherited from interface org.refcodes.mixin.PayloadAccessor.PayloadProperty
letPayloadMethods inherited from interface Segment
fromTransmission, fromTransmission, fromTransmission, receiveFrom, receiveFromMethods inherited from interface Segment.SegmentMixin
receiveFromMethods inherited from interface Transmission
toSimpleTypeMap, transmitTo, transmitToMethods inherited from interface Transmission.TransmissionMixin
transmitTo
-
Field Details
-
BYTES
public static final int BYTES- See Also:
-
-
Constructor Details
-
BooleanSegment
public BooleanSegment()Constructs an emptyBooleanSegment. -
BooleanSegment
Constructs aBooleanSegmentwith the given boolean payload.- Parameters:
aValue- The value (payload) to be contained by theBooleanSegment.
-
BooleanSegment
Constructs an emptyBooleanSegment.- Parameters:
aAlias- The alias which identifies the content of this segment.
-
BooleanSegment
Constructs aBooleanSegmentwith the given boolean payload.- Parameters:
aAlias- The alias which identifies the content of this segment.aValue- The value (payload) to be contained by theBooleanSegment.
-
-
Method Details
-
toSequence
Provides theSequencerepresentation of thisTransmission. In case of nestedTransmissioninstances, allSequencerepresentations from all sub-segments are accumulated to the result as well. Caution, the Transmission (or its nestedTransmissioninstances) may be backed by the returnedSequence.- Specified by:
toSequencein interfaceTransmission- Returns:
- The according instance's
Sequence.
-
fromTransmission
(Re-)initializes this instance with the the givenSequencedata.- Specified by:
fromTransmissionin interfaceSegment- Parameters:
aSequence- TheSequencedata from which to (re-)initialize this instance.aOffset- The offset where to start processing the providedSequence.- Returns:
- The index after the last offset into the given
Sequenceprocessed by this method. - Throws:
TransmissionException- thrown in case a givenSequencecannot be processed.
-
getLength
public int getLength()Determines the overall length of thisTransmission. In case of nestedTransmissioninstances, all length values from all sub-segments are accumulated to the result as well.- Specified by:
getLengthin interfaceorg.refcodes.mixin.LengthAccessor- Specified by:
getLengthin interfaceTransmission- Returns:
- The (overall) length of the
Transmission(including any sub-segments).
-
reset
public void reset()Resets any dynamic data (e.g. values such as payloads or checksums) and must not(!) reset any configurations or settings required to produce the dynamic data (e.g. theTransmissionMetrics).- Specified by:
resetin interfaceorg.refcodes.mixin.Resetable- Specified by:
resetin interfaceTransmission- Overrides:
resetin classAbstractPayloadSegment<Boolean>
-
toSchema
- Specified by:
toSchemain interfaceorg.refcodes.schema.Schemable- Specified by:
toSchemain interfaceTransmission
-
withPayload
- Specified by:
withPayloadin interfaceorg.refcodes.mixin.PayloadAccessor.PayloadBuilder<Boolean, PayloadTransmission<Boolean>>
-