Class ByteSegment
- All Implemented Interfaces:
Serializable, org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.LengthAccessor, org.refcodes.mixin.PayloadAccessor<Byte>, org.refcodes.mixin.PayloadAccessor.PayloadBuilder<Byte, PayloadTransmission<Byte>>, org.refcodes.mixin.PayloadAccessor.PayloadMutator<Byte>, org.refcodes.mixin.PayloadAccessor.PayloadProperty<Byte>, org.refcodes.mixin.Resetable, org.refcodes.schema.Schemable, PayloadSegment<Byte>, PayloadTransmission<Byte>, Segment, Segment.SegmentMixin, Transmission, Transmission.TransmissionMixin
The
ByteSegment is an implementation of a Segment carrying in
byte value as payload.- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.LengthAccessor
org.refcodes.mixin.LengthAccessor.LengthBuilder<B>, org.refcodes.mixin.LengthAccessor.LengthMutator, org.refcodes.mixin.LengthAccessor.LengthPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.PayloadAccessor
org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P,B>, org.refcodes.mixin.PayloadAccessor.PayloadMutator<P>, org.refcodes.mixin.PayloadAccessor.PayloadProperty<P> Nested classes/interfaces inherited from interface Segment
Segment.SegmentMixinNested classes/interfaces inherited from interface Transmission
Transmission.TransmissionMixin -
Field Summary
FieldsFields inherited from class AbstractPayloadSegment
_alias, _payload -
Constructor Summary
ConstructorsConstructorDescriptionConstructs an emptyByteSegment.ByteSegment(Byte aValue) Constructs aByteSegmentwith the given byte payload.ByteSegment(String aAlias) Constructs an emptyByteSegment.ByteSegment(String aAlias, Byte aValue) Constructs aByteSegmentwith the given byte payload. -
Method Summary
Modifier and TypeMethodDescriptionintfromTransmission(Sequence aSequence, int aOffset) (Re-)initializes this instance with the the givenSequencedata.intDetermines the overall length of thisTransmission.voidreset()Resets any dynamic data (e.g. values such as payloads or checksums) and must not(!)toSchema()Provides theSequencerepresentation of thisTransmission.withPayload(Byte aValue) Methods inherited from class AbstractPayloadSegment
equals, getAlias, getPayload, hashCode, setPayload, toSimpleTypeMap, toStringMethods inherited from interface org.refcodes.mixin.PayloadAccessor
getPayloadOrMethods inherited from interface org.refcodes.mixin.PayloadAccessor.PayloadProperty
letPayloadMethods inherited from interface Segment
fromTransmission, fromTransmission, fromTransmission, receiveFrom, receiveFromMethods inherited from interface Segment.SegmentMixin
receiveFromMethods inherited from interface Transmission
toSimpleTypeMap, transmitTo, transmitToMethods inherited from interface Transmission.TransmissionMixin
transmitTo
-
Field Details
-
BYTES
public static final int BYTES- See Also:
-
-
Constructor Details
-
ByteSegment
public ByteSegment()Constructs an emptyByteSegment. -
ByteSegment
Constructs aByteSegmentwith the given byte payload.- Parameters:
aValue- The value (payload) to be contained by theSegment.
-
ByteSegment
Constructs an emptyByteSegment.- Parameters:
aAlias- The alias which identifies the content of this segment.
-
ByteSegment
Constructs aByteSegmentwith the given byte payload.- Parameters:
aAlias- The alias which identifies the content of this segment.aValue- The value (payload) to be contained by theSegment.
-
-
Method Details
-
toSequence
Provides theSequencerepresentation of thisTransmission. In case of nestedTransmissioninstances, allSequencerepresentations from all sub-segments are accumulated to the result as well. Caution, the Transmission (or its nestedTransmissioninstances) may be backed by the returnedSequence.- Specified by:
toSequencein interfaceTransmission- Returns:
- The according instance's
Sequence.
-
fromTransmission
(Re-)initializes this instance with the the givenSequencedata.- Specified by:
fromTransmissionin interfaceSegment- Parameters:
aSequence- TheSequencedata from which to (re-)initialize this instance.aOffset- The offset where to start processing the providedSequence.- Returns:
- The index after the last offset into the given
Sequenceprocessed by this method. - Throws:
TransmissionException- thrown in case a givenSequencecannot be processed.
-
getLength
public int getLength()Determines the overall length of thisTransmission. In case of nestedTransmissioninstances, all length values from all sub-segments are accumulated to the result as well.- Specified by:
getLengthin interfaceorg.refcodes.mixin.LengthAccessor- Specified by:
getLengthin interfaceTransmission- Returns:
- The (overall) length of the
Transmission(including any sub-segments).
-
reset
public void reset()Resets any dynamic data (e.g. values such as payloads or checksums) and must not(!) reset any configurations or settings required to produce the dynamic data (e.g. theTransmissionMetrics).- Specified by:
resetin interfaceorg.refcodes.mixin.Resetable- Specified by:
resetin interfaceTransmission- Overrides:
resetin classAbstractPayloadSegment<Byte>
-
toSchema
- Specified by:
toSchemain interfaceorg.refcodes.schema.Schemable- Specified by:
toSchemain interfaceTransmission
-
withPayload
- Specified by:
withPayloadin interfaceorg.refcodes.mixin.PayloadAccessor.PayloadBuilder<Byte, PayloadTransmission<Byte>>
-