Class CharArraySection

java.lang.Object
org.refcodes.serial.AbstractPayloadSection<char[]>
org.refcodes.serial.CharArraySection
All Implemented Interfaces:
Serializable, AliasAccessor, EncodingAccessor<Charset>, LengthAccessor, PayloadAccessor<char[]>, PayloadAccessor.PayloadBuilder<char[], PayloadTransmission<char[]>>, PayloadAccessor.PayloadMutator<char[]>, PayloadAccessor.PayloadProperty<char[]>, Resetable, Diagnosable, Schemable<DiagnosticOptions>, PayloadSection<char[]>, PayloadTransmission<char[]>, Section, Section.SectionMixin, Transmission, Transmission.TransmissionMixin

public class CharArraySection extends AbstractPayloadSection<char[]> implements EncodingAccessor<Charset>
The CharArraySection is an implementation of a PayloadSection carrying a char array as payload.
See Also:
  • Constructor Details

    • CharArraySection

      public CharArraySection(TransmissionMetrics aTransmissionMetrics)
      Constructs an according instance from the given configuration. The configuration attributes are taken from the TransmissionMetrics configuration object, though only those attributes are supported which are also supported by the other constructors!
      Parameters:
      aTransmissionMetrics - The TransmissionMetrics to be used for configuring this instance.
    • CharArraySection

      public CharArraySection(TransmissionMetrics aTransmissionMetrics, char... aValue)
      Constructs an according instance from the given configuration. The configuration attributes are taken from the TransmissionMetrics configuration object, though only those attributes are supported which are also supported by the other constructors!
      Parameters:
      aTransmissionMetrics - The TransmissionMetrics to be used for configuring this instance.
      aValue - The payload to be contained by the CharArraySection.
    • CharArraySection

      public CharArraySection(TransmissionMetrics aTransmissionMetrics, Character... aValue)
      Constructs an according instance from the given configuration. The configuration attributes are taken from the TransmissionMetrics configuration object, though only those attributes are supported which are also supported by the other constructors!
      Parameters:
      aTransmissionMetrics - The TransmissionMetrics to be used for configuring this instance.
      aValue - The payload to be contained by the CharArraySection.
    • CharArraySection

      public CharArraySection(String aAlias, TransmissionMetrics aTransmissionMetrics)
      Constructs an according instance from the given configuration. The configuration attributes are taken from the TransmissionMetrics configuration object, though only those attributes are supported which are also supported by the other constructors!
      Parameters:
      aAlias - The alias which identifies the content of this instance.
      aTransmissionMetrics - The TransmissionMetrics to be used for configuring this instance.
    • CharArraySection

      public CharArraySection(String aAlias, TransmissionMetrics aTransmissionMetrics, char... aValue)
      Constructs an according instance from the given configuration. The configuration attributes are taken from the TransmissionMetrics configuration object, though only those attributes are supported which are also supported by the other constructors!
      Parameters:
      aAlias - The alias which identifies the content of this instance.
      aTransmissionMetrics - The TransmissionMetrics to be used for configuring this instance.
      aValue - The payload to be contained by the CharArraySection.
    • CharArraySection

      public CharArraySection(String aAlias, TransmissionMetrics aTransmissionMetrics, Character... aValue)
      Constructs an according instance from the given configuration. The configuration attributes are taken from the TransmissionMetrics configuration object, though only those attributes are supported which are also supported by the other constructors!
      Parameters:
      aAlias - The alias which identifies the content of this instance.
      aTransmissionMetrics - The TransmissionMetrics to be used for configuring this instance.
      aValue - The payload to be contained by the CharArraySection.
    • CharArraySection

      public CharArraySection()
      Constructs an empty CharArraySection. Uses UTF-16 by default for encoding.
    • CharArraySection

      public CharArraySection(Charset aCharset)
      Constructs an empty CharArraySection.
      Parameters:
      aCharset - The charset to be used for encoding.
    • CharArraySection

      public CharArraySection(char[] aPayload)
      Constructs a CharArraySection with the given char array payload. Uses TransmissionMetrics.DEFAULT_ENCODING by default for encoding.
      Parameters:
      aPayload - The payload to be contained by the PayloadSection.
    • CharArraySection

      public CharArraySection(Character[] aPayload)
      Constructs a CharArraySection with the given char array payload. Uses TransmissionMetrics.DEFAULT_ENCODING by default for encoding.
      Parameters:
      aPayload - The payload to be contained by the PayloadSection.
    • CharArraySection

      public CharArraySection(Charset aCharset, char... aPayload)
      Constructs a CharArraySection with the given char array payload. Uses TransmissionMetrics.DEFAULT_ENCODING by default for encoding.
      Parameters:
      aCharset - The charset to be used for encoding.
      aPayload - The payload to be contained by the PayloadSection.
    • CharArraySection

      public CharArraySection(Charset aCharset, Character... aPayload)
      Constructs a CharArraySection with the given char array payload. Uses TransmissionMetrics.DEFAULT_ENCODING by default for encoding.
      Parameters:
      aCharset - The charset to be used for encoding.
      aPayload - The payload to be contained by the PayloadSection.
    • CharArraySection

      public CharArraySection(String aAlias)
      Constructs an empty CharArraySection. Uses UTF-16 by default for encoding.
      Parameters:
      aAlias - The alias which identifies the content of this segment.
    • CharArraySection

      public CharArraySection(String aAlias, Charset aCharset)
      Constructs an empty CharArraySection.
      Parameters:
      aAlias - The alias which identifies the content of this segment.
      aCharset - The charset to be used for encoding.
    • CharArraySection

      public CharArraySection(String aAlias, char[] aPayload)
      Constructs a CharArraySection with the given char array payload. Uses TransmissionMetrics.DEFAULT_ENCODING by default for encoding.
      Parameters:
      aAlias - The alias which identifies the content of this segment.
      aPayload - The payload to be contained by the PayloadSection.
    • CharArraySection

      public CharArraySection(String aAlias, Character[] aPayload)
      Constructs a CharArraySection with the given char array payload. Uses TransmissionMetrics.DEFAULT_ENCODING by default for encoding.
      Parameters:
      aAlias - The alias which identifies the content of this segment.
      aPayload - The payload to be contained by the PayloadSection.
    • CharArraySection

      public CharArraySection(String aAlias, Charset aCharset, char... aPayload)
      Constructs a CharArraySection with the given char array payload. Uses TransmissionMetrics.DEFAULT_ENCODING by default for encoding.
      Parameters:
      aAlias - The alias which identifies the content of this segment.
      aCharset - The charset to be used for encoding.
      aPayload - The payload to be contained by the PayloadSection.
    • CharArraySection

      public CharArraySection(String aAlias, Charset aCharset, Character... aPayload)
      Constructs a CharArraySection with the given char array payload. Uses TransmissionMetrics.DEFAULT_ENCODING by default for encoding.
      Parameters:
      aAlias - The alias which identifies the content of this segment.
      aCharset - The charset to be used for encoding.
      aPayload - The payload to be contained by the PayloadSection.
  • Method Details