Class CrossoverLoopbackPort

All Implemented Interfaces:
Flushable, Comparable<Port<?>>, Closable, Closable.CloseAutomaton, ClosedAccessor, ConnectableComponent, ConnectableComponent.ConnectableAutomaton, ConnectionComponent<PortMetrics>, ConnectionComponent.ConnectionAutomaton<PortMetrics>, ConnectionOpenable<PortMetrics>, ConnectionOpenable.ConnectionOpenAutomaton<PortMetrics>, ConnectionOpenable.ConnectionOpenBuilder<PortMetrics, Port<PortMetrics>>, ConnectionStatusAccessor, Flushable, LinkComponent, LinkComponent.LinkAutomaton, Openable, Openable.OpenAutomaton, Openable.OpenBuilder<Port<PortMetrics>>, OpenedAccessor, Availability, ByteDestination, ByteReceiver, BytesDestination, ByteSource, BytesReceiver, BytesSource, BytesTransceiver, BytesTransmitter, ByteTransceiver, ByteTransmitter, Receivable, Skippable, TimeoutInputStreamAccessor, Transmittable, AliasAccessor, InputStreamAccessor, OutputStreamAccessor, Port<PortMetrics>, PortMetricsAccessor<PortMetrics>, SegmentDestination, SegmentReceiver, SegmentSource, SegmentTransceiver, SegmentTransmitter, SerialReceiver, SerialTransceiver, SerialTransmitter

public class CrossoverLoopbackPort extends LoopbackPort
The CrossoverLoopbackPort is an in-memory implementation of a Port which loops its output directly to the "connected" LoopbackPort counterpart ("other end of the wire"). This is suitable for cases using a some kind of frequent handshake between a transmitter and a receiver on the same line where we have to simulate a bidirectional in-memory communication between two ports.
  • Constructor Details

    • CrossoverLoopbackPort

      public CrossoverLoopbackPort(LoopbackPort aCounterpartPort)
      Constructs a CrossoverLoopbackPort.
      Parameters:
      aCounterpartPort - The port's counterpart (other end of the line).
    • CrossoverLoopbackPort

      public CrossoverLoopbackPort(String aAlias, LoopbackPort aCounterpartPort)
      Constructs a CrossoverLoopbackPort.
      Parameters:
      aAlias - The alias to use for this port.
      aCounterpartPort - The port's counterpart (other end of the line).
    • CrossoverLoopbackPort

      public CrossoverLoopbackPort(LoopbackPort aCounterpartPort, ExecutorService aExecutorService)
      Constructs a CrossoverLoopbackPort.
      Parameters:
      aCounterpartPort - The port's counterpart (other end of the line).
      aExecutorService - The ExecutorService to be used when invoking asynchronously working methods.
    • CrossoverLoopbackPort

      public CrossoverLoopbackPort(String aAlias, LoopbackPort aCounterpartPort, ExecutorService aExecutorService)
      Instantiates the class CrossoverLoopbackPort.
      Parameters:
      aAlias - the alias
      aCounterpartPort - The port's counterpart (other end of the line).
      aExecutorService - the executor service
      See Also: