- java.lang.Object
-
- org.refcodes.serial.AbstractPayloadSection<double[]>
-
- org.refcodes.serial.DoubleArraySection
-
- All Implemented Interfaces:
Serializable,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.LengthAccessor,org.refcodes.mixin.PayloadAccessor<double[]>,org.refcodes.mixin.PayloadAccessor.PayloadBuilder<double[],PayloadTransmission<double[]>>,org.refcodes.mixin.PayloadAccessor.PayloadMutator<double[]>,org.refcodes.mixin.PayloadAccessor.PayloadProperty<double[]>,PayloadSection<double[]>,PayloadTransmission<double[]>,Section,Section.SectionMixin,Transmission,Transmission.TransmissionMixin
public class DoubleArraySection extends AbstractPayloadSection<double[]> implements PayloadSection<double[]>
TheDoubleArraySectionis an implementation of aSectioncarrying a double array as payload.- See Also:
- Serialized Form
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.LengthAccessor
org.refcodes.mixin.LengthAccessor.LengthBuilder<B extends org.refcodes.mixin.LengthAccessor.LengthBuilder<B>>, org.refcodes.mixin.LengthAccessor.LengthMutator, org.refcodes.mixin.LengthAccessor.LengthProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.PayloadAccessor
org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P extends Object,B extends org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P,B>>, org.refcodes.mixin.PayloadAccessor.PayloadMutator<P extends Object>, org.refcodes.mixin.PayloadAccessor.PayloadProperty<P extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.serial.Section
Section.SectionMixin
-
Nested classes/interfaces inherited from interface org.refcodes.serial.Transmission
Transmission.TransmissionMixin
-
-
Field Summary
Fields Modifier and Type Field Description static StringENDIANESS-
Fields inherited from class org.refcodes.serial.AbstractPayloadSection
_alias, _payload
-
-
Constructor Summary
Constructors Constructor Description DoubleArraySection()Constructs an emptyDoubleArraySectionwith aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theDoubleArraySection's value.DoubleArraySection(double... aValue)Constructs aDoubleArraySectionwith the given double array payload and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theDoubleArraySection's value.DoubleArraySection(Double... aValue)Constructs aDoubleArraySectionwith the given double array payload and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theDoubleArraySection's value.DoubleArraySection(String aAlias)Constructs an emptyDoubleArraySectionwith aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theDoubleArraySection's value.DoubleArraySection(String aAlias, double... aValue)Constructs aDoubleArraySectionwith the given double array payload and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theDoubleArraySection's value.DoubleArraySection(String aAlias, Double... aValue)Constructs aDoubleArraySectionwith the given double array payload and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theDoubleArraySection's value.DoubleArraySection(String aAlias, org.refcodes.numerical.Endianess aEndianess)Constructs an emptyDoubleArraySectionwith the givenEndianess.DoubleArraySection(String aAlias, org.refcodes.numerical.Endianess aEndianess, double... aValue)Constructs aDoubleArraySectionwith the given double array payload and the givenEndianessfor the representation of theDoubleArraySection's value.DoubleArraySection(String aAlias, org.refcodes.numerical.Endianess aEndianess, Double... aValue)Constructs aDoubleArraySectionwith the given double array payload and the givenEndianessfor the representation of theDoubleArraySection's value.DoubleArraySection(String aAlias, TransmissionMetrics aTransmissionMetrics)Constructs an according instance from the given configuration.DoubleArraySection(String aAlias, TransmissionMetrics aTransmissionMetrics, double... aValue)Constructs an according instance from the given configuration.DoubleArraySection(String aAlias, TransmissionMetrics aTransmissionMetrics, Double... aValue)Constructs an according instance from the given configuration.DoubleArraySection(org.refcodes.numerical.Endianess aEndianess)Constructs an emptyDoubleArraySectionwith the givenEndianess.DoubleArraySection(org.refcodes.numerical.Endianess aEndianess, double... aValue)Constructs aDoubleArraySectionwith the given double array payload and the givenEndianessfor the representation of theDoubleArraySection's value.DoubleArraySection(org.refcodes.numerical.Endianess aEndianess, Double... aValue)Constructs aDoubleArraySectionwith the given double array payload and the givenEndianessfor the representation of theDoubleArraySection's value.DoubleArraySection(TransmissionMetrics aTransmissionMetrics)Constructs an according instance from the given configuration.DoubleArraySection(TransmissionMetrics aTransmissionMetrics, double... aValue)Constructs an according instance from the given configuration.DoubleArraySection(TransmissionMetrics aTransmissionMetrics, Double... aValue)Constructs an according instance from the given configuration.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description voidfromTransmission(Sequence aSequence, int aOffset, int aLength)(Re-)initializes this instance with the the givenSequencedata.intgetLength()Determines the overall length of thisTransmission.voidsetPayload(Double[] aPayload)Convenience method to convert the array of wrapper types into its counterpart with primitive types before invokingAbstractPayloadSection.setPayload(Object).SchematoSchema()Retrieves theSchemarepresenting theTransmission.SequencetoSequence()Provides theSequencerepresentation of thisTransmission.StringtoString()DoubleArraySectionwithPayload(double[] aValue)DoubleArraySectionwithPayload(Double[] aPayload)Convenience method to convert the array of wrapper types into its counterpart with primitive types before invokingwithPayload(double[]).-
Methods inherited from class org.refcodes.serial.AbstractPayloadSection
equals, getAlias, getPayload, hashCode, setPayload, toSimpleTypeMap
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface org.refcodes.serial.Section
fromTransmission, fromTransmission, fromTransmission, receiveFrom, receiveFrom
-
Methods inherited from interface org.refcodes.serial.Section.SectionMixin
receiveFrom
-
Methods inherited from interface org.refcodes.serial.Transmission
toSimpleTypeMap, transmitTo, transmitTo
-
Methods inherited from interface org.refcodes.serial.Transmission.TransmissionMixin
transmitTo
-
-
-
-
Field Detail
-
ENDIANESS
public static final String ENDIANESS
- See Also:
- Constant Field Values
-
-
Constructor Detail
-
DoubleArraySection
public DoubleArraySection(TransmissionMetrics aTransmissionMetrics)
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.
-
DoubleArraySection
public DoubleArraySection(TransmissionMetrics aTransmissionMetrics, double... aValue)
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.aValue- The payload to be contained by theDoubleArraySection.
-
DoubleArraySection
public DoubleArraySection(TransmissionMetrics aTransmissionMetrics, Double... aValue)
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.aValue- The payload to be contained by theDoubleArraySection.
-
DoubleArraySection
public DoubleArraySection(String aAlias, TransmissionMetrics aTransmissionMetrics)
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aAlias- The alias which identifies the content of this instance.aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.
-
DoubleArraySection
public DoubleArraySection(String aAlias, TransmissionMetrics aTransmissionMetrics, double... aValue)
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aAlias- The alias which identifies the content of this instance.aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.aValue- The payload to be contained by theDoubleArraySection.
-
DoubleArraySection
public DoubleArraySection(String aAlias, TransmissionMetrics aTransmissionMetrics, Double... aValue)
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aAlias- The alias which identifies the content of this instance.aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.aValue- The payload to be contained by theDoubleArraySection.
-
DoubleArraySection
public DoubleArraySection()
Constructs an emptyDoubleArraySectionwith aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theDoubleArraySection's value.
-
DoubleArraySection
public DoubleArraySection(org.refcodes.numerical.Endianess aEndianess)
Constructs an emptyDoubleArraySectionwith the givenEndianess.- Parameters:
aEndianess- TheEndianessto be used for payload values.
-
DoubleArraySection
public DoubleArraySection(double... aValue)
Constructs aDoubleArraySectionwith the given double array payload and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theDoubleArraySection's value.- Parameters:
aValue- The payload to be contained by theDoubleArraySection.
-
DoubleArraySection
public DoubleArraySection(Double... aValue)
Constructs aDoubleArraySectionwith the given double array payload and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theDoubleArraySection's value.- Parameters:
aValue- The payload to be contained by theDoubleArraySection.
-
DoubleArraySection
public DoubleArraySection(org.refcodes.numerical.Endianess aEndianess, double... aValue)Constructs aDoubleArraySectionwith the given double array payload and the givenEndianessfor the representation of theDoubleArraySection's value.- Parameters:
aEndianess- TheEndianessto be used for payload values.aValue- The payload to be contained by theDoubleArraySection.
-
DoubleArraySection
public DoubleArraySection(org.refcodes.numerical.Endianess aEndianess, Double... aValue)Constructs aDoubleArraySectionwith the given double array payload and the givenEndianessfor the representation of theDoubleArraySection's value.- Parameters:
aEndianess- TheEndianessto be used for payload values.aValue- The payload to be contained by theDoubleArraySection.
-
DoubleArraySection
public DoubleArraySection(String aAlias)
Constructs an emptyDoubleArraySectionwith aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theDoubleArraySection's value.- Parameters:
aAlias- The alias which identifies the content of this segment.
-
DoubleArraySection
public DoubleArraySection(String aAlias, org.refcodes.numerical.Endianess aEndianess)
Constructs an emptyDoubleArraySectionwith the givenEndianess.- Parameters:
aAlias- The alias which identifies the content of this segment.aEndianess- TheEndianessto be used for payload values.
-
DoubleArraySection
public DoubleArraySection(String aAlias, double... aValue)
Constructs aDoubleArraySectionwith the given double array payload and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theDoubleArraySection's value.- Parameters:
aAlias- The alias which identifies the content of this segment.aValue- The payload to be contained by theDoubleArraySection.
-
DoubleArraySection
public DoubleArraySection(String aAlias, Double... aValue)
Constructs aDoubleArraySectionwith the given double array payload and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theDoubleArraySection's value.- Parameters:
aAlias- The alias which identifies the content of this segment.aValue- The payload to be contained by theDoubleArraySection.
-
DoubleArraySection
public DoubleArraySection(String aAlias, org.refcodes.numerical.Endianess aEndianess, double... aValue)
Constructs aDoubleArraySectionwith the given double array payload and the givenEndianessfor the representation of theDoubleArraySection's value.- Parameters:
aAlias- The alias which identifies the content of this segment.aEndianess- TheEndianessto be used for payload values.aValue- The payload to be contained by theDoubleArraySection.
-
DoubleArraySection
public DoubleArraySection(String aAlias, org.refcodes.numerical.Endianess aEndianess, Double... aValue)
Constructs aDoubleArraySectionwith the given double array payload and the givenEndianessfor the representation of theDoubleArraySection's value.- Parameters:
aAlias- The alias which identifies the content of this segment.aEndianess- TheEndianessto be used for payload values.aValue- The payload to be contained by theDoubleArraySection.
-
-
Method Detail
-
toSequence
public Sequence toSequence()
Provides theSequencerepresentation of thisTransmission. In case of nestedTransmissioninstances, allSequencerepresentations from all sub-segments are accumulated to the result as well. Caution, the Transmission (or its nestedTransmissioninstances) may be backed by the returnedSequence.- Specified by:
toSequencein interfaceTransmission- Returns:
- The according instance's
Sequence.
-
fromTransmission
public void fromTransmission(Sequence aSequence, int aOffset, int aLength) throws TransmissionException
(Re-)initializes this instance with the the givenSequencedata.- Specified by:
fromTransmissionin interfaceSection- Parameters:
aSequence- TheSequencedata from which to (re-)initialize this instance.aOffset- The offset where to start processing the providedSequence.aLength- The length of data assigned by theSequence.- Throws:
TransmissionException- thrown in case a givenSequencecannot be processed.
-
getLength
public int getLength()
Determines the overall length of thisTransmission. In case of nestedTransmissioninstances, all length values from all sub-segments are accumulated to the result as well.- Specified by:
getLengthin interfaceorg.refcodes.mixin.LengthAccessor- Specified by:
getLengthin interfaceTransmission- Returns:
- The (overall) length of the
Transmission(including any sub-segments).
-
toSchema
public Schema toSchema()
Retrieves theSchemarepresenting theTransmission. Retrieving aSchemais useful when analyzing and debugging data structures such as aAllocSectionDecoratorSegmentinstance to help document, learn and verify on the structure (as well as the content) of that veryAllocSectionDecoratorSegment.- Specified by:
toSchemain interfaceTransmission- Returns:
- The
Schemarepresentation of the implementing type for debugging and verification (or documentation) purposes.
-
toString
public String toString()
- Overrides:
toStringin classAbstractPayloadSection<double[]>
-
withPayload
public DoubleArraySection withPayload(double[] aValue)
- Specified by:
withPayloadin interfaceorg.refcodes.mixin.PayloadAccessor.PayloadBuilder<double[],PayloadTransmission<double[]>>
-
setPayload
public void setPayload(Double[] aPayload)
Convenience method to convert the array of wrapper types into its counterpart with primitive types before invokingAbstractPayloadSection.setPayload(Object).- Parameters:
aPayload- The payload with the wrapper types.
-
withPayload
public DoubleArraySection withPayload(Double[] aPayload)
Convenience method to convert the array of wrapper types into its counterpart with primitive types before invokingwithPayload(double[]).- Parameters:
aPayload- The payload with the wrapper types.- Returns:
- This instance as of the builder pattern.
-
-