Class DoubleSegment

    • Constructor Detail

      • DoubleSegment

        public DoubleSegment​(TransmissionMetrics aTransmissionMetrics)
        Constructs an according instance from the given configuration. The configuration attributes are taken from the TransmissionMetrics configuration object, though only those attributes are supported which are also supported by the other constructors!
        Parameters:
        aTransmissionMetrics - The TransmissionMetrics to be used for configuring this instance.
      • DoubleSegment

        public DoubleSegment​(Double aValue,
                             TransmissionMetrics aTransmissionMetrics)
        Constructs an according instance from the given configuration. The configuration attributes are taken from the TransmissionMetrics configuration object, though only those attributes are supported which are also supported by the other constructors!
        Parameters:
        aValue - The payload to be contained by the DoubleArraySection.
        aTransmissionMetrics - The TransmissionMetrics to be used for configuring this instance.
      • DoubleSegment

        public DoubleSegment​(String aAlias,
                             TransmissionMetrics aTransmissionMetrics)
        Constructs an according instance from the given configuration. The configuration attributes are taken from the TransmissionMetrics configuration object, though only those attributes are supported which are also supported by the other constructors!
        Parameters:
        aAlias - The alias which identifies the content of this instance.
        aTransmissionMetrics - The TransmissionMetrics to be used for configuring this instance.
      • DoubleSegment

        public DoubleSegment​(String aAlias,
                             Double aValue,
                             TransmissionMetrics aTransmissionMetrics)
        Constructs an according instance from the given configuration. The configuration attributes are taken from the TransmissionMetrics configuration object, though only those attributes are supported which are also supported by the other constructors!
        Parameters:
        aAlias - The alias which identifies the content of this instance.
        aValue - The payload to be contained by the DoubleArraySection.
        aTransmissionMetrics - The TransmissionMetrics to be used for configuring this instance.
      • DoubleSegment

        public DoubleSegment​(org.refcodes.numerical.Endianess aEndianess)
        Constructs an empty DoubleSegment with the given Endianess.
        Parameters:
        aEndianess - The Endianess to be used for payload values.
      • DoubleSegment

        public DoubleSegment​(Double aValue,
                             org.refcodes.numerical.Endianess aEndianess)
        Constructs a DoubleSegment with the given double value (payload) and the given Endianess for the representation of the Segment's value.
        Parameters:
        aValue - The value (payload) to be contained by the Segment.
        aEndianess - The Endianess to be used for payload values.
      • DoubleSegment

        public DoubleSegment​(String aAlias,
                             org.refcodes.numerical.Endianess aEndianess)
        Constructs an empty DoubleSegment with the given Endianess.
        Parameters:
        aAlias - The alias which identifies the content of this segment.
        aEndianess - The Endianess to be used for payload values.
      • DoubleSegment

        public DoubleSegment​(String aAlias,
                             Double aValue,
                             org.refcodes.numerical.Endianess aEndianess)
        Constructs a DoubleSegment with the given double value (payload) and the given Endianess for the representation of the Segment's value.
        Parameters:
        aAlias - The alias which identifies the content of this segment.
        aValue - The value (payload) to be contained by the Segment.
        aEndianess - The Endianess to be used for payload values.