- java.lang.Object
-
- org.refcodes.serial.FixedLengthSequenceSegment
-
- All Implemented Interfaces:
Serializable,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.LengthAccessor,org.refcodes.mixin.PayloadAccessor<Sequence>,org.refcodes.mixin.PayloadAccessor.PayloadBuilder<Sequence,PayloadTransmission<Sequence>>,org.refcodes.mixin.PayloadAccessor.PayloadMutator<Sequence>,org.refcodes.mixin.PayloadAccessor.PayloadProperty<Sequence>,PayloadSegment<Sequence>,PayloadTransmission<Sequence>,Segment,Segment.SegmentMixin,Transmission,Transmission.TransmissionMixin
public class FixedLengthSequenceSegment extends Object implements PayloadSegment<Sequence>, Segment.SegmentMixin
TheFixedLengthSequenceSegmentis aSegmentrepresenting aSequenceof a fixed length (as of the arguments passed to one of its constructors).- See Also:
- Serialized Form
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.LengthAccessor
org.refcodes.mixin.LengthAccessor.LengthBuilder<B extends org.refcodes.mixin.LengthAccessor.LengthBuilder<B>>, org.refcodes.mixin.LengthAccessor.LengthMutator, org.refcodes.mixin.LengthAccessor.LengthProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.PayloadAccessor
org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P extends Object,B extends org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P,B>>, org.refcodes.mixin.PayloadAccessor.PayloadMutator<P extends Object>, org.refcodes.mixin.PayloadAccessor.PayloadProperty<P extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.serial.Segment
Segment.SegmentMixin
-
Nested classes/interfaces inherited from interface org.refcodes.serial.Transmission
Transmission.TransmissionMixin
-
-
Constructor Summary
Constructors Constructor Description FixedLengthSequenceSegment(int aSequenceSize)Constructs theFixedLengthSequenceSegment.FixedLengthSequenceSegment(String aAlias, int aSequenceSize)Constructs theFixedLengthSequenceSegment.FixedLengthSequenceSegment(String aAlias, Sequence aSequence)Constructs theFixedLengthSequenceSegment.FixedLengthSequenceSegment(Sequence aSequence)Constructs theFixedLengthSequenceSegment.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description intfromTransmission(Sequence aSequence, int aOffset)(Re-)initializes this instance with the the givenSequencedata.StringgetAlias()intgetLength()Determines the overall length of thisTransmission.SequencegetPayload()voidsetPayload(Sequence aValue)SchematoSchema()Retrieves theSchemarepresenting theTransmission.SequencetoSequence()Provides theSequencerepresentation of thisTransmission.org.refcodes.struct.SimpleTypeMaptoSimpleTypeMap()Returns theSimpleTypeMaprepresentation of thisTransmission.PayloadTransmission<Sequence>withPayload(Sequence aValue)-
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
Methods inherited from interface org.refcodes.serial.Segment
fromTransmission, fromTransmission, fromTransmission, receiveFrom, receiveFrom
-
Methods inherited from interface org.refcodes.serial.Segment.SegmentMixin
receiveFrom
-
Methods inherited from interface org.refcodes.serial.Transmission
transmitTo, transmitTo
-
Methods inherited from interface org.refcodes.serial.Transmission.TransmissionMixin
transmitTo
-
-
-
-
Constructor Detail
-
FixedLengthSequenceSegment
public FixedLengthSequenceSegment(int aSequenceSize)
Constructs theFixedLengthSequenceSegment.- Parameters:
aSequenceSize- The size of theSequence.
-
FixedLengthSequenceSegment
public FixedLengthSequenceSegment(String aAlias, int aSequenceSize)
Constructs theFixedLengthSequenceSegment.
-
FixedLengthSequenceSegment
public FixedLengthSequenceSegment(Sequence aSequence)
Constructs theFixedLengthSequenceSegment.- Parameters:
aSequence- TheSequencerepresenting thisFixedLengthSequenceSegment.
-
FixedLengthSequenceSegment
public FixedLengthSequenceSegment(String aAlias, Sequence aSequence)
Constructs theFixedLengthSequenceSegment.- Parameters:
aAlias- The alias which identifies the content of thisSegment.aSequence- TheSequencerepresenting thisFixedLengthSequenceSegment.
-
-
Method Detail
-
getLength
public int getLength()
Determines the overall length of thisTransmission. In case of nestedTransmissioninstances, all length values from all sub-segments are accumulated to the result as well.- Specified by:
getLengthin interfaceorg.refcodes.mixin.LengthAccessor- Specified by:
getLengthin interfaceTransmission- Returns:
- The (overall) length of the
Transmission(including any sub-segments).
-
toSequence
public Sequence toSequence()
Provides theSequencerepresentation of thisTransmission. In case of nestedTransmissioninstances, allSequencerepresentations from all sub-segments are accumulated to the result as well. Caution, the Transmission (or its nestedTransmissioninstances) may be backed by the returnedSequence.- Specified by:
toSequencein interfaceTransmission- Returns:
- The according instance's
Sequence.
-
fromTransmission
public int fromTransmission(Sequence aSequence, int aOffset) throws TransmissionException
(Re-)initializes this instance with the the givenSequencedata.- Specified by:
fromTransmissionin interfaceSegment- Parameters:
aSequence- TheSequencedata from which to (re-)initialize this instance.aOffset- The offset where to start processing the providedSequence.- Returns:
- The index after the last offset into the given
Sequenceprocessed by this method. - Throws:
TransmissionException- thrown in case a givenSequencecannot be processed.
-
toSchema
public Schema toSchema()
Retrieves theSchemarepresenting theTransmission. Retrieving aSchemais useful when analyzing and debugging data structures such as aAllocSectionDecoratorSegmentinstance to help document, learn and verify on the structure (as well as the content) of that veryAllocSectionDecoratorSegment.- Specified by:
toSchemain interfaceTransmission- Returns:
- The
Schemarepresentation of the implementing type for debugging and verification (or documentation) purposes.
-
getAlias
public String getAlias()
- Specified by:
getAliasin interfaceorg.refcodes.mixin.AliasAccessor
-
withPayload
public PayloadTransmission<Sequence> withPayload(Sequence aValue)
- Specified by:
withPayloadin interfaceorg.refcodes.mixin.PayloadAccessor.PayloadBuilder<Sequence,PayloadTransmission<Sequence>>
-
getPayload
public Sequence getPayload()
- Specified by:
getPayloadin interfaceorg.refcodes.mixin.PayloadAccessor<Sequence>
-
setPayload
public void setPayload(Sequence aValue)
- Specified by:
setPayloadin interfaceorg.refcodes.mixin.PayloadAccessor.PayloadMutator<Sequence>
-
toSimpleTypeMap
public org.refcodes.struct.SimpleTypeMap toSimpleTypeMap()
Returns theSimpleTypeMaprepresentation of thisTransmission. In case this Transmission hasTransmissionchildren, then the children are queried as well and contained in the resultingSimpleTypeMap. The aliases of the accordingTransmissioninstances represent the resulting path to aTransmission's final simple type.- Specified by:
toSimpleTypeMapin interfaceTransmission- Returns:
- The
SimpleTypeMaprepresenting thisTransmissionand (if any) its children, with the according aliases forming the paths to theTransmission's values.
-
-