Class FixedSegmentArraySection<ARRAY extends Segment>
java.lang.Object
org.refcodes.serial.AbstractArrayTransmission<ARRAY>
org.refcodes.serial.FixedSegmentArraySection<ARRAY>
- Type Parameters:
ARRAY- The type of the array elements to be contained in this instance.
- All Implemented Interfaces:
Serializable, AliasAccessor, ArrayAccessor<ARRAY[]>, ArrayAccessor.ArrayBuilder<ARRAY[], ArrayTransmission<ARRAY>>, ArrayAccessor.ArrayMutator<ARRAY[]>, ArrayAccessor.ArrayProperty<ARRAY[]>, LengthAccessor, Resetable, Diagnosable, Schemable<DiagnosticOptions>, ArraySection<ARRAY>, ArrayTransmission<ARRAY>, Section, Section.SectionMixin, Transmission, Transmission.TransmissionMixin
public class FixedSegmentArraySection<ARRAY extends Segment>
extends AbstractArrayTransmission<ARRAY>
implements ArraySection<ARRAY>
A
FixedSegmentArraySection is a Section consisting of
Segment elements with each element of the same (uniform) length (in
contrast to the SegmentArraySection). When using the
FixedSegmentArraySection, it is to be taken care of the uniform
Segment elements' lengths.- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface AliasAccessor
AliasAccessor.AliasBuilder<B>, AliasAccessor.AliasMutator, AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface ArrayAccessor
ArrayAccessor.ArrayBuilder<T,B>, ArrayAccessor.ArrayMutator<T>, ArrayAccessor.ArrayProperty<T> Nested classes/interfaces inherited from interface LengthAccessor
LengthAccessor.LengthBuilder<B>, LengthAccessor.LengthMutator, LengthAccessor.LengthPropertyNested classes/interfaces inherited from interface Section
Section.SectionMixinNested classes/interfaces inherited from interface Transmission
Transmission.TransmissionMixin -
Field Summary
Fields inherited from class AbstractArrayTransmission
_alias, _array, _sequenceableFactory -
Constructor Summary
ConstructorsConstructorDescriptionFixedSegmentArraySection(ARRAY... aSegments) Instantiates the classFixedSegmentArraySection.FixedSegmentArraySection(Class<ARRAY> aSegmentClass) Instantiates the classFixedSegmentArraySection.FixedSegmentArraySection(String aAlias, ARRAY... aSegments) Instantiates the classFixedSegmentArraySection.FixedSegmentArraySection(String aAlias, Class<ARRAY> aSegmentClass) Instantiates the classFixedSegmentArraySection.FixedSegmentArraySection(String aAlias, Collection<ARRAY> aSegments) Instantiates the classFixedSegmentArraySection.FixedSegmentArraySection(String aAlias, TypeFactory<ARRAY> aSegmentFactory) Instantiates the classFixedSegmentArraySection.FixedSegmentArraySection(String aAlias, TypeFactory<ARRAY> aSegmentFactory, ARRAY... aSegments) Instantiates the classFixedSegmentArraySection.FixedSegmentArraySection(String aAlias, TypeFactory<ARRAY> aSegmentFactory, Collection<ARRAY> aSegments) Instantiates the classFixedSegmentArraySection.FixedSegmentArraySection(Collection<ARRAY> aSegments) Instantiates the classFixedSegmentArraySection.FixedSegmentArraySection(TypeFactory<ARRAY> aSegmentFactory) Instantiates the classFixedSegmentArraySection.FixedSegmentArraySection(TypeFactory<ARRAY> aSegmentFactory, ARRAY... aSegments) Instantiates the classFixedSegmentArraySection.FixedSegmentArraySection(TypeFactory<ARRAY> aSegmentFactory, Collection<ARRAY> aSegments) Instantiates the classFixedSegmentArraySection. -
Method Summary
Modifier and TypeMethodDescriptionvoidfromTransmission(Sequence aSequence, int aOffset, int aLength) (Re-)initializes this instance with the the givenSequencedata.Methods inherited from class AbstractArrayTransmission
getAlias, getArray, getLength, reset, setArray, toSchema, toStringMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface AliasAccessor
getAliasMethods inherited from interface ArrayAccessor
getArrayMethods inherited from interface ArrayAccessor.ArrayMutator
setArrayMethods inherited from interface ArrayAccessor.ArrayProperty
letArrayMethods inherited from interface ArrayTransmission
getLength, toSchema, toSequence, toSimpleTypeTableMethods inherited from interface Section
fromTransmission, fromTransmission, fromTransmission, receiveFrom, receiveFromMethods inherited from interface Section.SectionMixin
receiveFromMethods inherited from interface Transmission
reset, transmitTo, transmitToMethods inherited from interface Transmission.TransmissionMixin
transmitTo
-
Constructor Details
-
FixedSegmentArraySection
Instantiates the classFixedSegmentArraySection.- Parameters:
aSegmentClass- the segment class- See Also:
-
FixedSegmentArraySection
Instantiates the classFixedSegmentArraySection.- Parameters:
aSegments- the segments- See Also:
-
FixedSegmentArraySection
Instantiates the classFixedSegmentArraySection.- Parameters:
aSegments- the segments- See Also:
-
FixedSegmentArraySection
Instantiates the classFixedSegmentArraySection.- Parameters:
aAlias- the aliasaSegmentClass- the segment class- See Also:
-
FixedSegmentArraySection
Instantiates the classFixedSegmentArraySection.- Parameters:
aAlias- the aliasaSegments- the segments- See Also:
-
FixedSegmentArraySection
Instantiates the classFixedSegmentArraySection.- Parameters:
aAlias- the aliasaSegments- the segments- See Also:
-
FixedSegmentArraySection
public FixedSegmentArraySection(String aAlias, TypeFactory<ARRAY> aSegmentFactory, Collection<ARRAY> aSegments) Instantiates the classFixedSegmentArraySection.- Parameters:
aAlias- the aliasaSegmentFactory- the segment factoryaSegments- the segments- See Also:
-
FixedSegmentArraySection
@SafeVarargs public FixedSegmentArraySection(String aAlias, TypeFactory<ARRAY> aSegmentFactory, ARRAY... aSegments) Instantiates the classFixedSegmentArraySection.- Parameters:
aAlias- the aliasaSegmentFactory- the segment factoryaSegments- the segments- See Also:
-
FixedSegmentArraySection
Instantiates the classFixedSegmentArraySection.- Parameters:
aAlias- the aliasaSegmentFactory- the segment factory- See Also:
-
FixedSegmentArraySection
Instantiates the classFixedSegmentArraySection.- Parameters:
aSegmentFactory- the segment factoryaSegments- the segments- See Also:
-
FixedSegmentArraySection
@SafeVarargs public FixedSegmentArraySection(TypeFactory<ARRAY> aSegmentFactory, ARRAY... aSegments) Instantiates the classFixedSegmentArraySection.- Parameters:
aSegmentFactory- the segment factoryaSegments- the segments- See Also:
-
FixedSegmentArraySection
Instantiates the classFixedSegmentArraySection.- Parameters:
aSegmentFactory- the segment factory- See Also:
-
-
Method Details
-
withArray
- Specified by:
withArrayin interfaceArrayAccessor.ArrayBuilder<ARRAY extends Segment[], ArrayTransmission<ARRAY extends Segment>>- Overrides:
withArrayin classAbstractArrayTransmission<ARRAY extends Segment>
-
fromTransmission
public void fromTransmission(Sequence aSequence, int aOffset, int aLength) throws TransmissionException (Re-)initializes this instance with the the givenSequencedata.- Specified by:
fromTransmissionin interfaceSection- Parameters:
aSequence- TheSequencedata from which to (re-)initialize this instance.aOffset- The offset where to start processing the providedSequence.aLength- The length of data assigned by theSequence.- Throws:
TransmissionException- thrown in case a givenSequencecannot be processed.
-