Class FloatArraySection
java.lang.Object
org.refcodes.serial.AbstractPayloadSection<float[]>
org.refcodes.serial.FloatArraySection
- All Implemented Interfaces:
Serializable, AliasAccessor, LengthAccessor, PayloadAccessor<float[]>, PayloadAccessor.PayloadBuilder<float[], PayloadTransmission<float[]>>, PayloadAccessor.PayloadMutator<float[]>, PayloadAccessor.PayloadProperty<float[]>, Resetable, Diagnosable, Schemable<DiagnosticOptions>, PayloadSection<float[]>, PayloadTransmission<float[]>, Section, Section.SectionMixin, Transmission, Transmission.TransmissionMixin
The
FloatArraySection is an implementation of a Section
carrying a float array as payload.- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface AliasAccessor
AliasAccessor.AliasBuilder<B>, AliasAccessor.AliasMutator, AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface LengthAccessor
LengthAccessor.LengthBuilder<B>, LengthAccessor.LengthMutator, LengthAccessor.LengthPropertyNested classes/interfaces inherited from interface PayloadAccessor
PayloadAccessor.PayloadBuilder<P,B>, PayloadAccessor.PayloadMutator<P>, PayloadAccessor.PayloadProperty<P> Nested classes/interfaces inherited from interface Section
Section.SectionMixinNested classes/interfaces inherited from interface Transmission
Transmission.TransmissionMixin -
Field Summary
Fields inherited from class AbstractPayloadSection
_alias, _payload -
Constructor Summary
ConstructorsConstructorDescriptionConstructs an emptyFloatArraySectionwith aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theSection's value.FloatArraySection(float... aValue) Constructs aFloatArraySectionwith the given float array payload and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theSection's value.FloatArraySection(Float... aValue) Constructs aFloatArraySectionwith the given float array payload and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theSection's value.FloatArraySection(String aAlias) Constructs an emptyFloatArraySectionwith aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theSection's value.FloatArraySection(String aAlias, float... aValue) Constructs aFloatArraySectionwith the given float array payload and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theSection's value.FloatArraySection(String aAlias, Float... aValue) Constructs aFloatArraySectionwith the given float array payload and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theSection's value.FloatArraySection(String aAlias, Endianess aEndianess) Constructs an emptyFloatArraySectionwith the givenEndianess.FloatArraySection(String aAlias, Endianess aEndianess, float... aValue) Constructs aFloatArraySectionwith the given float array payload andEndianessfor the representation of theSection's value.FloatArraySection(String aAlias, Endianess aEndianess, Float... aValue) Constructs aFloatArraySectionwith the given float array payload andEndianessfor the representation of theSection's value.FloatArraySection(String aAlias, TransmissionMetrics aTransmissionMetrics) Constructs an according instance from the given configuration.FloatArraySection(String aAlias, TransmissionMetrics aTransmissionMetrics, float... aValue) Constructs an according instance from the given configuration.FloatArraySection(String aAlias, TransmissionMetrics aTransmissionMetrics, Float... aValue) Constructs an according instance from the given configuration.FloatArraySection(Endianess aEndianess) Constructs an emptyFloatArraySectionwith the givenEndianess.FloatArraySection(Endianess aEndianess, float... aValue) Constructs aFloatArraySectionwith the given float array payload andEndianessfor the representation of theSection's value.FloatArraySection(Endianess aEndianess, Float... aValue) Constructs aFloatArraySectionwith the given float array payload andEndianessfor the representation of theSection's value.FloatArraySection(TransmissionMetrics aTransmissionMetrics) Constructs an according instance from the given configuration.FloatArraySection(TransmissionMetrics aTransmissionMetrics, float... aValue) Constructs an according instance from the given configuration.FloatArraySection(TransmissionMetrics aTransmissionMetrics, Float... aValue) Constructs an according instance from the given configuration. -
Method Summary
Modifier and TypeMethodDescriptionvoidfromTransmission(Sequence aSequence, int aOffset, int aLength) (Re-)initializes this instance with the the givenSequencedata.intDetermines the overall length of thisTransmission.voidsetPayload(Float[] aPayload) Convenience method to convert the array of wrapper types into its counterpart with primitive types before invokingAbstractPayloadSection.setPayload(Object).toSchema()Provides theSequencerepresentation of thisTransmission.toString()withPayload(float[] aValue) withPayload(Float[] aPayload) Convenience method to convert the array of wrapper types into its counterpart with primitive types before invokingwithPayload(float[]).Methods inherited from class AbstractPayloadSection
equals, getAlias, getPayload, hashCode, reset, setPayload, toSimpleTypeTableMethods inherited from interface PayloadAccessor
getPayloadOrMethods inherited from interface PayloadAccessor.PayloadProperty
letPayloadMethods inherited from interface Section
fromTransmission, fromTransmission, fromTransmission, receiveFrom, receiveFromMethods inherited from interface Section.SectionMixin
receiveFromMethods inherited from interface Transmission
transmitTo, transmitToMethods inherited from interface Transmission.TransmissionMixin
transmitTo
-
Constructor Details
-
FloatArraySection
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.
-
FloatArraySection
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.aValue- The payload to be contained by theFloatArraySection.
-
FloatArraySection
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.aValue- The payload to be contained by theFloatArraySection.
-
FloatArraySection
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aAlias- The alias which identifies the content of this instance.aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.
-
FloatArraySection
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aAlias- The alias which identifies the content of this instance.aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.aValue- The payload to be contained by theFloatArraySection.
-
FloatArraySection
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aAlias- The alias which identifies the content of this instance.aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.aValue- The payload to be contained by theFloatArraySection.
-
FloatArraySection
public FloatArraySection()Constructs an emptyFloatArraySectionwith aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theSection's value. -
FloatArraySection
Constructs an emptyFloatArraySectionwith the givenEndianess.- Parameters:
aEndianess- TheEndianessto be used for payload values.
-
FloatArraySection
public FloatArraySection(float... aValue) Constructs aFloatArraySectionwith the given float array payload and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theSection's value.- Parameters:
aValue- The payload to be contained by theSection.
-
FloatArraySection
Constructs aFloatArraySectionwith the given float array payload and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theSection's value.- Parameters:
aValue- The payload to be contained by theSection.
-
FloatArraySection
Constructs aFloatArraySectionwith the given float array payload andEndianessfor the representation of theSection's value. -
FloatArraySection
Constructs aFloatArraySectionwith the given float array payload andEndianessfor the representation of theSection's value. -
FloatArraySection
Constructs an emptyFloatArraySectionwith aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theSection's value.- Parameters:
aAlias- The alias which identifies the content of this segment.
-
FloatArraySection
Constructs an emptyFloatArraySectionwith the givenEndianess.- Parameters:
aAlias- The alias which identifies the content of this segment.aEndianess- TheEndianessto be used for payload values.
-
FloatArraySection
Constructs aFloatArraySectionwith the given float array payload and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theSection's value.- Parameters:
aAlias- The alias which identifies the content of this segment.aValue- The payload to be contained by theSection.
-
FloatArraySection
Constructs aFloatArraySectionwith the given float array payload and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theSection's value.- Parameters:
aAlias- The alias which identifies the content of this segment.aValue- The payload to be contained by theSection.
-
FloatArraySection
Constructs aFloatArraySectionwith the given float array payload andEndianessfor the representation of theSection's value. -
FloatArraySection
Constructs aFloatArraySectionwith the given float array payload andEndianessfor the representation of theSection's value.
-
-
Method Details
-
toSequence
Provides theSequencerepresentation of thisTransmission. In case of nestedTransmissioninstances, allSequencerepresentations from all sub-segments are accumulated to the result as well. Caution, the Transmission (or its nestedTransmissioninstances) may be backed by the returnedSequence.- Returns:
- The according instance's
Sequence.
-
fromTransmission
public void fromTransmission(Sequence aSequence, int aOffset, int aLength) throws TransmissionException (Re-)initializes this instance with the the givenSequencedata.- Parameters:
aSequence- TheSequencedata from which to (re-)initialize this instance.aOffset- The offset where to start processing the providedSequence.aLength- The length of data assigned by theSequence.- Throws:
TransmissionException- thrown in case a givenSequencecannot be processed.
-
getLength
public int getLength()Determines the overall length of thisTransmission. In case of nestedTransmissioninstances, all length values from all sub-segments are accumulated to the result as well.- Returns:
- The (overall) length of the
Transmission(including any sub-segments).
-
toSchema
-
toString
- Overrides:
toStringin classAbstractPayloadSection<float[]>
-
withPayload
-
setPayload
Convenience method to convert the array of wrapper types into its counterpart with primitive types before invokingAbstractPayloadSection.setPayload(Object).- Parameters:
aPayload- The payload with the wrapper types.
-
withPayload
Convenience method to convert the array of wrapper types into its counterpart with primitive types before invokingwithPayload(float[]).- Parameters:
aPayload- The payload with the wrapper types.- Returns:
- This instance as of the builder pattern.
-