Class FlowControlRetryException
- All Implemented Interfaces:
Serializable, ErrorCodeAccessor, Trap, RetryNumberAccessor, TimeoutMillisAccessor
public class FlowControlRetryException
extends FlowControlTimeoutException
implements RetryNumberAccessor
Thrown in case a flow control failed due t a timeout.
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface ErrorCodeAccessor
ErrorCodeAccessor.ErrorCodeBuilder<B>, ErrorCodeAccessor.ErrorCodeMutator, ErrorCodeAccessor.ErrorCodePropertyNested classes/interfaces inherited from interface RetryNumberAccessor
RetryNumberAccessor.RetryNumberBuilder<B>, RetryNumberAccessor.RetryNumberMutator, RetryNumberAccessor.RetryNumberPropertyNested classes/interfaces inherited from interface TimeoutMillisAccessor
TimeoutMillisAccessor.TimeoutMillisBuilder<B>, TimeoutMillisAccessor.TimeoutMillisMutator, TimeoutMillisAccessor.TimeoutMillisProperty -
Constructor Summary
ConstructorsConstructorDescriptionFlowControlRetryException(int aRetryNumber, long aTimeoutMillis, String aMessage) Instantiates the classFlowControlRetryException.FlowControlRetryException(int aRetryNumber, long aTimeoutMillis, String aMessage, String aErrorCode) Instantiates the classFlowControlRetryException.FlowControlRetryException(int aRetryNumber, long aTimeoutMillis, String aMessage, Throwable aCause) Instantiates the classFlowControlRetryException.FlowControlRetryException(int aRetryNumber, long aTimeoutMillis, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classFlowControlRetryException.FlowControlRetryException(int aRetryNumber, long aTimeoutMillis, Throwable aCause) Instantiates the classFlowControlRetryException.FlowControlRetryException(int aRetryNumber, long aTimeoutMillis, Throwable aCause, String aErrorCode) Instantiates the classFlowControlRetryException. -
Method Summary
Methods inherited from class FlowControlTimeoutException
getTimeoutMillisMethods inherited from class AbstractIOException
getErrorCodeMethods inherited from class Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface Trap
getPatternArguments, toLocalizedMessage, toMessage, toMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
FlowControlRetryException
public FlowControlRetryException(int aRetryNumber, long aTimeoutMillis, String aMessage, String aErrorCode) Instantiates the classFlowControlRetryException.- Parameters:
aRetryNumber- The number of retries after which the exception occurred.aTimeoutMillis- the timeout millisaMessage- the messageaErrorCode- the error code- See Also:
-
FlowControlRetryException
public FlowControlRetryException(int aRetryNumber, long aTimeoutMillis, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classFlowControlRetryException.- Parameters:
aRetryNumber- The number of retries after which the exception occurred.aTimeoutMillis- the timeout millisaMessage- the messageaCause- the causeaErrorCode- the error code- See Also:
-
FlowControlRetryException
public FlowControlRetryException(int aRetryNumber, long aTimeoutMillis, String aMessage, Throwable aCause) Instantiates the classFlowControlRetryException.- Parameters:
aRetryNumber- The number of retries after which the exception occurred.aTimeoutMillis- the timeout millisaMessage- the messageaCause- the cause- See Also:
-
FlowControlRetryException
Instantiates the classFlowControlRetryException.- Parameters:
aRetryNumber- The number of retries after which the exception occurred.aTimeoutMillis- the timeout millisaMessage- the message- See Also:
-
FlowControlRetryException
public FlowControlRetryException(int aRetryNumber, long aTimeoutMillis, Throwable aCause, String aErrorCode) Instantiates the classFlowControlRetryException.- Parameters:
aRetryNumber- The number of retries after which the exception occurred.aTimeoutMillis- the timeout millisaCause- the causeaErrorCode- the error code- See Also:
-
FlowControlRetryException
Instantiates the classFlowControlRetryException.- Parameters:
aRetryNumber- The number of retries after which the exception occurred.aTimeoutMillis- the timeout millisaCause- the cause- See Also:
-
-
Method Details
-
getRetryNumber
public int getRetryNumber()The timeout attribute in milliseconds.- Specified by:
getRetryNumberin interfaceRetryNumberAccessor- Returns:
- An long integer with the timeout in milliseconds.
-