-
- All Known Subinterfaces:
HandshakeMagicBytesAccessor.HandshakeMagicBytesProperty
public interface HandshakeMagicBytesAccessorProvides an accessor for a handshake magic bytes property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceHandshakeMagicBytesAccessor.HandshakeMagicBytesBuilder<B extends HandshakeMagicBytesAccessor.HandshakeMagicBytesBuilder<B>>Provides a builder method for a handshake magic bytes property returning the builder for applying multiple build operations.static interfaceHandshakeMagicBytesAccessor.HandshakeMagicBytesMutatorProvides a mutator for a handshake magic bytes property.static interfaceHandshakeMagicBytesAccessor.HandshakeMagicBytesPropertyProvides a handshake magic bytes property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description byte[]getHandshakeMagicBytes()Retrieves the magic bytes from the handshake magic bytes property.
-