Interface HandshakeMagicBytesAccessor.HandshakeMagicBytesMutator

    • Method Detail

      • setHandshakeMagicBytes

        void setHandshakeMagicBytes​(byte[] aHandshakeMagicBytes)
        Sets the magic bytes for the handshake magic bytes property.
        Parameters:
        aHandshakeMagicBytes - The magic bytes to be stored by the handshake magic bytes property.
      • setHandshakeMagicBytes

        default void setHandshakeMagicBytes​(String aHandshakeMagicBytes)
        Sets the magic bytes for the handshake magic bytes property. Uses TransmissionMetrics.DEFAULT_ENCODING for converting the String into a byte array.
        Parameters:
        aHandshakeMagicBytes - The magic bytes to be stored by the magic bytes property.
      • setHandshakeMagicBytes

        default void setHandshakeMagicBytes​(String aHandshakeMagicBytes,
                                            Charset aEncoding)
        Sets the magic bytes for the handshake magic bytes property.
        Parameters:
        aHandshakeMagicBytes - The magic bytes to be stored by the magic bytes property.
        aEncoding - The string's bytes are converted using the given Charset.