Enum HandshakeProtocol

java.lang.Object
java.lang.Enum<HandshakeProtocol>
org.refcodes.serial.HandshakeProtocol
All Implemented Interfaces:
Serializable, Comparable<HandshakeProtocol>, java.lang.constant.Constable

public enum HandshakeProtocol extends Enum<HandshakeProtocol>
Enumeration with the various protocol settings when receiving a transmission. A transmission may require an acknowledge handshake for a transmission.
  • Enum Constant Details

    • NO_ACKNOWLEDGE

      public static final HandshakeProtocol NO_ACKNOWLEDGE
      No CRC error detection and no acknowledge handshake.
    • REQUEST_FOR_ACKNOWLEDGE

      public static final HandshakeProtocol REQUEST_FOR_ACKNOWLEDGE
      No CRC error detection but acknowledge handshake.
  • Method Details

    • values

      public static HandshakeProtocol[] values()
      Returns an array containing the constants of this enum type, in the order they are declared.
      Returns:
      an array containing the constants of this enum type, in the order they are declared
    • valueOf

      public static HandshakeProtocol valueOf(String name)
      Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum type has no constant with the specified name
      NullPointerException - if the argument is null
    • isAcknowledge

      public boolean isAcknowledge()
      Determines whether an acknowledge handshake is to be established upon receival of a transmission.
      Returns:
      True in case of an acknowledge handshake.