Class LongArraySection
java.lang.Object
org.refcodes.serial.AbstractPayloadSection<long[]>
org.refcodes.serial.LongArraySection
- All Implemented Interfaces:
Serializable, AliasAccessor, LengthAccessor, PayloadAccessor<long[]>, PayloadAccessor.PayloadBuilder<long[], PayloadTransmission<long[]>>, PayloadAccessor.PayloadMutator<long[]>, PayloadAccessor.PayloadProperty<long[]>, Resetable, Diagnosable, Schemable<DiagnosticOptions>, PayloadSection<long[]>, PayloadTransmission<long[]>, Section, Section.SectionMixin, Transmission, Transmission.TransmissionMixin
The
LongArraySection is an implementation of a Section
carrying a long array as payload.- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface AliasAccessor
AliasAccessor.AliasBuilder<B>, AliasAccessor.AliasMutator, AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface LengthAccessor
LengthAccessor.LengthBuilder<B>, LengthAccessor.LengthMutator, LengthAccessor.LengthPropertyNested classes/interfaces inherited from interface PayloadAccessor
PayloadAccessor.PayloadBuilder<P,B>, PayloadAccessor.PayloadMutator<P>, PayloadAccessor.PayloadProperty<P> Nested classes/interfaces inherited from interface Section
Section.SectionMixinNested classes/interfaces inherited from interface Transmission
Transmission.TransmissionMixin -
Field Summary
Fields inherited from class AbstractPayloadSection
_alias, _payload -
Constructor Summary
ConstructorsConstructorDescriptionConstructs an emptyLongArraySectionwith aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theLongArraySection's value.LongArraySection(long... aValue) Constructs aLongArraySectionwith the given long array payload and the given aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theLongArraySection's value.LongArraySection(Long... aValue) Constructs aLongArraySectionwith the given long array payload and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theLongArraySection's value.LongArraySection(String aAlias) Constructs an emptyLongArraySectionwith aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theLongArraySection's value.LongArraySection(String aAlias, long... aValue) Constructs aLongArraySectionwith the given long array payload and the given aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theLongArraySection's value.LongArraySection(String aAlias, Long... aValue) Constructs aLongArraySectionwith the given long array payload and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theLongArraySection's value.LongArraySection(String aAlias, Endianess aEndianess) Constructs an emptyLongArraySectionwith the givenEndianess.LongArraySection(String aAlias, Endianess aEndianess, long... aValue) Constructs aLongArraySectionwith the given long array payload and the givenEndianessfor the representation of theLongArraySection's value.LongArraySection(String aAlias, Endianess aEndianess, Long... aValue) Constructs aLongArraySectionwith the given long array payload and the givenEndianessfor the representation of theLongArraySection's value.LongArraySection(String aAlias, TransmissionMetrics aTransmissionMetrics) Constructs an according instance from the given configuration.LongArraySection(String aAlias, TransmissionMetrics aTransmissionMetrics, long... aValue) Constructs an according instance from the given configuration.LongArraySection(String aAlias, TransmissionMetrics aTransmissionMetrics, Long... aValue) Constructs an according instance from the given configuration.LongArraySection(Endianess aEndianess) Constructs an emptyLongArraySectionwith the givenEndianess.LongArraySection(Endianess aEndianess, long... aValue) Constructs aLongArraySectionwith the given long array payload and the givenEndianessfor the representation of theLongArraySection's value.LongArraySection(Endianess aEndianess, Long... aValue) Constructs aLongArraySectionwith the given long array payload and the givenEndianessfor the representation of theLongArraySection's value.LongArraySection(TransmissionMetrics aTransmissionMetrics) Constructs an according instance from the given configuration.LongArraySection(TransmissionMetrics aTransmissionMetrics, long... aValue) Constructs an according instance from the given configuration.LongArraySection(TransmissionMetrics aTransmissionMetrics, Long... aValue) Constructs an according instance from the given configuration. -
Method Summary
Modifier and TypeMethodDescriptionvoidfromTransmission(Sequence aSequence, int aOffset, int aLength) (Re-)initializes this instance with the the givenSequencedata.intDetermines the overall length of thisTransmission.voidsetPayload(Long[] aPayload) Convenience method to convert the array of wrapper types into its counterpart with primitive types before invokingAbstractPayloadSection.setPayload(Object).toSchema()Provides theSequencerepresentation of thisTransmission.toString()withPayload(long[] aValue) withPayload(Long[] aPayload) Convenience method to convert the array of wrapper types into its counterpart with primitive types before invokingwithPayload(long[]).Methods inherited from class AbstractPayloadSection
equals, getAlias, getPayload, hashCode, reset, setPayload, toSimpleTypeTableMethods inherited from interface PayloadAccessor
getPayloadOrMethods inherited from interface PayloadAccessor.PayloadProperty
letPayloadMethods inherited from interface Section
fromTransmission, fromTransmission, fromTransmission, receiveFrom, receiveFromMethods inherited from interface Section.SectionMixin
receiveFromMethods inherited from interface Transmission
transmitTo, transmitToMethods inherited from interface Transmission.TransmissionMixin
transmitTo
-
Constructor Details
-
LongArraySection
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.
-
LongArraySection
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.aValue- The payload to be contained by theLongArraySection.
-
LongArraySection
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.aValue- The payload to be contained by theLongArraySection.
-
LongArraySection
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aAlias- The alias which identifies the content of this instance.aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.
-
LongArraySection
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aAlias- The alias which identifies the content of this instance.aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.aValue- The payload to be contained by theLongArraySection.
-
LongArraySection
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aAlias- The alias which identifies the content of this instance.aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.aValue- The payload to be contained by theLongArraySection.
-
LongArraySection
public LongArraySection()Constructs an emptyLongArraySectionwith aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theLongArraySection's value. -
LongArraySection
Constructs an emptyLongArraySectionwith the givenEndianess.- Parameters:
aEndianess- TheEndianessto be used for payload values.
-
LongArraySection
public LongArraySection(long... aValue) Constructs aLongArraySectionwith the given long array payload and the given aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theLongArraySection's value.- Parameters:
aValue- The payload to be contained by theLongArraySection.
-
LongArraySection
Constructs aLongArraySectionwith the given long array payload and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theLongArraySection's value.- Parameters:
aValue- The payload to be contained by theLongArraySection.
-
LongArraySection
Constructs aLongArraySectionwith the given long array payload and the givenEndianessfor the representation of theLongArraySection's value.- Parameters:
aEndianess- TheEndianessto be used for payload values.aValue- The payload to be contained by theLongArraySection.
-
LongArraySection
Constructs aLongArraySectionwith the given long array payload and the givenEndianessfor the representation of theLongArraySection's value.- Parameters:
aEndianess- TheEndianessto be used for payload values.aValue- The payload to be contained by theLongArraySection.
-
LongArraySection
Constructs an emptyLongArraySectionwith aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theLongArraySection's value.- Parameters:
aAlias- The alias which identifies the content of this segment.
-
LongArraySection
Constructs an emptyLongArraySectionwith the givenEndianess.- Parameters:
aAlias- The alias which identifies the content of this segment.aEndianess- TheEndianessto be used for payload values.
-
LongArraySection
Constructs aLongArraySectionwith the given long array payload and the given aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theLongArraySection's value.- Parameters:
aAlias- The alias which identifies the content of this segment.aValue- The payload to be contained by theLongArraySection.
-
LongArraySection
Constructs aLongArraySectionwith the given long array payload and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theLongArraySection's value.- Parameters:
aAlias- The alias which identifies the content of this segment.aValue- The payload to be contained by theLongArraySection.
-
LongArraySection
Constructs aLongArraySectionwith the given long array payload and the givenEndianessfor the representation of theLongArraySection's value.- Parameters:
aAlias- The alias which identifies the content of this segment.aEndianess- TheEndianessto be used for payload values.aValue- The payload to be contained by theLongArraySection.
-
LongArraySection
Constructs aLongArraySectionwith the given long array payload and the givenEndianessfor the representation of theLongArraySection's value.- Parameters:
aAlias- The alias which identifies the content of this segment.aEndianess- TheEndianessto be used for payload values.aValue- The payload to be contained by theLongArraySection.
-
-
Method Details
-
toSequence
Provides theSequencerepresentation of thisTransmission. In case of nestedTransmissioninstances, allSequencerepresentations from all sub-segments are accumulated to the result as well. Caution, the Transmission (or its nestedTransmissioninstances) may be backed by the returnedSequence.- Returns:
- The according instance's
Sequence.
-
fromTransmission
public void fromTransmission(Sequence aSequence, int aOffset, int aLength) throws TransmissionException (Re-)initializes this instance with the the givenSequencedata.- Parameters:
aSequence- TheSequencedata from which to (re-)initialize this instance.aOffset- The offset where to start processing the providedSequence.aLength- The length of data assigned by theSequence.- Throws:
TransmissionException- thrown in case a givenSequencecannot be processed.
-
getLength
public int getLength()Determines the overall length of thisTransmission. In case of nestedTransmissioninstances, all length values from all sub-segments are accumulated to the result as well.- Returns:
- The (overall) length of the
Transmission(including any sub-segments).
-
toSchema
-
toString
- Overrides:
toStringin classAbstractPayloadSection<long[]>
-
withPayload
-
setPayload
Convenience method to convert the array of wrapper types into its counterpart with primitive types before invokingAbstractPayloadSection.setPayload(Object).- Parameters:
aPayload- The payload with the wrapper types.
-
withPayload
Convenience method to convert the array of wrapper types into its counterpart with primitive types before invokingwithPayload(long[]).- Parameters:
aPayload- The payload with the wrapper types.- Returns:
- This instance as of the builder pattern.
-