Class LoopbackPort

All Implemented Interfaces:
Flushable, Comparable<Port<?>>, Closable, Closable.CloseAutomaton, ClosedAccessor, ConnectableComponent, ConnectableComponent.ConnectableAutomaton, ConnectionComponent<PortMetrics>, ConnectionComponent.ConnectionAutomaton<PortMetrics>, ConnectionOpenable<PortMetrics>, ConnectionOpenable.ConnectionOpenAutomaton<PortMetrics>, ConnectionOpenable.ConnectionOpenBuilder<PortMetrics, Port<PortMetrics>>, ConnectionStatusAccessor, Flushable, LinkComponent, LinkComponent.LinkAutomaton, Openable, Openable.OpenAutomaton, Openable.OpenBuilder<Port<PortMetrics>>, OpenedAccessor, Availability, ByteDestination, ByteReceiver, BytesDestination, ByteSource, BytesReceiver, BytesSource, BytesTransceiver, BytesTransmitter, ByteTransceiver, ByteTransmitter, Receivable, Skippable, TimeoutInputStreamAccessor, Transmittable, AliasAccessor, InputStreamAccessor, OutputStreamAccessor, Port<PortMetrics>, PortMetricsAccessor<PortMetrics>, SegmentDestination, SegmentReceiver, SegmentSource, SegmentTransceiver, SegmentTransmitter, SerialReceiver, SerialTransceiver, SerialTransmitter
Direct Known Subclasses:
CrossoverLoopbackPort

public class LoopbackPort extends AbstractPort<PortMetrics>
The LoopbackPort is an in-memory implementation of a Port which loops its output directly back to its input. This is suitable for straight forward cases where data is first transmitted to be received in the next step by the same Port. For cases using a some kind of frequent handshake between a transmitter and a receiver on the same line please use the CrossoverLoopbackPort as counterpart of a LoopbackPort for simulating a bidirectional in-memory communication between these two ports.