-
- All Superinterfaces:
org.refcodes.mixin.MagicBytesAccessor
- All Known Subinterfaces:
MagicBytesAccessor.MagicBytesProperty
- All Known Implementing Classes:
AbstractMagicBytesTransmission,AbstractMagicBytesTransmissionDecorator,AssertMagicBytesSectionDecorator,AssertMagicBytesSegment,AssertMagicBytesSegmentDecorator,BadMagicBytesException,BadMagicBytesSequenceException,MagicBytes,MagicBytesSectionDecorator,MagicBytesSegment,MagicBytesSegmentDecorator
public interface MagicBytesAccessor extends org.refcodes.mixin.MagicBytesAccessorProvides an accessor for a magic byte array property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceMagicBytesAccessor.MagicBytesBuilder<B extends MagicBytesAccessor.MagicBytesBuilder<B>>Provides a builder method for a magic byte array property returning the builder for applying multiple build operations.static interfaceMagicBytesAccessor.MagicBytesMutatorProvides a mutator for a magic byte array property.static interfaceMagicBytesAccessor.MagicBytesPropertyProvides a magic byte array property.
-
Method Summary
All Methods Instance Methods Default Methods Modifier and Type Method Description default StringtoMagicBytes()Returns the magic bytes (as ofMagicBytesAccessor.getMagicBytes())Stringbeing UTF-8 encoded.default StringtoMagicBytes(Charset aCharset)Returns the magic bytes (as ofMagicBytesAccessor.getMagicBytes()) as an accordingly encodedString.
-