Interface MagicBytesLengthAccessor
- All Known Subinterfaces:
MagicBytesLengthAccessor.MagicBytesLengthProperty
- All Known Implementing Classes:
AbstractMagicBytesTransmission, AbstractMagicBytesTransmissionDecorator, AssertMagicBytesSectionDecorator, AssertMagicBytesSegment, AssertMagicBytesSegmentDecorator, MagicBytesSectionDecorator, MagicBytesSegment, MagicBytesSegmentDecorator, TransmissionMetrics
public interface MagicBytesLengthAccessor
Provides an accessor for a magic bytes length property.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceMagicBytesLengthAccessor.MagicBytesLengthBuilder<B extends MagicBytesLengthAccessor.MagicBytesLengthBuilder<B>>Provides a builder method for a magic bytes length property returning the builder for applying multiple build operations.static interfaceProvides a mutator for a magic bytes length property.static interfaceProvides a magic bytes length property. -
Method Summary
Modifier and TypeMethodDescriptionintRetrieves the magic bytes length from the magic bytes magic bytes length property.
-
Method Details
-
getMagicBytesLength
int getMagicBytesLength()Retrieves the magic bytes length from the magic bytes magic bytes length property.- Returns:
- The magic bytes length stored by the magic bytes magic bytes length property.
-