Module org.refcodes.serial
Package org.refcodes.serial
Interface MagicBytesLengthAccessor.MagicBytesLengthMutator
-
- All Known Subinterfaces:
MagicBytesLengthAccessor.MagicBytesLengthProperty
- Enclosing interface:
- MagicBytesLengthAccessor
public static interface MagicBytesLengthAccessor.MagicBytesLengthMutatorProvides a mutator for a magic bytes length property.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description voidsetMagicBytesLength(int aMagicBytesLength)Sets the magic bytes length for the magic bytes magic bytes length property.
-