Class NumberSegment

All Implemented Interfaces:
Serializable, AliasAccessor, LengthAccessor, PayloadAccessor<Long>, PayloadAccessor.PayloadBuilder<Long, PayloadTransmission<Long>>, PayloadAccessor.PayloadMutator<Long>, PayloadAccessor.PayloadProperty<Long>, Resetable, ValueAccessor<Long>, ValueAccessor.ValueBuilder<Long, NumberSegment>, ValueAccessor.ValueMutator<Long>, ValueAccessor.ValueProperty<Long>, Diagnosable, Schemable<DiagnosticOptions>, PayloadSegment<Long>, PayloadTransmission<Long>, Segment, Segment.SegmentMixin, Transmission, Transmission.TransmissionMixin
Direct Known Subclasses:
SequenceNumberSegment

The NumberSegment is an implementation of a Segment carrying an integer value with a configurable width (in bytes) as payload.
See Also:
  • Constructor Details

    • NumberSegment

      public NumberSegment(int aNumberWidth, TransmissionMetrics aTransmissionMetrics)
      Constructs an according instance from the given configuration. The configuration attributes are taken from the TransmissionMetrics configuration object, though only those attributes are supported which are also supported by the other constructors!
      Parameters:
      aNumberWidth - The number of bytes to be occupied by the number.
      aTransmissionMetrics - The TransmissionMetrics to be used for configuring this instance.
    • NumberSegment

      public NumberSegment(int aNumberWidth, Long aValue, TransmissionMetrics aTransmissionMetrics)
      Constructs an according instance from the given configuration. The configuration attributes are taken from the TransmissionMetrics configuration object, though only those attributes are supported which are also supported by the other constructors!
      Parameters:
      aNumberWidth - The number of bytes to be occupied by the number.
      aValue - The payload to be contained by the DoubleArraySection.
      aTransmissionMetrics - The TransmissionMetrics to be used for configuring this instance.
    • NumberSegment

      public NumberSegment(String aAlias, int aNumberWidth, TransmissionMetrics aTransmissionMetrics)
      Constructs an according instance from the given configuration. The configuration attributes are taken from the TransmissionMetrics configuration object, though only those attributes are supported which are also supported by the other constructors!
      Parameters:
      aAlias - The alias which identifies the content of this instance.
      aNumberWidth - The number of bytes to be occupied by the number.
      aTransmissionMetrics - The TransmissionMetrics to be used for configuring this instance.
    • NumberSegment

      public NumberSegment(int aNumberWidth)
      Constructs an empty NumberSegment with a TransmissionMetrics.DEFAULT_ENDIANESS endian representation of the NumberSegment's value.
      Parameters:
      aNumberWidth - The number of bytes to be occupied by the number.
    • NumberSegment

      public NumberSegment(int aNumberWidth, Endianess aEndianess)
      Constructs an empty NumberSegment with the given Endianess.
      Parameters:
      aNumberWidth - The number of bytes to be occupied by the number.
      aEndianess - The Endianess to be used for payload values.
    • NumberSegment

      public NumberSegment(int aNumberWidth, Long aValue)
      Constructs a NumberSegment with the given long payload and a TransmissionMetrics.DEFAULT_ENDIANESS endian representation of the NumberSegment's value.
      Parameters:
      aNumberWidth - The number of bytes to be occupied by the number.
      aValue - The payload to be contained by the NumberSegment.
    • NumberSegment

      public NumberSegment(int aNumberWidth, Long aValue, Endianess aEndianess)
      Constructs a NumberSegment with the given long payload and the given Endianess for the representation of the NumberSegment's value (payload).
      Parameters:
      aNumberWidth - The number of bytes to be occupied by the number.
      aValue - The value (payload) to be contained by the NumberSegment.
      aEndianess - The Endianess to be used for payload values.
    • NumberSegment

      public NumberSegment(String aAlias, int aNumberWidth)
      Constructs an empty NumberSegment with a TransmissionMetrics.DEFAULT_ENDIANESS endian representation of the NumberSegment's value.
      Parameters:
      aAlias - The alias which identifies the content of this segment.
      aNumberWidth - The number of bytes to be occupied by the number.
    • NumberSegment

      public NumberSegment(String aAlias, int aNumberWidth, Endianess aEndianess)
      Constructs an empty NumberSegment with the given Endianess.
      Parameters:
      aAlias - The alias which identifies the content of this segment.
      aNumberWidth - The number of bytes to be occupied by the number.
      aEndianess - The Endianess to be used for payload values.
    • NumberSegment

      public NumberSegment(String aAlias, int aNumberWidth, Long aValue)
      Constructs a NumberSegment with the given long payload and a TransmissionMetrics.DEFAULT_ENDIANESS endian representation of the NumberSegment's value.
      Parameters:
      aAlias - The alias which identifies the content of this segment.
      aNumberWidth - The number of bytes to be occupied by the number.
      aValue - The payload to be contained by the NumberSegment.
    • NumberSegment

      public NumberSegment(String aAlias, int aNumberWidth, Long aValue, Endianess aEndianess)
      Constructs a NumberSegment with the given long payload and the given Endianess for the representation of the NumberSegment's value (payload).
      Parameters:
      aAlias - The alias which identifies the content of this segment.
      aNumberWidth - The number of bytes to be occupied by the number.
      aValue - The value (payload) to be contained by the NumberSegment.
      aEndianess - The Endianess to be used for payload values.
  • Method Details