-
- All Known Subinterfaces:
PacketLengthWidthAccessor.PacketLengthWidthProperty
- All Known Implementing Classes:
PacketInputStream,PacketOutputStream,StopAndWaitPacketInputStream,StopAndWaitPacketOutputStream,TransmissionMetrics
public interface PacketLengthWidthAccessorProvides an accessor for a packet length width (in bytes) property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfacePacketLengthWidthAccessor.PacketLengthWidthBuilder<B extends PacketLengthWidthAccessor.PacketLengthWidthBuilder<B>>Provides a builder method for a packet length width (in bytes) property returning the builder for applying multiple build operations.static interfacePacketLengthWidthAccessor.PacketLengthWidthMutatorProvides a mutator for a packet length width (in bytes) property.static interfacePacketLengthWidthAccessor.PacketLengthWidthPropertyProvides a packet length width (in bytes) property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description intgetPacketLengthWidth()Retrieves the packet length width (in bytes) from the packet length width (in bytes) property.
-