Module org.refcodes.serial
Package org.refcodes.serial
Interface PacketLengthWidthAccessor.PacketLengthWidthMutator
-
- All Known Subinterfaces:
PacketLengthWidthAccessor.PacketLengthWidthProperty
- Enclosing interface:
- PacketLengthWidthAccessor
public static interface PacketLengthWidthAccessor.PacketLengthWidthMutatorProvides a mutator for a packet length width (in bytes) property.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description voidsetPacketLengthWidth(int aPacketLengthWidth)Sets the packet length width (in bytes) for the packet length width (in bytes) property.
-
-
-
Method Detail
-
setPacketLengthWidth
void setPacketLengthWidth(int aPacketLengthWidth)
Sets the packet length width (in bytes) for the packet length width (in bytes) property.- Parameters:
aPacketLengthWidth- The packet length width (in bytes) to be stored by the packet length width (in bytes) property.
-
-