-
- All Known Subinterfaces:
PacketMagicBytesAccessor.PacketMagicBytesProperty
- All Known Implementing Classes:
PacketInputStream,PacketOutputStream,StopAndWaitPacketInputStream,StopAndWaitPacketOutputStream,TransmissionMetrics
public interface PacketMagicBytesAccessorProvides an accessor for a packet magic bytes property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfacePacketMagicBytesAccessor.PacketMagicBytesBuilder<B extends PacketMagicBytesAccessor.PacketMagicBytesBuilder<B>>Provides a builder method for a packet magic bytes property returning the builder for applying multiple build operations.static interfacePacketMagicBytesAccessor.PacketMagicBytesMutatorProvides a mutator for a packet magic bytes property.static interfacePacketMagicBytesAccessor.PacketMagicBytesPropertyProvides a packet magic bytes property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description byte[]getPacketMagicBytes()Retrieves the magic bytes from the packet magic bytes property.
-