Module org.refcodes.serial
Package org.refcodes.serial
Interface PacketMagicBytesAccessor.PacketMagicBytesMutator
-
- All Known Subinterfaces:
PacketMagicBytesAccessor.PacketMagicBytesProperty
- All Known Implementing Classes:
TransmissionMetricsBuilder
- Enclosing interface:
- PacketMagicBytesAccessor
public static interface PacketMagicBytesAccessor.PacketMagicBytesMutatorProvides a mutator for a packet magic bytes property.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Default Methods Modifier and Type Method Description voidsetPacketMagicBytes(byte[] aPacketMagicBytes)Sets the magic bytes for the packet magic bytes property.default voidsetPacketMagicBytes(String aPacketMagicBytes)Sets the magic bytes for the packet magic bytes property.default voidsetPacketMagicBytes(String aPacketMagicBytes, Charset aEncoding)Sets the magic bytes for the packet magic bytes property.
-
-
-
Method Detail
-
setPacketMagicBytes
void setPacketMagicBytes(byte[] aPacketMagicBytes)
Sets the magic bytes for the packet magic bytes property.- Parameters:
aPacketMagicBytes- The magic bytes to be stored by the packet magic bytes property.
-
setPacketMagicBytes
default void setPacketMagicBytes(String aPacketMagicBytes)
Sets the magic bytes for the packet magic bytes property. UsesTransmissionMetrics.DEFAULT_ENCODINGfor converting theStringinto a byte array.- Parameters:
aPacketMagicBytes- The magic bytes to be stored by the magic bytes property.
-
setPacketMagicBytes
default void setPacketMagicBytes(String aPacketMagicBytes, Charset aEncoding)
Sets the magic bytes for the packet magic bytes property.- Parameters:
aPacketMagicBytes- The magic bytes to be stored by the magic bytes property.aEncoding- The string's bytes are converted using the givenCharset.
-
-