Interface PingMagicBytesAccessor.PingMagicBytesMutator

    • Method Detail

      • setPingMagicBytes

        void setPingMagicBytes​(byte[] aPingMagicBytes)
        Sets the magic bytes for the ping magic bytes property.
        Parameters:
        aPingMagicBytes - The magic bytes to be stored by the ping magic bytes property.
      • setPingMagicBytes

        default void setPingMagicBytes​(String aPingMagicBytes)
        Sets the magic bytes for the ping magic bytes property. Uses TransmissionMetrics.DEFAULT_ENCODING for converting the String into a byte array.
        Parameters:
        aPingMagicBytes - The magic bytes to be stored by the magic bytes property.
      • setPingMagicBytes

        default void setPingMagicBytes​(String aPingMagicBytes,
                                       Charset aEncoding)
        Sets the magic bytes for the ping magic bytes property.
        Parameters:
        aPingMagicBytes - The magic bytes to be stored by the magic bytes property.
        aEncoding - The string's bytes are converted using the given Charset.