Module org.refcodes.serial
Package org.refcodes.serial
Interface PingTimeoutInMsAccessor.PingTimeoutInMsMutator
-
- All Known Subinterfaces:
PingTimeoutInMsAccessor.PingTimeoutInMsProperty
- Enclosing interface:
- PingTimeoutInMsAccessor
public static interface PingTimeoutInMsAccessor.PingTimeoutInMsMutatorProvides a mutator for a ping timeout in milliseconds property.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description voidsetPingTimeoutInMs(long aPingTimeoutInMs)The ping timeout attribute in milliseconds.
-