Interface PortTestBench

All Superinterfaces:
AutoCloseable, org.refcodes.component.Openable
All Known Implementing Classes:
LoopbackPortTestBench

public interface PortTestBench extends AutoCloseable, org.refcodes.component.Openable
The PortTestBench provides a test bench merely for diagnostic purposes. Test code using the PortTestBench can be tested against exchangeable implementation of the PortTestBench.