Class PropertiesSection
java.lang.Object
org.refcodes.serial.AbstractPayloadSection<ImmutableProperties>
org.refcodes.serial.PropertiesSection
- All Implemented Interfaces:
Serializable, AliasAccessor, EncodingAccessor<Charset>, LengthAccessor, PayloadAccessor<ImmutableProperties>, PayloadAccessor.PayloadBuilder<ImmutableProperties, PayloadTransmission<ImmutableProperties>>, PayloadAccessor.PayloadMutator<ImmutableProperties>, PayloadAccessor.PayloadProperty<ImmutableProperties>, Resetable, Diagnosable, Schemable<DiagnosticOptions>, PayloadSection<ImmutableProperties>, PayloadTransmission<ImmutableProperties>, Section, Section.SectionMixin, Transmission, Transmission.TransmissionMixin
public class PropertiesSection
extends AbstractPayloadSection<ImmutableProperties>
implements Section, EncodingAccessor<Charset>
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface AliasAccessor
AliasAccessor.AliasBuilder<B>, AliasAccessor.AliasMutator, AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface EncodingAccessor
EncodingAccessor.EncodingBuilder<E,B>, EncodingAccessor.EncodingMutator<E>, EncodingAccessor.EncodingProperty<E> Nested classes/interfaces inherited from interface LengthAccessor
LengthAccessor.LengthBuilder<B>, LengthAccessor.LengthMutator, LengthAccessor.LengthPropertyNested classes/interfaces inherited from interface PayloadAccessor
PayloadAccessor.PayloadBuilder<P,B>, PayloadAccessor.PayloadMutator<P>, PayloadAccessor.PayloadProperty<P> Nested classes/interfaces inherited from interface Section
Section.SectionMixinNested classes/interfaces inherited from interface Transmission
Transmission.TransmissionMixin -
Field Summary
Fields inherited from class AbstractPayloadSection
_alias, _payload -
Constructor Summary
ConstructorsConstructorDescriptionConstructs an emptyPropertiesSectionusing UTF-8 encoding for the payload.PropertiesSection(String aAlias) Constructs an emptyPropertiesSectionusing UTF-8 encoding for the payload.PropertiesSection(String aAlias, Charset aCharset) Constructs aPropertiesSectionwith a payload expected to be encoded with the givenCharset.PropertiesSection(String aAlias, ImmutableProperties aPayload) Constructs aPropertiesSectionwith the givenImmutablePropertiespayload being UTF-8 encoded.PropertiesSection(String aAlias, ImmutableProperties aPayload, Charset aCharset) Constructs aPropertiesSectionwith the givenImmutablePropertiespayload being encoded with the givenCharset.PropertiesSection(String aAlias, ImmutableProperties aPayload, TransmissionMetrics aTransmissionMetrics) Constructs aPropertiesSectionwith the givenImmutablePropertiespayload being encoded with the givenCharset.PropertiesSection(Charset aCharset) Constructs aPropertiesSectionwith a payload expected to be encoded with the givenCharset.PropertiesSection(ImmutableProperties aPayload) Constructs aPropertiesSectionwith the givenImmutablePropertiespayload being UTF-8 encoded.PropertiesSection(ImmutableProperties aPayload, Charset aCharset) Constructs aPropertiesSectionwith the givenImmutablePropertiespayload being encoded with the givenCharset.PropertiesSection(ImmutableProperties aPayload, TransmissionMetrics aTransmissionMetrics) Constructs aPropertiesSectionwith the givenImmutablePropertiespayload being encoded with the givenCharset. -
Method Summary
Modifier and TypeMethodDescriptionbooleanvoidfromTransmission(Sequence aSequence, int aOffset, int aLength) (Re-)initializes this instance with the the givenSequencedata.intDetermines the overall length of thisTransmission.inthashCode()toSchema()Provides theSequencerepresentation of thisTransmission.Returns theImmutableSimpleTypeTablerepresentation of thisTransmission.withPayload(ImmutableProperties aValue) Methods inherited from class AbstractPayloadSection
getAlias, getPayload, reset, setPayload, toStringMethods inherited from interface PayloadAccessor
getPayloadOrMethods inherited from interface PayloadAccessor.PayloadProperty
letPayloadMethods inherited from interface Section
fromTransmission, fromTransmission, fromTransmission, receiveFrom, receiveFromMethods inherited from interface Section.SectionMixin
receiveFromMethods inherited from interface Transmission
reset, transmitTo, transmitToMethods inherited from interface Transmission.TransmissionMixin
transmitTo
-
Constructor Details
-
PropertiesSection
Constructs aPropertiesSectionwith the givenImmutablePropertiespayload being encoded with the givenCharset. The properties from the payload are copied into thePropertiesSection. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aPayload- The payload to be contained by theSection.aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.
-
PropertiesSection
public PropertiesSection(String aAlias, ImmutableProperties aPayload, TransmissionMetrics aTransmissionMetrics) Constructs aPropertiesSectionwith the givenImmutablePropertiespayload being encoded with the givenCharset. The properties from the payload are copied into thePropertiesSection. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aAlias- The alias which identifies the content of this segment.aPayload- The payload to be contained by theSection.aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.
-
PropertiesSection
public PropertiesSection()Constructs an emptyPropertiesSectionusing UTF-8 encoding for the payload. -
PropertiesSection
Constructs aPropertiesSectionwith the givenImmutablePropertiespayload being UTF-8 encoded. The properties from the payload are copied into thePropertiesSection.- Parameters:
aPayload- The payload to be contained by theSection.
-
PropertiesSection
Constructs aPropertiesSectionwith a payload expected to be encoded with the givenCharset. -
PropertiesSection
Constructs aPropertiesSectionwith the givenImmutablePropertiespayload being encoded with the givenCharset. The properties from the payload are copied into thePropertiesSection. -
PropertiesSection
Constructs an emptyPropertiesSectionusing UTF-8 encoding for the payload.- Parameters:
aAlias- The alias which identifies the content of this segment.
-
PropertiesSection
Constructs aPropertiesSectionwith the givenImmutablePropertiespayload being UTF-8 encoded. The properties from the payload are copied into thePropertiesSection.- Parameters:
aAlias- The alias which identifies the content of this segment.aPayload- The payload to be contained by theSection.
-
PropertiesSection
-
PropertiesSection
Constructs aPropertiesSectionwith the givenImmutablePropertiespayload being encoded with the givenCharset. The properties from the payload are copied into thePropertiesSection.
-
-
Method Details
-
toSequence
Provides theSequencerepresentation of thisTransmission. In case of nestedTransmissioninstances, allSequencerepresentations from all sub-segments are accumulated to the result as well. Caution, the Transmission (or its nestedTransmissioninstances) may be backed by the returnedSequence.- Specified by:
toSequencein interfaceTransmission- Returns:
- The according instance's
Sequence.
-
fromTransmission
public void fromTransmission(Sequence aSequence, int aOffset, int aLength) throws TransmissionException (Re-)initializes this instance with the the givenSequencedata.- Specified by:
fromTransmissionin interfaceSection- Parameters:
aSequence- TheSequencedata from which to (re-)initialize this instance.aOffset- The offset where to start processing the providedSequence.aLength- The length of data assigned by theSequence.- Throws:
TransmissionException- thrown in case a givenSequencecannot be processed.
-
getLength
public int getLength()Determines the overall length of thisTransmission. In case of nestedTransmissioninstances, all length values from all sub-segments are accumulated to the result as well.- Specified by:
getLengthin interfaceLengthAccessor- Specified by:
getLengthin interfaceTransmission- Returns:
- The (overall) length of the
Transmission(including any sub-segments).
-
toSchema
- Specified by:
toSchemain interfaceSchemable<DiagnosticOptions>
-
hashCode
public int hashCode()- Overrides:
hashCodein classAbstractPayloadSection<ImmutableProperties>
-
equals
- Overrides:
equalsin classAbstractPayloadSection<ImmutableProperties>
-
withPayload
- Specified by:
withPayloadin interfacePayloadAccessor.PayloadBuilder<ImmutableProperties, PayloadTransmission<ImmutableProperties>>
-
toSimpleTypeTable
Returns theImmutableSimpleTypeTablerepresentation of thisTransmission. In case this Transmission hasTransmissionchildren, then the children are queried as well and contained in the resultingImmutableSimpleTypeTable. The aliases of the accordingTransmissioninstances represent the resulting path to aTransmission's final simple type.- Specified by:
toSimpleTypeTablein interfaceTransmission- Overrides:
toSimpleTypeTablein classAbstractPayloadSection<ImmutableProperties>- Returns:
- The
ImmutableSimpleTypeTablerepresenting thisTransmissionand (if any) its children, with the according aliases forming the paths to theTransmission's values.
-
getEncoding
- Specified by:
getEncodingin interfaceEncodingAccessor<Charset>
-