Class SegmentArraySection<ARRAY extends Segment>

java.lang.Object
org.refcodes.serial.AbstractArrayTransmission<ARRAY>
org.refcodes.serial.SegmentArraySection<ARRAY>
Type Parameters:
ARRAY - The type of the array elements to be contained in this instance.
All Implemented Interfaces:
Serializable, AliasAccessor, ArrayAccessor<ARRAY[]>, ArrayAccessor.ArrayBuilder<ARRAY[], ArrayTransmission<ARRAY>>, ArrayAccessor.ArrayMutator<ARRAY[]>, ArrayAccessor.ArrayProperty<ARRAY[]>, LengthAccessor, Resetable, Diagnosable, Schemable<DiagnosticOptions>, ArraySection<ARRAY>, ArrayTransmission<ARRAY>, Section, Section.SectionMixin, Transmission, Transmission.TransmissionMixin

public class SegmentArraySection<ARRAY extends Segment> extends AbstractArrayTransmission<ARRAY> implements Section, ArraySection<ARRAY>
A SegmentArraySection is a Segment consisting of Segment elements with each element of presumably different lengths ( in contrast to the FixedSegmentArraySection).
See Also: