Interface SegmentConsumer<SEGMENT extends Segment>

  • Type Parameters:
    SEGMENT - The Segment type being consumed.
    Functional Interface:
    This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.

    @FunctionalInterface
    public interface SegmentConsumer<SEGMENT extends Segment>
    A SegmentConsumer consumes a Segment and is used to create lambda expressions used for asynchronous callback.
    • Method Detail

      • onSegment

        void onSegment​(SEGMENT aSegment)
        Callback consuming a Segment.
        Parameters:
        aSegment - The Segment to be consumed.