-
- All Known Subinterfaces:
Port<PM>,SegmentTransceiver,SegmentTransmitter,SerialTransceiver,SerialTransmitter
- All Known Implementing Classes:
AbstractPort,AbstractPortDecorator,CrossoverLoopbackPort,LoopbackPort
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
@FunctionalInterface public interface SegmentSource
TheSegmentSourceis used to sendSegmentinstances in a unified way.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description <SEGMENT extends Segment>
voidtransmitSegment(SEGMENT aSegment)Transmits aSegment(and blocks this thread) till all it'sSequencedata (as ofTransmission.toSequence()) has been sent.
-
-
-
Method Detail
-
transmitSegment
<SEGMENT extends Segment> void transmitSegment(SEGMENT aSegment) throws IOException
Transmits aSegment(and blocks this thread) till all it'sSequencedata (as ofTransmission.toSequence()) has been sent.- Type Parameters:
SEGMENT- TheSegmenttype describing theSegmentsubclass used.- Parameters:
aSegment- TheSegment's data to be sent.- Throws:
IOException- thrown in case of I/O issues (e.g. a timeout) while sending.
-
-