Class SerialSchema

java.lang.Object
java.util.AbstractMap<String,Object>
java.util.HashMap<String,Object>
org.refcodes.schema.Schema
org.refcodes.serial.SerialSchema
All Implemented Interfaces:
Serializable, Cloneable, Map<String,Object>, org.refcodes.exception.ExceptionAccessor<Throwable>, org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.ChildrenAccessor<org.refcodes.schema.Schema[]>, org.refcodes.mixin.DescriptionAccessor, org.refcodes.mixin.HashAccessor, org.refcodes.mixin.IdentifierAccessor, org.refcodes.mixin.KeyAccessor<String>, org.refcodes.mixin.LengthAccessor, org.refcodes.mixin.StereotypeAccessor<String>, org.refcodes.mixin.TypeAccessor, org.refcodes.mixin.ValueAccessor<Object>

public class SerialSchema extends org.refcodes.schema.Schema implements org.refcodes.mixin.LengthAccessor
The purpose of a SerialSchema is to automatically outline and generate documentation of serial data (structures).
See Also:
  • Nested Class Summary

    Nested Classes
    Modifier and Type
    Class
    Description
    static final class 

    Nested classes/interfaces inherited from class java.util.AbstractMap

    AbstractMap.SimpleEntry<K,V>, AbstractMap.SimpleImmutableEntry<K,V>

    Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor

    org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasProperty

    Nested classes/interfaces inherited from interface org.refcodes.mixin.ChildrenAccessor

    org.refcodes.mixin.ChildrenAccessor.ChildrenBuilder<T,B extends org.refcodes.mixin.ChildrenAccessor.ChildrenBuilder<T,B>>, org.refcodes.mixin.ChildrenAccessor.ChildrenMutator<T>, org.refcodes.mixin.ChildrenAccessor.ChildrenProperty<T>

    Nested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor

    org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionProperty

    Nested classes/interfaces inherited from interface org.refcodes.exception.ExceptionAccessor

    org.refcodes.exception.ExceptionAccessor.ExceptionBuilder<EXC extends Throwable,B extends org.refcodes.exception.ExceptionAccessor.ExceptionBuilder<EXC,B>>, org.refcodes.exception.ExceptionAccessor.ExceptionMutator<EXC extends Throwable>, org.refcodes.exception.ExceptionAccessor.ExceptionProperty<EXC extends Throwable>

    Nested classes/interfaces inherited from interface org.refcodes.mixin.HashAccessor

    org.refcodes.mixin.HashAccessor.HashBuilder<B extends org.refcodes.mixin.HashAccessor.HashBuilder<B>>, org.refcodes.mixin.HashAccessor.HashMutator, org.refcodes.mixin.HashAccessor.HashProperty

    Nested classes/interfaces inherited from interface org.refcodes.mixin.IdentifierAccessor

    org.refcodes.mixin.IdentifierAccessor.IdentifierBuilder<B extends org.refcodes.mixin.IdentifierAccessor.IdentifierBuilder<B>>, org.refcodes.mixin.IdentifierAccessor.IdentifierMutator, org.refcodes.mixin.IdentifierAccessor.IdentifierProperty

    Nested classes/interfaces inherited from interface org.refcodes.mixin.KeyAccessor

    org.refcodes.mixin.KeyAccessor.KeyBuilder<K,B extends org.refcodes.mixin.KeyAccessor.KeyBuilder<K,B>>, org.refcodes.mixin.KeyAccessor.KeyMutator<K>, org.refcodes.mixin.KeyAccessor.KeyProperty<K>

    Nested classes/interfaces inherited from interface org.refcodes.mixin.LengthAccessor

    org.refcodes.mixin.LengthAccessor.LengthBuilder<B extends org.refcodes.mixin.LengthAccessor.LengthBuilder<B>>, org.refcodes.mixin.LengthAccessor.LengthMutator, org.refcodes.mixin.LengthAccessor.LengthProperty

    Nested classes/interfaces inherited from interface java.util.Map

    Map.Entry<K,V>

    Nested classes/interfaces inherited from interface org.refcodes.mixin.StereotypeAccessor

    org.refcodes.mixin.StereotypeAccessor.StereotypeBuilder<T,B extends org.refcodes.mixin.StereotypeAccessor.StereotypeBuilder<T,B>>, org.refcodes.mixin.StereotypeAccessor.StereotypeMutator<T>, org.refcodes.mixin.StereotypeAccessor.StereotypeProperty<T>

    Nested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor

    org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T>, org.refcodes.mixin.TypeAccessor.TypeProperty<T>

    Nested classes/interfaces inherited from interface org.refcodes.mixin.ValueAccessor

    org.refcodes.mixin.ValueAccessor.ValueBuilder<V,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V,B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V>, org.refcodes.mixin.ValueAccessor.ValueProperty<V>
  • Field Summary

    Fields
    Modifier and Type
    Field
    Description
    static final String
     
    static final String
     

    Fields inherited from class org.refcodes.schema.Schema

    _children, ALIAS, ASSOCIATION, DESCRIPTION, EXCEPTION, HASH, HASH_SEPARATOR, IDENTIFIER, KEY, STEREOTYPE, TYPE, VALUE
  • Constructor Summary

    Constructors
    Constructor
    Description
    SerialSchema(String aIdentifier, String aAlias, String aKey, Class<?> aType, Integer aHash, String aStereotype, Object aValue, Throwable aException, String aDescription, org.refcodes.schema.Schema aSchema, org.refcodes.schema.Schema[] aChildren)
    Instantiates the class SerialSchema.
  • Method Summary

    Modifier and Type
    Method
    Description
    Creates builder to build SerialSchema.
    int
    Retrieves the more verbose view on the structure of the data.

    Methods inherited from class org.refcodes.schema.Schema

    get, getAlias, getChildren, getDescription, getException, getHash, getIdentifier, getKey, getOr, getStereotype, getType, getValue, init, toLabel, toNotation, toObjectId, toSimpleObjectId, toString, visit

    Methods inherited from class java.util.AbstractMap

    equals, hashCode

    Methods inherited from class java.lang.Object

    finalize, getClass, notify, notifyAll, wait, wait, wait

    Methods inherited from interface java.util.Map

    equals, hashCode

    Methods inherited from interface org.refcodes.mixin.ValueAccessor

    getValueOr, hasValue
  • Field Details

  • Constructor Details

    • SerialSchema

      public SerialSchema(String aIdentifier, String aAlias, String aKey, Class<?> aType, Integer aHash, String aStereotype, Object aValue, Throwable aException, String aDescription, org.refcodes.schema.Schema aSchema, org.refcodes.schema.Schema[] aChildren)
      Instantiates the class SerialSchema.
      Parameters:
      aIdentifier - the identifier
      aAlias - the alias
      aKey - the key
      aType - the type
      aHash - the hash
      aStereotype - the stereotype
      aValue - the value
      aException - the exception
      aDescription - the description
      aSchema - the schema
      aChildren - the children
      See Also:
      • Schema(String, String, String, Class<?>, Integer, String, Object, Throwable, String, Schema, Schema[])
  • Method Details

    • getLength

      public int getLength()
      Specified by:
      getLength in interface org.refcodes.mixin.LengthAccessor
    • getVerbose

      public String getVerbose()
      Retrieves the more verbose view on the structure of the data.
      Returns:
      The more verbose view on the structure of the data.
    • builder

      public static SerialSchema.Builder builder()
      Creates builder to build SerialSchema.
      Returns:
      created builder