- java.lang.Object
-
- org.refcodes.serial.AbstractPayloadSection<String>
-
- org.refcodes.serial.StringSection
-
- All Implemented Interfaces:
Serializable,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.EncodingAccessor<Charset>,org.refcodes.mixin.LengthAccessor,org.refcodes.mixin.PayloadAccessor<String>,org.refcodes.mixin.PayloadAccessor.PayloadBuilder<String,PayloadTransmission<String>>,org.refcodes.mixin.PayloadAccessor.PayloadMutator<String>,org.refcodes.mixin.PayloadAccessor.PayloadProperty<String>,PayloadSection<String>,PayloadTransmission<String>,Section,Section.SectionMixin,Transmission,Transmission.TransmissionMixin
public class StringSection extends AbstractPayloadSection<String> implements PayloadSection<String>, org.refcodes.mixin.EncodingAccessor<Charset>
TheStringSectionis an implementation of aSectioncarrying aStringas payload. By default, if not otherwise specified, theTransmissionMetrics.DEFAULT_ENCODINGencoding is used for encoding and decodingStringinstances.- See Also:
- Serialized Form
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.EncodingAccessor
org.refcodes.mixin.EncodingAccessor.EncodingBuilder<E extends Object,B extends org.refcodes.mixin.EncodingAccessor.EncodingBuilder<E,B>>, org.refcodes.mixin.EncodingAccessor.EncodingMutator<E extends Object>, org.refcodes.mixin.EncodingAccessor.EncodingProperty<E extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.LengthAccessor
org.refcodes.mixin.LengthAccessor.LengthBuilder<B extends org.refcodes.mixin.LengthAccessor.LengthBuilder<B>>, org.refcodes.mixin.LengthAccessor.LengthMutator, org.refcodes.mixin.LengthAccessor.LengthProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.PayloadAccessor
org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P extends Object,B extends org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P,B>>, org.refcodes.mixin.PayloadAccessor.PayloadMutator<P extends Object>, org.refcodes.mixin.PayloadAccessor.PayloadProperty<P extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.serial.Section
Section.SectionMixin
-
Nested classes/interfaces inherited from interface org.refcodes.serial.Transmission
Transmission.TransmissionMixin
-
-
Field Summary
-
Fields inherited from class org.refcodes.serial.AbstractPayloadSection
_alias, _payload
-
-
Constructor Summary
Constructors Constructor Description StringSection()Constructs an emptyStringSectionusing theTransmissionMetrics.DEFAULT_ENCODINGencoding for the payload.StringSection(String aValue)Constructs aStringSectionwith the givenStringpayload being encoded with theTransmissionMetrics.DEFAULT_ENCODING.StringSection(String aAlias, String aValue)Constructs aStringSectionwith the givenStringpayload being encoded with theTransmissionMetrics.DEFAULT_ENCODING.StringSection(String aAlias, String aValue, Charset aCharset)StringSection(String aAlias, String aValue, TransmissionMetrics aTransmissionMetrics)Constructs an according instance from the given configuration.StringSection(String aValue, Charset aCharset)StringSection(String aValue, TransmissionMetrics aTransmissionMetrics)Constructs an according instance from the given configuration.StringSection(Charset aCharset)Constructs aStringSectionwith a payload expected to be encoded with the givenCharset.StringSection(TransmissionMetrics aTransmissionMetrics)Constructs an according instance from the given configuration.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description voidfromTransmission(Sequence aSequence, int aOffset, int aLength)(Re-)initializes this instance with the the givenSequencedata.CharsetgetEncoding()intgetLength()Determines the overall length of thisTransmission.SchematoSchema()Retrieves theSchemarepresenting theTransmission.SequencetoSequence()Provides theSequencerepresentation of thisTransmission.StringSectionwithPayload(String aValue)-
Methods inherited from class org.refcodes.serial.AbstractPayloadSection
equals, getAlias, getPayload, hashCode, setPayload, toSimpleTypeMap, toString
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface org.refcodes.serial.Section
fromTransmission, fromTransmission, fromTransmission, receiveFrom, receiveFrom
-
Methods inherited from interface org.refcodes.serial.Section.SectionMixin
receiveFrom
-
Methods inherited from interface org.refcodes.serial.Transmission
toSimpleTypeMap, transmitTo, transmitTo
-
Methods inherited from interface org.refcodes.serial.Transmission.TransmissionMixin
transmitTo
-
-
-
-
Constructor Detail
-
StringSection
public StringSection(TransmissionMetrics aTransmissionMetrics)
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.
-
StringSection
public StringSection(String aValue, TransmissionMetrics aTransmissionMetrics)
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aValue- The payload to be contained by theStringSection.aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.
-
StringSection
public StringSection(String aAlias, String aValue, TransmissionMetrics aTransmissionMetrics)
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aAlias- The alias which identifies the content of this instance.aValue- The payload to be contained by theStringSection.aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.
-
StringSection
public StringSection()
Constructs an emptyStringSectionusing theTransmissionMetrics.DEFAULT_ENCODINGencoding for the payload.
-
StringSection
public StringSection(String aValue)
Constructs aStringSectionwith the givenStringpayload being encoded with theTransmissionMetrics.DEFAULT_ENCODING.- Parameters:
aValue- The payload to be contained by thisStringSection.
-
StringSection
public StringSection(Charset aCharset)
Constructs aStringSectionwith a payload expected to be encoded with the givenCharset.
-
StringSection
public StringSection(String aValue, Charset aCharset)
- Parameters:
aValue- The payload to be contained by thisStringSection.aCharset- TheCharsetto be used for encoding theString.
-
StringSection
public StringSection(String aAlias, String aValue)
Constructs aStringSectionwith the givenStringpayload being encoded with theTransmissionMetrics.DEFAULT_ENCODING.- Parameters:
aAlias- The alias which identifies the content of this segment.aValue- The payload to be contained by thisStringSection.
-
-
Method Detail
-
toSequence
public Sequence toSequence()
Provides theSequencerepresentation of thisTransmission. In case of nestedTransmissioninstances, allSequencerepresentations from all sub-segments are accumulated to the result as well. Caution, the Transmission (or its nestedTransmissioninstances) may be backed by the returnedSequence.- Specified by:
toSequencein interfaceTransmission- Returns:
- The according instance's
Sequence.
-
fromTransmission
public void fromTransmission(Sequence aSequence, int aOffset, int aLength) throws TransmissionException
(Re-)initializes this instance with the the givenSequencedata.- Specified by:
fromTransmissionin interfaceSection- Parameters:
aSequence- TheSequencedata from which to (re-)initialize this instance.aOffset- The offset where to start processing the providedSequence.aLength- The length of data assigned by theSequence.- Throws:
TransmissionException- thrown in case a givenSequencecannot be processed.
-
getLength
public int getLength()
Determines the overall length of thisTransmission. In case of nestedTransmissioninstances, all length values from all sub-segments are accumulated to the result as well.- Specified by:
getLengthin interfaceorg.refcodes.mixin.LengthAccessor- Specified by:
getLengthin interfaceTransmission- Returns:
- The (overall) length of the
Transmission(including any sub-segments).
-
toSchema
public Schema toSchema()
Retrieves theSchemarepresenting theTransmission. Retrieving aSchemais useful when analyzing and debugging data structures such as aAllocSectionDecoratorSegmentinstance to help document, learn and verify on the structure (as well as the content) of that veryAllocSectionDecoratorSegment.- Specified by:
toSchemain interfaceTransmission- Returns:
- The
Schemarepresentation of the implementing type for debugging and verification (or documentation) purposes.
-
withPayload
public StringSection withPayload(String aValue)
- Specified by:
withPayloadin interfaceorg.refcodes.mixin.PayloadAccessor.PayloadBuilder<String,PayloadTransmission<String>>
-
-