Uses of Class
org.refcodes.serial.AbstractReferenceeLengthSegment
-
-
Uses of AbstractReferenceeLengthSegment in org.refcodes.serial
Subclasses of AbstractReferenceeLengthSegment in org.refcodes.serial Modifier and Type Class Description classAbstractLengthDecoratorSegment<DECORATEE extends Transmission>TheAbstractLengthDecoratorSegmentdecorates a decoratee with a length prefix.classAllocSectionDecoratorSegment<DECORATEE extends Section>AnAllocSectionDecoratorSegmentenriches anSectionwith an allocation declaration being prefixed to the enrichedSection.classAllocSegmentHeadAnAllocSegmentHeadprovides the allocation length for aAllocSegmentBody.classLengthSegment<REFERENCEE extends Transmission>AnLengthSegmentenriches aSegmentwith an allocation declaration computed from the referencedTransmission.classLengthSegmentDecoratorSegment<DECORATEE extends Segment>AnLengthSegmentDecoratorSegmentenriches aSegmentwith an allocation declaration being prefixed to the enrichedSegment.
-