Uses of Class
org.refcodes.serial.BooleanArraySection
-
Uses of BooleanArraySection in org.refcodes.serial
Methods in org.refcodes.serial that return BooleanArraySection Modifier and Type Method Description static BooleanArraySectionSerialSugar. booleanArraySection()Constructs an emptyBooleanArraySection.static BooleanArraySectionSerialSugar. booleanArraySection(boolean... aValue)Constructs aBooleanArraySectionwith the given boolean array payload.static BooleanArraySectionSerialSugar. booleanArraySection(Boolean... aValue)Constructs aBooleanArraySectionwith the given boolean array payload.static BooleanArraySectionSerialSugar. booleanArraySection(String aAlias)Constructs an emptyBooleanArraySection.static BooleanArraySectionSerialSugar. booleanArraySection(String aAlias, boolean... aValue)Constructs aBooleanArraySectionwith the given boolean array payload.static BooleanArraySectionSerialSugar. booleanArraySection(String aAlias, Boolean... aValue)Constructs aBooleanArraySectionwith the given boolean array payload.BooleanArraySectionBooleanArraySection. withPayload(boolean[] aValue)BooleanArraySectionBooleanArraySection. withPayload(Boolean[] aPayload)Convenience method to convert the array of wrapper types into its counterpart with primitive types before invokingwithPayload(boolean[]).