Uses of Class
org.refcodes.serial.ByteArraySection
-
-
Uses of ByteArraySection in org.refcodes.serial
Methods in org.refcodes.serial that return ByteArraySection Modifier and Type Method Description static ByteArraySectionSerialSugar. byteArraySection()Constructs an emptyByteArraySection.static ByteArraySectionSerialSugar. byteArraySection(byte... aArray)Constructs aByteArraySectionwith the given byte array payload.static ByteArraySectionSerialSugar. byteArraySection(Byte... aArray)Constructs aByteArraySectionwith the given byte array payload.static ByteArraySectionSerialSugar. byteArraySection(String aAlias)Constructs an emptyByteArraySection.static ByteArraySectionSerialSugar. byteArraySection(String aAlias, byte... aArray)Constructs aByteArraySectionwith the given byte array payload.static ByteArraySectionSerialSugar. byteArraySection(String aAlias, Byte... aArray)Constructs aByteArraySectionwith the given byte array payload.ByteArraySectionByteArraySection. withPayload(byte[] aValue)ByteArraySectionByteArraySection. withPayload(Byte[] aPayload)Convenience method to convert the array of wrapper types into its counterpart with primitive types before invokingwithPayload(byte[]).
-