Uses of Class
org.refcodes.serial.FixedSegmentArraySection
-
Uses of FixedSegmentArraySection in org.refcodes.serial
Methods in org.refcodes.serial that return FixedSegmentArraySection Modifier and Type Method Description static <ARRAY extends Segment>
FixedSegmentArraySection<ARRAY>SerialSugar. fixedSegmentArraySection(ARRAY... aSegmentArray)Constructs aFixedSegmentArraySectionwith the givenSegmentelements.static <ARRAY extends Segment>
FixedSegmentArraySection<ARRAY>SerialSugar. fixedSegmentArraySection(Class<ARRAY> aSegmentClass)Constructs aFixedSegmentArraySectionwith instances of the array being created using the providedClassinstance.static <ARRAY extends Segment>
FixedSegmentArraySection<ARRAY>SerialSugar. fixedSegmentArraySection(org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory)Constructs aFixedSegmentArraySectionwith instances of the array being created using the providedTypeFactoryinstance.static <ARRAY extends Segment>
FixedSegmentArraySection<ARRAY>SerialSugar. fixedSegmentArraySection(org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory, ARRAY... aSegmentArray)Constructs aFixedSegmentArraySectionwith the given elements.FixedSegmentArraySection<ARRAY>FixedSegmentArraySection. withArray(ARRAY[] aValue)