Uses of Enum Class
org.refcodes.serial.HandshakeProtocol
-
Uses of HandshakeProtocol in org.refcodes.serial
Subclasses with type arguments of type HandshakeProtocol in org.refcodes.serialModifier and TypeClassDescriptionenumEnumeration with the various protocol settings when receiving a transmission.Methods in org.refcodes.serial that return HandshakeProtocolModifier and TypeMethodDescriptionstatic HandshakeProtocolReturns the enum constant of this class with the specified name.static HandshakeProtocol[]HandshakeProtocol.values()Returns an array containing the constants of this enum class, in the order they are declared.