Uses of Enum Class
org.refcodes.serial.MagicBytes
-
Uses of MagicBytes in org.refcodes.serial
Subclasses with type arguments of type MagicBytes in org.refcodes.serialModifier and TypeClassDescriptionenumTheMagicBytesenumeration provides various predefined magic bytes for common use cases.Methods in org.refcodes.serial that return MagicBytesModifier and TypeMethodDescriptionstatic MagicBytesReturns the enum constant of this class with the specified name.static MagicBytes[]MagicBytes.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.refcodes.serial with parameters of type MagicBytesModifier and TypeMethodDescriptionstatic byte[]MagicBytes.toMagicBytes(MagicBytes... aMagicBytes) Constructs magic bytes from the providedMagicByteselements to be concatenated to a single magic bytes sequence.