Uses of Class
org.refcodes.serial.PacketInputStream
-
Uses of PacketInputStream in org.refcodes.serial
Subclasses of PacketInputStream in org.refcodes.serial Modifier and Type Class Description classStopAndWaitPacketInputStreamTheStopAndWaitPacketInputStreamwraps anOutputStreamand chunks any data to be written into packets with a sequence number and a block of data.Methods in org.refcodes.serial that return PacketInputStream Modifier and Type Method Description PacketInputStreamPacketInputStream.Builder. build()Returns thePacketInputStreaminstance build according to thePacketInputStream.Builderconfiguration.