Uses of Class
org.refcodes.serial.PacketInputStream.Builder
-
Uses of PacketInputStream.Builder in org.refcodes.serial
Subclasses of PacketInputStream.Builder in org.refcodes.serialModifier and TypeClassDescriptionstatic classBuilder to buildStopAndWaitPacketInputStreaminstances.Classes in org.refcodes.serial that implement interfaces with type arguments of type PacketInputStream.BuilderModifier and TypeClassDescriptionstatic classBuilder to buildPacketInputStreaminstances.static classBuilder to buildPacketInputStreaminstances.static classBuilder to buildPacketInputStreaminstances.static classBuilder to buildPacketInputStreaminstances.static classBuilder to buildPacketInputStreaminstances.static classBuilder to buildPacketInputStreaminstances.static classBuilder to buildPacketInputStreaminstances.static classBuilder to buildPacketInputStreaminstances.static classBuilder to buildPacketInputStreaminstances.static classBuilder to buildPacketInputStreaminstances.static classBuilder to buildPacketInputStreaminstances.static classBuilder to buildPacketInputStreaminstances.Methods in org.refcodes.serial that return PacketInputStream.BuilderModifier and TypeMethodDescriptionstatic PacketInputStream.BuilderPacketInputStream.builder()Creates builder to buildPacketInputStream.PacketInputStream.Builder.withBlockSize(int aBlockSize) PacketInputStream.Builder.withChecksumValidationMode(ChecksumValidationMode aChecksumValidationMode) PacketInputStream.Builder.withCrcAlgorithm(CrcAlgorithm aCrcAlgorithm) PacketInputStream.Builder.withCrcChecksumConcatenateMode(ConcatenateMode aCrcChecksumConcatenateMode) PacketInputStream.Builder.withEndianess(Endianess aEndianess) PacketInputStream.Builder.withInputStream(InputStream aInputStream) PacketInputStream.Builder.withPacketLengthWidth(int aPacketLengthWidth) Sets the packet length width (in bytes) for the packet length width (in bytes) property.PacketInputStream.Builder.withPacketMagicBytes(byte[] aPacketMagicBytes) Sets the magic bytes for the packet magic bytes property.PacketInputStream.Builder.withPacketSegmentPackager(SegmentPackager aPacketSegmentPackager) Sets theSegmentPackagerfor the packetSegmentPackagerproperty.PacketInputStream.Builder.withSequenceNumberConcatenateMode(ConcatenateMode aSequenceNumberConcatenateMode) Sets theConcatenateModefor the sequence numberConcatenateModeproperty.PacketInputStream.Builder.withSequenceNumberInitValue(int aSequenceNumberInitValue) Sets the sequence number initial value for the sequence number initial value property.PacketInputStream.Builder.withSequenceNumberWidth(int aSequenceNumberWidth) Sets the sequence number width (in bytes) for the sequence number width (in bytes) property.