Uses of Interface
org.refcodes.serial.PacketMagicBytesAccessor
-
-
Uses of PacketMagicBytesAccessor in org.refcodes.serial
Subinterfaces of PacketMagicBytesAccessor in org.refcodes.serial Modifier and Type Interface Description static interfacePacketMagicBytesAccessor.PacketMagicBytesPropertyProvides a packet magic bytes property.Classes in org.refcodes.serial that implement PacketMagicBytesAccessor Modifier and Type Class Description classPacketInputStreamThePacketInputStreamwraps anInputStreamand chunks any data to be written into packets with a sequence number and a block of data.classPacketOutputStreamThePacketOutputStreamwraps anOutputStreamand chunks any data to be written into packets with a sequence number, a block of data and a CRC checksum.classStopAndWaitPacketInputStreamTheStopAndWaitPacketInputStreamwraps anInputStreamand chunks any data to be written into packets with a sequence number and a block of data.classStopAndWaitPacketOutputStreamTheStopAndWaitPacketOutputStreamwraps anOutputStreamand chunks any data to be written into packets with a sequence number, a block of data and a CRC checksum.classTransmissionMetricsTheTransmissionMetricsinterface represents common parameters required when configuring a transmission.
-