Uses of Class
org.refcodes.serial.PacketOutputStream
-
Uses of PacketOutputStream in org.refcodes.serial
Subclasses of PacketOutputStream in org.refcodes.serial Modifier and Type Class Description classStopAndWaitPacketOutputStreamTheStopAndWaitPacketOutputStreamwraps anOutputStreamand chunks any data to be written into packets with a sequence number, a block of data and a CRC checksum.Methods in org.refcodes.serial that return PacketOutputStream Modifier and Type Method Description PacketOutputStreamPacketOutputStream.Builder. build()Returns theStopAndWaitPacketInputStreaminstance build according to thePacketOutputStream.Builderconfiguration.