Uses of Class
org.refcodes.serial.PacketOutputStream.Builder
-
Uses of PacketOutputStream.Builder in org.refcodes.serial
Subclasses of PacketOutputStream.Builder in org.refcodes.serialModifier and TypeClassDescriptionstatic final classBuilder to buildStopAndWaitPacketInputStreaminstances.Classes in org.refcodes.serial that implement interfaces with type arguments of type PacketOutputStream.BuilderModifier and TypeClassDescriptionstatic classBuilder to buildStopAndWaitPacketInputStreaminstances.static classBuilder to buildStopAndWaitPacketInputStreaminstances.static classBuilder to buildStopAndWaitPacketInputStreaminstances.static classBuilder to buildStopAndWaitPacketInputStreaminstances.static classBuilder to buildStopAndWaitPacketInputStreaminstances.static classBuilder to buildStopAndWaitPacketInputStreaminstances.static classBuilder to buildStopAndWaitPacketInputStreaminstances.static classBuilder to buildStopAndWaitPacketInputStreaminstances.static classBuilder to buildStopAndWaitPacketInputStreaminstances.static classBuilder to buildStopAndWaitPacketInputStreaminstances.static classBuilder to buildStopAndWaitPacketInputStreaminstances.static classBuilder to buildStopAndWaitPacketInputStreaminstances.Methods in org.refcodes.serial that return PacketOutputStream.BuilderModifier and TypeMethodDescriptionstatic PacketOutputStream.BuilderPacketOutputStream.builder()Creates builder to buildPacketOutputStream.PacketOutputStream.Builder.withBlockSize(int aBlockSize) PacketOutputStream.Builder.withChecksumValidationMode(org.refcodes.numerical.ChecksumValidationMode aChecksumValidationMode) PacketOutputStream.Builder.withCrcAlgorithm(org.refcodes.numerical.CrcAlgorithm aCrcAlgorithm) PacketOutputStream.Builder.withCrcChecksumConcatenateMode(org.refcodes.mixin.ConcatenateMode aCrcChecksumConcatenateMode) PacketOutputStream.Builder.withEndianess(org.refcodes.numerical.Endianess aEndianess) PacketOutputStream.Builder.withOutputStream(OutputStream aOutputStream) PacketOutputStream.Builder.withPacketLengthWidth(int aPacketLengthWidth) Sets the packet length width (in bytes) for the packet length width (in bytes) property.PacketOutputStream.Builder.withPacketMagicBytes(byte[] aPacketMagicBytes) Sets the magic bytes for the packet magic bytes property.PacketOutputStream.Builder.withPacketSegmentPackager(SegmentPackager aPacketSegmentPackager) Sets theSegmentPackagerfor the packetSegmentPackagerproperty.PacketOutputStream.Builder.withSequenceNumberConcatenateMode(org.refcodes.mixin.ConcatenateMode aSequenceNumberConcatenateMode) Sets theConcatenateModefor the sequence numberConcatenateModeproperty.PacketOutputStream.Builder.withSequenceNumberInitValue(int aSequenceNumberInitValue) Sets the sequence number initial value for the sequence number initial value property.PacketOutputStream.Builder.withSequenceNumberWidth(int aSequenceNumberWidth) Sets the sequence number width (in bytes) for the sequence number width (in bytes) property.