Uses of Class
org.refcodes.serial.PropertiesSection
-
Uses of PropertiesSection in org.refcodes.serial
Methods in org.refcodes.serial that return PropertiesSectionModifier and TypeMethodDescriptionstatic PropertiesSectionSerialSugar.propertiesSection()Constructs an emptyPropertiesSectionusing UTF-8 encoding for the payload.static PropertiesSectionSerialSugar.propertiesSection(String aAlias) Constructs an emptyPropertiesSectionusing UTF-8 encoding for the payload.static PropertiesSectionSerialSugar.propertiesSection(String aAlias, Charset aCharset) Constructs aPropertiesSectionwith a payload expected to be encoded with the givenCharset.static PropertiesSectionSerialSugar.propertiesSection(String aAlias, ImmutableProperties aPayload) Constructs aPropertiesSectionwith the givenImmutablePropertiespayload being UTF-8 encoded.static PropertiesSectionSerialSugar.propertiesSection(String aAlias, ImmutableProperties aPayload, Charset aCharset) Constructs aPropertiesSectionwith the givenImmutablePropertiespayload being encoded with the givenCharset.static PropertiesSectionSerialSugar.propertiesSection(String aAlias, ImmutableProperties aPayload, TransmissionMetrics aTransmissionMetrics) Constructs aPropertiesSectionwith the givenImmutablePropertiespayload being encoded with the givenCharset.static PropertiesSectionSerialSugar.propertiesSection(Charset aCharset) Constructs aPropertiesSectionwith a payload expected to be encoded with the givenCharset.static PropertiesSectionSerialSugar.propertiesSection(ImmutableProperties aPayload) Constructs aPropertiesSectionwith the givenImmutablePropertiespayload being UTF-8 encoded.static PropertiesSectionSerialSugar.propertiesSection(ImmutableProperties aPayload, Charset aCharset) Constructs aPropertiesSectionwith the givenImmutablePropertiespayload being encoded with the givenCharset.static PropertiesSectionSerialSugar.propertiesSection(ImmutableProperties aPayload, TransmissionMetrics aTransmissionMetrics) Constructs aPropertiesSectionwith the givenImmutablePropertiespayload being encoded with the givenCharset.PropertiesSection.withPayload(ImmutableProperties aValue)