Uses of Class
org.refcodes.serial.SegmentArraySection
-
Uses of SegmentArraySection in org.refcodes.serial
Methods in org.refcodes.serial that return SegmentArraySection Modifier and Type Method Description static <ARRAY extends Segment>
SegmentArraySection<ARRAY>SerialSugar. arraySection(ARRAY... aSegmentArray)Constructs aSegmentArraySectionwith the givenSegmentelements.static <ARRAY extends Segment>
SegmentArraySection<ARRAY>SerialSugar. arraySection(Class<ARRAY> aSegmentClass)Constructs aSegmentArraySectionwith instances of the array being created using the providedClassinstance.static <ARRAY extends Segment>
SegmentArraySection<ARRAY>SerialSugar. arraySection(org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory)Constructs aSegmentArraySectionwith instances of the array being created using the providedTypeFactoryinstance.static <ARRAY extends Segment>
SegmentArraySection<ARRAY>SerialSugar. arraySection(org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory, ARRAY... aSegmentArray)Constructs aSegmentArraySectionwith the given elements.SegmentArraySection<ARRAY>SegmentArraySection. withArray(ARRAY[] aValue)