Uses of Interface
org.refcodes.serial.SegmentSource
-
-
Uses of SegmentSource in org.refcodes.serial
Subinterfaces of SegmentSource in org.refcodes.serial Modifier and Type Interface Description interfacePort<PM extends PortMetrics>APortenriches aSerialTransceiverwithPortMetricsdescribing theSerialTransceiver's physical properties.interfaceSegmentTransceiverCombines theSegmentTransmitterandSegmentReceiverfunctionality in a single interface to be implemented by a single class so thatSegmentTransmitterandSegmentReceiverfunctionality can be provided by a single instance.interfaceSegmentTransmitterTheSegmentTransmitteris used to transmitSegmentinstances in a unified way.interfaceSerialTransceiverinterfaceSerialTransmitterASerialTransmitteris used to write data to a serial port or the like.Classes in org.refcodes.serial that implement SegmentSource Modifier and Type Class Description classAbstractPort<PM extends PortMetrics>AAbstractPortis a basePortimplementationclassAbstractPortDecorator<PM extends PortMetrics>classCrossoverLoopbackPortTheCrossoverLoopbackPortis an in-memory implementation of aPortwhich loops its output directly to the "connected"LoopbackPortcounterpart ("other end of the wire").classLoopbackPortTheLoopbackPortis an in-memory implementation of aPortwhich loops its output directly back to its input.
-