-
class
Thrown in case a transmission's CRC checksum did not match the according
calculated CRC checksum.
class
Thrown in case a
Sequence CRC checksum did not match the according
calculated CRC checksum.
class
class
class
Thrown in case a flow control failed.
class
Thrown in case a flow control failed due t a timeout.
class
Thrown in case a flow control failed due t a timeout.
class
Thrown in case there is no such port found.
class
class
Thrown in case a given
Sequence cannot be processed.