StringSegment |
StringSegment.Builder.build() |
|
static StringSegment |
SerialSugar.stringSegment() |
Instantiates a new string segment.
|
static StringSegment |
SerialSugar.stringSegment(int aLengthWidth) |
Constructs an empty allocation value with the given number of bytes used
to specify the decoratee's length and a
TransmissionMetrics.DEFAULT_ENDIANESS endian representation of
the decoratee's length.
|
static StringSegment |
SerialSugar.stringSegment(int aLengthWidth,
org.refcodes.numerical.Endianess aEndianess) |
Constructs an empty allocation value with the given number of bytes used
to specify the decoratee's length and the provided Endianess
representation of the decoratee's length.
|
static StringSegment |
SerialSugar.stringSegment(String aValue) |
|
static StringSegment |
SerialSugar.stringSegment(String aValue,
int aLengthWidth) |
|
static StringSegment |
SerialSugar.stringSegment(String aValue,
int aLengthWidth,
org.refcodes.numerical.Endianess aEndianess) |
|
static StringSegment |
SerialSugar.stringSegment(String aAlias,
String aValue) |
|
static StringSegment |
SerialSugar.stringSegment(String aAlias,
String aValue,
int aLengthWidth) |
|
static StringSegment |
SerialSugar.stringSegment(String aAlias,
String aValue,
int aLengthWidth,
org.refcodes.numerical.Endianess aEndianess) |
|
static StringSegment |
SerialSugar.stringSegment(String aAlias,
String aValue,
Charset aEncoding) |
|
static StringSegment |
SerialSugar.stringSegment(String aAlias,
String aValue,
Charset aEncoding,
int aLengthWidth) |
|
static StringSegment |
SerialSugar.stringSegment(String aAlias,
String aValue,
Charset aEncoding,
int aLengthWidth,
org.refcodes.numerical.Endianess aEndianess) |
|
static StringSegment |
SerialSugar.stringSegment(String aAlias,
String aValue,
Charset aEncoding,
org.refcodes.numerical.Endianess aEndianess) |
|
static StringSegment |
SerialSugar.stringSegment(String aAlias,
String aValue,
org.refcodes.numerical.Endianess aEndianess) |
|
static StringSegment |
SerialSugar.stringSegment(String aAlias,
String aValue,
TransmissionMetrics aTransmissionMetrics) |
Constructs an according instance from the given configuration.
|
static StringSegment |
SerialSugar.stringSegment(String aValue,
Charset aEncoding) |
|
static StringSegment |
SerialSugar.stringSegment(String aValue,
Charset aEncoding,
int aLengthWidth) |
|
static StringSegment |
SerialSugar.stringSegment(String aValue,
Charset aEncoding,
int aLengthWidth,
org.refcodes.numerical.Endianess aEndianess) |
|
static StringSegment |
SerialSugar.stringSegment(String aValue,
Charset aEncoding,
org.refcodes.numerical.Endianess aEndianess) |
|
static StringSegment |
SerialSugar.stringSegment(String aValue,
org.refcodes.numerical.Endianess aEndianess) |
|
static StringSegment |
SerialSugar.stringSegment(String aValue,
TransmissionMetrics aTransmissionMetrics) |
Constructs an according instance from the given configuration.
|
static StringSegment |
SerialSugar.stringSegment(Charset aEncoding) |
|
static StringSegment |
SerialSugar.stringSegment(Charset aEncoding,
int aLengthWidth) |
|
static StringSegment |
SerialSugar.stringSegment(Charset aEncoding,
int aLengthWidth,
org.refcodes.numerical.Endianess aEndianess) |
|
static StringSegment |
SerialSugar.stringSegment(Charset aEncoding,
org.refcodes.numerical.Endianess aEndianess) |
|
static StringSegment |
SerialSugar.stringSegment(org.refcodes.numerical.Endianess aEndianess) |
Constructs an empty allocation value with a width of
TransmissionMetrics.DEFAULT_LENGTH_WIDTH bytes used to specify
the decoratee's length and the provided Endianess representation
of the decoratee's length.
|
static StringSegment |
SerialSugar.stringSegment(TransmissionMetrics aTransmissionMetrics) |
Constructs an according instance from the given configuration.
|
StringSegment |
StringSegment.withPayload(String aValue) |