Module org.refcodes.serial
Package org.refcodes.serial
-
Interface Summary Interface Description AcknowledgeMagicBytesAccessor Provides an accessor for a acknowledge magic bytes property.AcknowledgeMagicBytesAccessor.AcknowledgeMagicBytesBuilder<B extends AcknowledgeMagicBytesAccessor.AcknowledgeMagicBytesBuilder<B>> Provides a builder method for a acknowledge magic bytes property returning the builder for applying multiple build operations.AcknowledgeMagicBytesAccessor.AcknowledgeMagicBytesMutator Provides a mutator for a acknowledge magic bytes property.AcknowledgeMagicBytesAccessor.AcknowledgeMagicBytesProperty Provides a acknowledge magic bytes property.AcknowledgeRetryNumberAccessor Provides an accessor for a acknowledge retry number.AcknowledgeRetryNumberAccessor.AcknowledgeRetryNumberBuilder<B extends AcknowledgeRetryNumberAccessor.AcknowledgeRetryNumberBuilder<B>> Provides a builder method for a acknowledge retry number returning the builder for applying multiple build operations.AcknowledgeRetryNumberAccessor.AcknowledgeRetryNumberMutator Provides a mutator for a acknowledge retry number.AcknowledgeRetryNumberAccessor.AcknowledgeRetryNumberProperty Provides a acknowledge retry number.A acknowledge retry number is the overall number of retries to use when counting retries.AcknowledgeSegmentPackagerAccessor Provides an accessor for aSegmentPackagerACK property.AcknowledgeSegmentPackagerAccessor.AcknowledgeSegmentPackagerBuilder<B extends AcknowledgeSegmentPackagerAccessor.AcknowledgeSegmentPackagerBuilder<B>> Provides a builder method for aSegmentPackagerACK property returning the builder for applying multiple build operations.AcknowledgeSegmentPackagerAccessor.AcknowledgeSegmentPackagerMutator Provides a mutator for aSegmentPackagerACK property.AcknowledgeSegmentPackagerAccessor.AcknowledgeSegmentPackagerProperty Provides aSegmentPackagerACK property.AcknowledgeTimeoutInMsAccessor Provides an accessor for a acknowledge timeout in milliseconds property.AcknowledgeTimeoutInMsAccessor.AcknowledgeTimeoutInMsBuilder<B extends AcknowledgeTimeoutInMsAccessor.AcknowledgeTimeoutInMsBuilder<B>> Provides a builder method for the acknowledge timeout property returning the builder for applying multiple build operations.AcknowledgeTimeoutInMsAccessor.AcknowledgeTimeoutInMsMutator Provides a mutator for a acknowledge timeout in milliseconds property.AcknowledgeTimeoutInMsAccessor.AcknowledgeTimeoutInMsProperty Provides a acknowledge timeout in milliseconds property.AllocLengthAccessor Provides an accessor for a allocation length property.AllocLengthAccessor.AllocLengthBuilder<B extends AllocLengthAccessor.AllocLengthBuilder<B>> Provides a builder method for a allocation length property returning the builder for applying multiple build operations.AllocLengthAccessor.AllocLengthMutator Provides a mutator for a allocation length property.AllocLengthAccessor.AllocLengthProperty Provides a allocation length property.ArraySection<ARRAY extends Transmission> ArraySegment<SEGMENT extends Segment> ArrayTransmission<ARRAY extends Transmission> ClearToSendMagicBytesAccessor Provides an accessor for a CTS ("clear-to-send") magic bytes property.ClearToSendMagicBytesAccessor.ClearToSendMagicBytesBuilder<B extends ClearToSendMagicBytesAccessor.ClearToSendMagicBytesBuilder<B>> Provides a builder method for a CTS ("clear-to-send") magic bytes property returning the builder for applying multiple build operations.ClearToSendMagicBytesAccessor.ClearToSendMagicBytesMutator Provides a mutator for a CTS ("clear-to-send") magic bytes property.ClearToSendMagicBytesAccessor.ClearToSendMagicBytesProperty Provides a CTS ("clear-to-send") magic bytes property.ClearToSendRetryNumberAccessor Provides an accessor for a CTS ("clear-to-send") retry number.ClearToSendRetryNumberAccessor.ClearToSendRetryNumberBuilder<B extends ClearToSendRetryNumberAccessor.ClearToSendRetryNumberBuilder<B>> Provides a builder method for a CTS ("clear-to-send") retry number returning the builder for applying multiple build operations.ClearToSendRetryNumberAccessor.ClearToSendRetryNumberMutator Provides a mutator for a CTS ("clear-to-send") retry number.ClearToSendRetryNumberAccessor.ClearToSendRetryNumberProperty Provides a CTS ("clear-to-send") retry number.A CTS ( "clear-to-send") retry number is the overall number of retries to use when counting retries.ClearToSendSegmentPackagerAccessor Provides an accessor for aSegmentPackagerCTS ("clear-to-send") property.ClearToSendSegmentPackagerAccessor.ClearToSendSegmentPackagerBuilder<B extends ClearToSendSegmentPackagerAccessor.ClearToSendSegmentPackagerBuilder<B>> Provides a builder method for aSegmentPackagerCTS ("clear-to-send") property returning the builder for applying multiple build operations.ClearToSendSegmentPackagerAccessor.ClearToSendSegmentPackagerMutator Provides a mutator for aSegmentPackagerCTS ("clear-to-send") property.ClearToSendSegmentPackagerAccessor.ClearToSendSegmentPackagerProperty Provides aSegmentPackagerCTS ("clear-to-send") property.ClearToSendTimeoutInMsAccessor Provides an accessor for a CTS ("clear-to-send") timeout in milliseconds property.ClearToSendTimeoutInMsAccessor.ClearToSendTimeoutInMsBuilder<B extends ClearToSendTimeoutInMsAccessor.ClearToSendTimeoutInMsBuilder<B>> Provides a builder method for a the CTS ("clear-to-send") timeout property returning the builder for applying multiple build operations.ClearToSendTimeoutInMsAccessor.ClearToSendTimeoutInMsMutator Provides a mutator for a CTS ("clear-to-send") timeout in milliseconds property.ClearToSendTimeoutInMsAccessor.ClearToSendTimeoutInMsProperty Provides a CTS ("clear-to-send") timeout in milliseconds property.DecoratorSection<DECORATEE extends Transmission> TheDecoratorSectioninterface provided means to access a decoratedTransmissionwith the means of aSection.DecoratorSegment<DECORATEE extends Transmission> TheDecoratorSegmentinterface provided means to access a decoratedTransmissionwith the means of aSegment.DynamicTypeTransmission heDynamicTypeTransmissionrepresents aTransmissionwhich's internal raw data is created from provided types at runtime and which's internal raw data is used to create provided types at runtime.EndOfStringByteAccessor Provides an accessor for a end of string byte property.EndOfStringByteAccessor.EndOfStringByteBuilder<B extends EndOfStringByteAccessor.EndOfStringByteBuilder<B>> Provides a builder method for a end of string byte property returning the builder for applying multiple build operations.EndOfStringByteAccessor.EndOfStringByteMutator Provides a mutator for a end of string byte property.EndOfStringByteAccessor.EndOfStringByteProperty Provides a end of string byte property.EnquiryStandbyTimeInMsAccessor Provides an accessor for a ENQ ("enquiry") timeout in milliseconds property.EnquiryStandbyTimeInMsAccessor.EnquiryStandbyTimeInMsBuilder<B extends EnquiryStandbyTimeInMsAccessor.EnquiryStandbyTimeInMsBuilder<B>> Provides a builder method for a the ENQ ("enquiry") timeout property returning the builder for applying multiple build operations.EnquiryStandbyTimeInMsAccessor.EnquiryStandbyTimeInMsMutator Provides a mutator for a ENQ ("enquiry") timeout in milliseconds property.EnquiryStandbyTimeInMsAccessor.EnquiryStandbyTimeInMsProperty Provides a ENQ ("enquiry") timeout in milliseconds property.ErrorCorrectionTransmission TheErrorCorrectionTransmissionrepresents the base error correction transmission definition.HandshakeMagicBytesAccessor Provides an accessor for a handshake magic bytes property.HandshakeMagicBytesAccessor.HandshakeMagicBytesBuilder<B extends HandshakeMagicBytesAccessor.HandshakeMagicBytesBuilder<B>> Provides a builder method for a handshake magic bytes property returning the builder for applying multiple build operations.HandshakeMagicBytesAccessor.HandshakeMagicBytesMutator Provides a mutator for a handshake magic bytes property.HandshakeMagicBytesAccessor.HandshakeMagicBytesProperty Provides a handshake magic bytes property.InputReturnStreamAccessor Provides an accessor for an input return stream property.InputReturnStreamAccessor.InputReturnStreamBuilder<B extends InputReturnStreamAccessor.InputReturnStreamBuilder<?>> Provides a mutator for an input return stream property.InputReturnStreamAccessor.InputReturnStreamMutator Provides a mutator for an input return stream property.InputReturnStreamAccessor.InputReturnStreamProperty Provides an input return stream property.IoHeuristicsTimeToLiveInMsAccessor Provides an accessor for a IO heuristics TTL (time to live) in milliseconds property.IoHeuristicsTimeToLiveInMsAccessor.IoHeuristicsTimeToLiveInMsBuilder<B extends IoHeuristicsTimeToLiveInMsAccessor.IoHeuristicsTimeToLiveInMsBuilder<B>> Provides a builder method for the IO heuristics TTL (time to live) property returning the builder for applying multiple build operations.IoHeuristicsTimeToLiveInMsAccessor.IoHeuristicsTimeToLiveInMsMutator Provides a mutator for a IO heuristics TTL (time to live) in milliseconds property.IoHeuristicsTimeToLiveInMsAccessor.IoHeuristicsTimeToLiveInMsProperty Provides a IO heuristics TTL (time to live) in milliseconds property.LengthWidthAccessor Provides an accessor for a length width (in bytes) property.LengthWidthAccessor.LengthWidthBuilder<B extends LengthWidthAccessor.LengthWidthBuilder<B>> Provides a builder method for a length width (in bytes) property returning the builder for applying multiple build operations.LengthWidthAccessor.LengthWidthMutator Provides a mutator for a length width (in bytes) property.LengthWidthAccessor.LengthWidthProperty Provides a length width (in bytes) property.MagicBytesAccessor Provides an accessor for a magic byte array property.MagicBytesAccessor.MagicBytesBuilder<B extends MagicBytesAccessor.MagicBytesBuilder<B>> Provides a builder method for a magic byte array property returning the builder for applying multiple build operations.MagicBytesAccessor.MagicBytesMutator Provides a mutator for a magic byte array property.MagicBytesAccessor.MagicBytesProperty Provides a magic byte array property.MagicBytesLengthAccessor Provides an accessor for a magic bytes length property.MagicBytesLengthAccessor.MagicBytesLengthBuilder<B extends MagicBytesLengthAccessor.MagicBytesLengthBuilder<B>> Provides a builder method for a magic bytes length property returning the builder for applying multiple build operations.MagicBytesLengthAccessor.MagicBytesLengthMutator Provides a mutator for a magic bytes length property.MagicBytesLengthAccessor.MagicBytesLengthProperty Provides a magic bytes length property.OutputReturnStreamAccessor Provides an accessor for an output return stream property.OutputReturnStreamAccessor.OutputReturnStreamBuilder<B extends OutputReturnStreamAccessor.OutputReturnStreamBuilder<?>> Provides a mutator for an output return stream property.OutputReturnStreamAccessor.OutputReturnStreamMutator Provides a mutator for an output return stream property.OutputReturnStreamAccessor.OutputReturnStreamProperty Provides an output return stream property.PacketLengthWidthAccessor Provides an accessor for a packet length width (in bytes) property.PacketLengthWidthAccessor.PacketLengthWidthBuilder<B extends PacketLengthWidthAccessor.PacketLengthWidthBuilder<B>> Provides a builder method for a packet length width (in bytes) property returning the builder for applying multiple build operations.PacketLengthWidthAccessor.PacketLengthWidthMutator Provides a mutator for a packet length width (in bytes) property.PacketLengthWidthAccessor.PacketLengthWidthProperty Provides a packet length width (in bytes) property.PacketMagicBytesAccessor Provides an accessor for a packet magic bytes property.PacketMagicBytesAccessor.PacketMagicBytesBuilder<B extends PacketMagicBytesAccessor.PacketMagicBytesBuilder<B>> Provides a builder method for a packet magic bytes property returning the builder for applying multiple build operations.PacketMagicBytesAccessor.PacketMagicBytesMutator Provides a mutator for a packet magic bytes property.PacketMagicBytesAccessor.PacketMagicBytesProperty Provides a packet magic bytes property.PacketSegmentPackagerAccessor Provides an accessor for a packetSegmentPackagerproperty.PacketSegmentPackagerAccessor.PacketSegmentPackagerBuilder<B extends PacketSegmentPackagerAccessor.PacketSegmentPackagerBuilder<B>> Provides a builder method for a packetSegmentPackagerproperty returning the builder for applying multiple build operations.PacketSegmentPackagerAccessor.PacketSegmentPackagerMutator Provides a mutator for a packetSegmentPackagerproperty.PacketSegmentPackagerAccessor.PacketSegmentPackagerProperty Provides a packetSegmentPackagerproperty.PayloadSection<T> ThePayloadSectioninterfaces defines aSectionwith a payload.PayloadSegment<T> ThePayloadSegmentinterfaces defines aSegmentwith a payload.PayloadTransmission<T> APayloadTransmissionrepresents aTransmissioncarrying a payload (value)PingMagicBytesAccessor Provides an accessor for a ping magic bytes property.PingMagicBytesAccessor.PingMagicBytesBuilder<B extends PingMagicBytesAccessor.PingMagicBytesBuilder<B>> Provides a builder method for a ping magic bytes property returning the builder for applying multiple build operations.PingMagicBytesAccessor.PingMagicBytesMutator Provides a mutator for a ping magic bytes property.PingMagicBytesAccessor.PingMagicBytesProperty Provides a ping magic bytes property.PingRetryNumberAccessor Provides an accessor for a ping retry number.PingRetryNumberAccessor.PingRetryNumberBuilder<B extends PingRetryNumberAccessor.PingRetryNumberBuilder<B>> Provides a builder method for a ping retry number returning the builder for applying multiple build operations.PingRetryNumberAccessor.PingRetryNumberMutator Provides a mutator for a ping retry number.PingRetryNumberAccessor.PingRetryNumberProperty Provides a ping retry number.A ping retry number is the overall number of retries to use when counting retries.PingTimeoutInMsAccessor Provides an accessor for a ping timeout in milliseconds property.PingTimeoutInMsAccessor.PingTimeoutInMsBuilder<B extends PingTimeoutInMsAccessor.PingTimeoutInMsBuilder<B>> Provides a builder method for the ping timeout property returning the builder for applying multiple build operations.PingTimeoutInMsAccessor.PingTimeoutInMsMutator Provides a mutator for a ping timeout in milliseconds property.PingTimeoutInMsAccessor.PingTimeoutInMsProperty Provides a ping timeout in milliseconds property.PongMagicBytesAccessor Provides an accessor for a pong magic bytes property.PongMagicBytesAccessor.PongMagicBytesBuilder<B extends PongMagicBytesAccessor.PongMagicBytesBuilder<B>> Provides a builder method for a pong magic bytes property returning the builder for applying multiple build operations.PongMagicBytesAccessor.PongMagicBytesMutator Provides a mutator for a pong magic bytes property.PongMagicBytesAccessor.PongMagicBytesProperty Provides a pong magic bytes property.Port<PM extends PortMetrics> APortenriches aSerialTransceiverwithPortMetricsdescribing theSerialTransceiver's physical properties.PortHub<PORT extends Port<PM>,PM extends PortMetrics> PortMetrics ThePortMetricsdescribe aPort's properties.PortMetricsAccessor<PM extends PortMetrics> Provides an accessor for aPortMetricsproperty.PortMetricsAccessor.PortMetricsBuilder<PM extends PortMetrics,B extends PortMetricsAccessor.PortMetricsBuilder<PM,B>> Provides a builder method for aPortMetricsproperty returning the builder for applying multiple build operations.PortMetricsAccessor.PortMetricsMutator<PM extends PortMetrics> Provides a mutator for aPortMetricsproperty.PortMetricsAccessor.PortMetricsProperty<PM extends PortMetrics> Provides aPortMetricsproperty.ReadyToReceiveMagicBytesAccessor Provides an accessor for a RTR ("ready-to-receive") magic bytes property.ReadyToReceiveMagicBytesAccessor.ReadyToReceiveMagicBytesBuilder<B extends ReadyToReceiveMagicBytesAccessor.ReadyToReceiveMagicBytesBuilder<B>> Provides a builder method for a RTR ("ready-to-receive") magic bytes property returning the builder for applying multiple build operations.ReadyToReceiveMagicBytesAccessor.ReadyToReceiveMagicBytesMutator Provides a mutator for a RTR ("ready-to-receive") magic bytes property.ReadyToReceiveMagicBytesAccessor.ReadyToReceiveMagicBytesProperty Provides a RTR ("ready-to-receive") magic bytes property.ReadyToReceiveRetryNumberAccessor Provides an accessor for a RTR ("ready-to-receive") retry number.ReadyToReceiveRetryNumberAccessor.ReadyToReceiveRetryNumberBuilder<B extends ReadyToReceiveRetryNumberAccessor.ReadyToReceiveRetryNumberBuilder<B>> Provides a builder method for a RTR ("ready-to-receive") retry number returning the builder for applying multiple build operations.ReadyToReceiveRetryNumberAccessor.ReadyToReceiveRetryNumberMutator Provides a mutator for a RTR ("ready-to-receive") retry number.ReadyToReceiveRetryNumberAccessor.ReadyToReceiveRetryNumberProperty Provides a RTR ("ready-to-receive") retry number.A RTR ( "ready-to-receive") retry number is the overall number of retries to use when counting retries.ReadyToReceiveSegmentPackagerAccessor Provides an accessor for aSegmentPackagerRTR ("ready-to-receive") property.ReadyToReceiveSegmentPackagerAccessor.ReadyToReceiveSegmentPackagerBuilder<B extends ReadyToReceiveSegmentPackagerAccessor.ReadyToReceiveSegmentPackagerBuilder<B>> Provides a builder method for aSegmentPackagerRTR ("ready-to-receive") property returning the builder for applying multiple build operations.ReadyToReceiveSegmentPackagerAccessor.ReadyToReceiveSegmentPackagerMutator Provides a mutator for aSegmentPackagerRTR ("ready-to-receive") property.ReadyToReceiveSegmentPackagerAccessor.ReadyToReceiveSegmentPackagerProperty Provides aSegmentPackagerRTR ("ready-to-receive") property.ReadyToReceiveTimeoutInMsAccessor Provides an accessor for a RTR ("ready-to-receive") timeout in milliseconds property.ReadyToReceiveTimeoutInMsAccessor.ReadyToReceiveTimeoutInMsBuilder<B extends ReadyToReceiveTimeoutInMsAccessor.ReadyToReceiveTimeoutInMsBuilder<B>> Provides a builder method for a the RTR ("ready-to-receive") timeout property returning the builder for applying multiple build operations.ReadyToReceiveTimeoutInMsAccessor.ReadyToReceiveTimeoutInMsMutator Provides a mutator for a RTR ("ready-to-receive") timeout in milliseconds property.ReadyToReceiveTimeoutInMsAccessor.ReadyToReceiveTimeoutInMsProperty Provides a RTR ("ready-to-receive") timeout in milliseconds property.ReadyToReceiveTransmission TheReadyToReceiveTransmissioninterface defines functionality for achieving a RTR "software" handshake between a receiver having the active RTR ("ready-to-receive") role and a transmitter being CTS ("clear-to-send") where the transmitter waits for a RTR signal from the receiver (the receiver signals to be ready for receiving data by issuing an RTR signal to the transmitter):TRANSMITTER RECEIVER | | Wait till enquiry-timeout | | Send RTR magic-bytes for RTR magic-bytes |←-----RTR------| Try RTR retry-number of times | | Wait till RTR retry-timeout/retry Send payload upon RTR | | magic-bytes or break-out |----PAYLOAD---→| Receive payload upon enquiry-timeout | |Handshake specific signals are only transmitted through the return channel, the data channel is only used indirectly for handshaking by transporting the payload data in response to the return channel signals.ReadyToSendMagicBytesAccessor Provides an accessor for a RTS ("ready-to-send") magic bytes property.ReadyToSendMagicBytesAccessor.ReadyToSendMagicBytesBuilder<B extends ReadyToSendMagicBytesAccessor.ReadyToSendMagicBytesBuilder<B>> Provides a builder method for a RTS ("ready-to-send") magic bytes property returning the builder for applying multiple build operations.ReadyToSendMagicBytesAccessor.ReadyToSendMagicBytesMutator Provides a mutator for a RTS ("ready-to-send") magic bytes property.ReadyToSendMagicBytesAccessor.ReadyToSendMagicBytesProperty Provides a RTS ("ready-to-send") magic bytes property.ReadyToSendRetryNumberAccessor Provides an accessor for a RTS ("ready-to-send") retry number.ReadyToSendRetryNumberAccessor.ReadyToSendRetryNumberBuilder<B extends ReadyToSendRetryNumberAccessor.ReadyToSendRetryNumberBuilder<B>> Provides a builder method for a RTS ("ready-to-send") retry number returning the builder for applying multiple build operations.ReadyToSendRetryNumberAccessor.ReadyToSendRetryNumberMutator Provides a mutator for a RTS ("ready-to-send") retry number.ReadyToSendRetryNumberAccessor.ReadyToSendRetryNumberProperty Provides a RTS ("ready-to-send") retry number.A RTS ( "ready-to-send") retry number is the overall number of retries to use when counting retries.ReadyToSendSegmentPackagerAccessor Provides an accessor for aSegmentPackagerRTS ("ready-to-send") property.ReadyToSendSegmentPackagerAccessor.ReadyToSendSegmentPackagerBuilder<B extends ReadyToSendSegmentPackagerAccessor.ReadyToSendSegmentPackagerBuilder<B>> Provides a builder method for aSegmentPackagerRTS ("ready-to-send") property returning the builder for applying multiple build operations.ReadyToSendSegmentPackagerAccessor.ReadyToSendSegmentPackagerMutator Provides a mutator for aSegmentPackagerRTS ("ready-to-send") property.ReadyToSendSegmentPackagerAccessor.ReadyToSendSegmentPackagerProperty Provides aSegmentPackagerRTS ("ready-to-send") property.ReadyToSendTimeoutInMsAccessor Provides an accessor for a RTS ("ready-to-send") timeout in milliseconds property.ReadyToSendTimeoutInMsAccessor.ReadyToSendTimeoutInMsBuilder<B extends ReadyToSendTimeoutInMsAccessor.ReadyToSendTimeoutInMsBuilder<B>> Provides a builder method for a the RTS ("ready-to-send") timeout property returning the builder for applying multiple build operations.ReadyToSendTimeoutInMsAccessor.ReadyToSendTimeoutInMsMutator Provides a mutator for a RTS ("ready-to-send") timeout in milliseconds property.ReadyToSendTimeoutInMsAccessor.ReadyToSendTimeoutInMsProperty Provides a RTS ("ready-to-send") timeout in milliseconds property.ReadyToSendTransmission TheReadyToSendTransmissioninterface defines functionality for achieving an RTS "software" handshake between a transmitter having the active RTS ("ready-to-send") role and a receiver confirming being CTS ("clear-to-send") where the receiver waits for a RTS signal from the transmitter (the transmitter signals to be ready for sending data by issuing an RTS signal to the receiver).Section TheSectioninterface enables an implementing type to provide aSequencerepresentation of itself or to transmit itsSequencerepresentation through anOutputStream(with an optional feedbackInputStream) as ofTransmission.transmitTo(OutputStream, InputStream)and to initialize with aSequencerepresentation for itself or to receive aSequencerepresentation for itself through anInputStream(with an optional feedbackOutputStream) as ofSection.receiveFrom(InputStream, int, OutputStream).Section.SectionMixin Default implementation of theSectioninterface providing an implementation of theSection.SectionMixin.receiveFrom(InputStream, int, OutputStream)method using theSection.fromTransmission(Sequence, int)method or theSection.fromTransmission(Sequence, int, int)method..Segment TheSegmentinterface enables an implementing type to provide aSequencerepresentation of itself or to transmit itsSequencerepresentation through anOutputStream(with an optional feedbackInputStream) as ofTransmission.transmitTo(OutputStream, InputStream)and to initialize with aSequencerepresentation for itself or to receive aSequencerepresentation for itself through anInputStream(with an optional feedbackOutputStream) as ofSegment.receiveFrom(InputStream, OutputStream).Segment.SegmentMixin Default implementation of theSegmentinterface providing an implementation of theSegment.SegmentMixin.receiveFrom(InputStream, OutputStream)method using theSegment.fromTransmission(Sequence)method or theSegment.fromTransmission(Sequence, int)method.SegmentConsumer<SEGMENT extends Segment> ASegmentConsumerconsumes aSegmentand is used to create lambda expressions used for asynchronous callback.SegmentDestination TheSegmentDestinationis used to receiveSegmentinstances in a unified way.SegmentPackager TheSegmentPackagerinterface defines methods to package (wrap) aSegmente.g. with aCrcSegmentDecorator.SegmentReceiver TheSegmentReceiveris used to receiveSegmentinstances in a unified way.SegmentSource TheSegmentSourceis used to sendSegmentinstances in a unified way.SegmentTransceiver Combines theSegmentTransmitterandSegmentReceiverfunctionality in a single interface to be implemented by a single class so thatSegmentTransmitterandSegmentReceiverfunctionality can be provided by a single instance.SegmentTransmitter TheSegmentTransmitteris used to transmitSegmentinstances in a unified way.Sequence ASequenceabstracts a byte field providing means to applying complex operations on that byte field.SequenceAccessor Provides an accessor for aSequenceproperty.SequenceAccessor.SequenceBuilder<B extends SequenceAccessor.SequenceBuilder<B>> Provides a builder method for a segment property returning the builder for applying multiple build operations.SequenceAccessor.SequenceMutator Provides a mutator for a segment property.SequenceAccessor.SequenceProperty Provides a segment property.SequenceConsumer ASequenceConsumerconsumes aSequenceand is used to create lambda expressions used for asynchronous callback.SequenceNumberAccessor Provides an accessor for a sequence number property.SequenceNumberAccessor.SequenceNumberBuilder<B extends SequenceNumberAccessor.SequenceNumberBuilder<B>> Provides a builder method for a sequence number property returning the builder for applying multiple build operations.SequenceNumberAccessor.SequenceNumberMutator Provides a mutator for a sequence number property.SequenceNumberAccessor.SequenceNumberProperty Provides a sequence number property.SequenceNumberConcatenateModeAccessor Provides an accessor for aConcatenateModeproperty.SequenceNumberConcatenateModeAccessor.SequenceNumberConcatenateModeBuilder<B extends SequenceNumberConcatenateModeAccessor.SequenceNumberConcatenateModeBuilder<B>> Provides a builder method for a sequence numberConcatenateModeproperty returning the builder for applying multiple build operations.SequenceNumberConcatenateModeAccessor.SequenceNumberConcatenateModeMutator Provides a mutator for a sequence numberConcatenateModeproperty.SequenceNumberConcatenateModeAccessor.SequenceNumberConcatenateModeProperty Provides a sequence numberConcatenateModeproperty.SequenceNumberInitValueAccessor Provides an accessor for a sequence number initial value property.SequenceNumberInitValueAccessor.SequenceNumberInitValueBuilder<B extends SequenceNumberInitValueAccessor.SequenceNumberInitValueBuilder<B>> Provides a builder method for a sequence number initial value property returning the builder for applying multiple build operations.SequenceNumberInitValueAccessor.SequenceNumberInitValueMutator Provides a mutator for a sequence number initial value property.SequenceNumberInitValueAccessor.SequenceNumberInitValueProperty Provides a sequence number initial value property.SequenceNumberWidthAccessor Provides an accessor for a sequence number width (in bytes) property.SequenceNumberWidthAccessor.SequenceNumberWidthBuilder<B extends SequenceNumberWidthAccessor.SequenceNumberWidthBuilder<B>> Provides a builder method for a sequence number width (in bytes) property returning the builder for applying multiple build operations.SequenceNumberWidthAccessor.SequenceNumberWidthMutator Provides a mutator for a sequence number width (in bytes) property.SequenceNumberWidthAccessor.SequenceNumberWidthProperty Provides a sequence number width (in bytes) property.SerialReceiver ASerialReceiveris used to read data from a serial port or the like.SerialTransceiver SerialTransmitter ASerialTransmitteris used to write data to a serial port or the like.StopAndWaitPacketStreamTransmission TheStopAndWaitPacketStreamTransmissioninterface defines the base functionality required by aTransmissioninstance for providing block stream functionality.StopAndWaitTransmission TheStopAndWaitTransmissionis the most simple implementation of the ARQ (Automatic repeat request) protocol.Transmission TheTransmissioninterface enables an implementing type to provide aSequencerepresentation of itself or to transmit itsSequencerepresentation through anOutputStream(with an optional feedbackInputStream) as ofTransmission.transmitTo(OutputStream, InputStream).Transmission.TransmissionMixin Default implementation of theTransmissioninterface providing an implementation of theTransmission.TransmissionMixin.transmitTo(OutputStream, InputStream)method using theTransmission.toSequence()method.TransmissionAccessor<T extends Transmission> Provides an accessor for aTransmissionproperty (as of the decorator pattern).TransmissionAccessor.TransmissionBuilder<T,B extends TransmissionAccessor.TransmissionBuilder<T,B>> Provides a builder method for aTransmissionproperty returning the builder for applying multiple build operations.TransmissionAccessor.TransmissionMutator<T extends Transmission> Provides a mutator for aTransmissionproperty.TransmissionAccessor.TransmissionProperty<T extends Transmission> Provides aTransmissionproperty.TransmissionComposite<CHILD extends Transmission> TransmissionMetricsAccessor Provides an accessor for aTransmissionMetricsproperty.TransmissionMetricsAccessor.TransmissionMetricsBuilder<B extends TransmissionMetricsAccessor.TransmissionMetricsBuilder<B>> Provides a builder method for aTransmissionMetricsproperty returning the builder for applying multiple build operations.TransmissionMetricsAccessor.TransmissionMetricsMutator Provides a mutator for aTransmissionMetricsproperty.TransmissionMetricsAccessor.TransmissionMetricsProperty Provides aTransmissionMetricsproperty.TransmissionRetryNumberAccessor Provides an accessor for a transmission retry number.TransmissionRetryNumberAccessor.TransmissionRetryNumberBuilder<B extends TransmissionRetryNumberAccessor.TransmissionRetryNumberBuilder<B>> Provides a builder method for a transmission retry number returning the builder for applying multiple build operations.TransmissionRetryNumberAccessor.TransmissionRetryNumberMutator Provides a mutator for a transmission retry number.TransmissionRetryNumberAccessor.TransmissionRetryNumberProperty Provides a transmission retry number.A transmission retry number is the overall number of retries to use when counting retries.TransmissionTimeoutInMsAccessor Provides an accessor for a transmission timeout in milliseconds property.TransmissionTimeoutInMsAccessor.TransmissionTimeoutInMsBuilder<B extends TransmissionTimeoutInMsAccessor.TransmissionTimeoutInMsBuilder<B>> Provides a builder method for the transmission timeout property returning the builder for applying multiple build operations.TransmissionTimeoutInMsAccessor.TransmissionTimeoutInMsMutator Provides a mutator for a transmission timeout in milliseconds property.TransmissionTimeoutInMsAccessor.TransmissionTimeoutInMsProperty Provides a transmission timeout in milliseconds property. -
Class Summary Class Description AbstractArrayTransmission<ARRAY extends Transmission> AnAbstractArrayTransmissionis aTransmissionconsisting ofTransmissionelements (an array of elements).AbstractCipherTransmissionDecorator<DECORATEE extends Transmission> An abstract implementation of bijective and inverse functions applied to the decoratee's transmitting and receiving methods.AbstractCrcTransmissionDecorator<DECORATEE extends Transmission> AAbstractCrcTransmissionDecoratorwraps aTransmissioninstance and enriches theTransmissionwith a CRC checksum.AbstractErrorCorrectionTransmissionDecorator<DECORATEE extends Transmission> TheAbstractErrorCorrectionTransmissionDecoratorclass implements a decorator providing base functionality for an error correctionTransmission.AbstractInvertibleTransmissionDecorator<DECORATEE extends Transmission> An abstract implementation of bijective and inverse functions applied to the decoratee's transmitting and receiving methods.AbstractLengthDecoratorSegment<DECORATEE extends Transmission> TheAbstractLengthDecoratorSegmentdecorates a decoratee with a length prefix.AbstractMagicBytesTransmission Magic bytes are usually found (somewhere) at the beginning of a file or a stream.AbstractMagicBytesTransmissionDecorator<DECORATEE extends Transmission> Magic bytes are usually found (somewhere) at the beginning of a file or a stream.AbstractMagicBytesTransmissionMultiplexer<CHILD extends Transmission> TheAbstractMagicBytesTransmissionMultiplexerdispatches a transmission to one of the aggregatedTransmissioninstances depending on the magic number provided by the transmission.AbstractPayloadSection<T> An abstract implementation of aSectionwith payload.AbstractPayloadSegment<T> An abstract implementation of aSegmentwith payload.AbstractPort<PM extends PortMetrics> AAbstractPortis a basePortimplementationAbstractPortDecorator<PM extends PortMetrics> AbstractReadyToReceiveTransmissionDecorator<DECORATEE extends Transmission> TheAbstractReadyToReceiveTransmissionDecoratorclass implements a decorator providingReadyToReceiveTransmissionfunctionality for aTransmission.AbstractReadyToSendTransmissionDecorator<DECORATEE extends Transmission> TheAbstractReadyToSendTransmissionDecoratorclass implements a decorator providingReadyToSendTransmissionfunctionality for aTransmission.AbstractReferenceeLengthSegment<REFERENCEE extends Transmission> TheAbstractReferenceeLengthSegmentrepresents a allocated length value as of the referencedTransmissionelement's length.AbstractSectionDecorator<SECTION extends Section> Convenience class for easily decorating aSection.AbstractSegmentDecorator<SEGMENT extends Segment> Convenience class for easily decorating aSegment.AbstractStopAndWaitPacketStreamTransmissionDecorator<DECORATEE extends Transmission> AAbstractStopAndWaitPacketStreamTransmissionDecoratorwraps aTransmissioninstance and enriches theTransmissionwith packet-stream functionality.AbstractStopAndWaitTransmissionDecorator<DECORATEE extends Transmission> TheAbstractStopAndWaitTransmissionDecoratorclass implements a decorator providingStopAndWaitTransmissionfunctionality for aTransmission.AbstractTransmissionComposite<CHILD extends Transmission> AAbstractTransmissionCompositeis aTransmissionconsisting ofTransmissionelements with each element.AbstractTransmissionDecorator<DECORATEE extends Transmission> An abstract implementation of aTransmissiondecorating anotherTransmission.AllocSectionDecoratorSegment<DECORATEE extends Section> AnAllocSectionDecoratorSegmentenriches anSectionwith an allocation declaration being prefixed to the enrichedSection.AllocSegmentBody<DECORATEE extends Section> AnAllocSegmentBodyprovides anSegmentwith an allocation length.AllocSegmentHead AnAllocSegmentHeadprovides the allocation length for aAllocSegmentBody.AsciizArraySegment AsciizSegment TheAsciizSegmentis an implementation of aSegmentcarrying an ASCII encodedStringas payload, terminated by a 0 ("zero") indicating its end.AssertMagicBytesSectionDecorator<DECORATEE extends Section> TheAssertMagicBytesSectionDecoratorextends theMagicBytesSectionDecoratorand enforces the configured magic bytes to match the received magic bytes (as ofAssertMagicBytesSectionDecorator.fromTransmission(Sequence, int, int)andAssertMagicBytesSectionDecorator.receiveFrom(java.io.InputStream, int, java.io.OutputStream)or the like).AssertMagicBytesSegment TheAssertMagicBytesSegmentextends theMagicBytesSegmentand enforces the configured magic bytes to match the received magic bytes (as ofSegment.fromTransmission(Sequence)andSegment.SegmentMixin.receiveFrom(java.io.InputStream, java.io.OutputStream)or the like).AssertMagicBytesSegmentDecorator<DECORATEE extends Segment> TheAssertMagicBytesSegmentDecoratorextends theMagicBytesSegmentDecoratorand enforces the configured magic bytes to match the received magic bytes (as ofSegment.fromTransmission(Sequence)andAssertMagicBytesSegmentDecorator.receiveFrom(java.io.InputStream, java.io.OutputStream)or the like).BooleanArraySection TheBooleanArraySectionis an implementation of aSectioncarrying a boolean array as payload.BooleanSegment TheBooleanSegmentis an implementation of aSegmentcarrying in boolean value as value.BoundedSequenceDecorator TheBoundedSequenceDecoratordecorates aSequencewhilst bounding its size to a given maximum size (to be set viaBoundedSequenceDecorator.setLength(int)) .BreakerSectionDecorator<DECORATEE extends Section> TheBreakerSectionDecoratoris aDecoratorSectionbuild to test error detection and error correctionTransmissionimplementations such as theCrcSectionDecoratoror theStopAndWaitSectionDecorator.BreakerSegmentDecorator<DECORATEE extends Segment> TheBreakerSegmentDecoratoris aDecoratorSegmentbuild to test error detection and error correctionTransmissionimplementations such as theCrcSegmentDecoratoror theStopAndWaitSegmentDecorator.ByteArraySection TheByteArraySectionis an implementation of aSectioncarrying a byte array as payload.ByteArraySequence AByteArraySequenceimplements theSequenceinterface by using chunks of byte arrays, therewith reducing array copy operations when working with byte fields.ByteSegment TheByteSegmentis an implementation of aSegmentcarrying in byte value as payload.CharArraySection TheCharArraySectionis an implementation of aPayloadSectioncarrying a char array as payload.CharSection TheCharSectionis an implementation of aSectioncarrying a char value as payload.CipherSectionDecorator<DECORATEE extends Section> ACipherSectionDecoratoris a transmission applying anInvertibleon outgoing bytes (as ofTransmission.transmitTo(java.io.OutputStream)or the like) and the inverse function on any incoming bytes.CipherSegmentDecorator<DECORATEE extends Segment> ACipherSegmentDecoratoris a transmission applying anInvertibleon outgoing bytes (as ofTransmission.transmitTo(java.io.OutputStream)or the like) and the inverse function on any incoming bytes.ComplexTypeSegment<T> AComplexTypeSegmenttakes a POJO (a data structure) and creates from its content aSegmentrepresenting the POJO's structure.CrcSectionDecorator<DECORATEE extends Section> CrcSegmentDecorator<DECORATEE extends Segment> CrcSegmentPackager ACrcSegmentPackagerenriches aSegmentwith a CRC checksum.CrossoverLoopbackPort TheCrossoverLoopbackPortis an in-memory implementation of aPortwhich loops its output directly to the "connected"LoopbackPortcounterpart ("other end of the wire").CrossoverLoopbackPortHub ACrossoverLoopbackPortHubis an in-memory implementation of aPortHubwhich'sPortinstances loop their output directly to the "connected"LoopbackPortHubcounterpartPortinstances ("other end of the wire").DoubleArraySection TheDoubleArraySectionis an implementation of aSectioncarrying a double array as payload.DoubleSegment TheDoubleSegmentis an implementation of aSegmentcarrying in double value as payload.DynamicTypeSection TheDynamicTypeSectionrepresents aSectionwhich's internal raw data is created from provided types at runtime and which's internal raw data is used to create provided types at runtime.DynamicTypeSegment TheDynamicTypeSegmentrepresents aSegmentwhich's internal raw data is created from provided types at runtime and which's internal raw data is used to create provided types at runtime.EnumSegment<E extends Enum<E>> TheEnumSegmentis an implementation of aSegmentcarrying an enumeration value as payload.FileSection AFileSectionrepresents aFileon the file system and can be used to receive or to transmit aFile.FixedLengthSequenceSegment TheFixedLengthSequenceSegmentis aSegmentrepresenting aSequenceof a fixed length (as of the arguments passed to one of its constructors).FixedSegmentArraySection<ARRAY extends Segment> AFixedSegmentArraySectionis aSectionconsisting ofSegmentelements with each element of the same (uniform) length (in contrast to theSegmentArraySection).FloatArraySection TheFloatArraySectionis an implementation of aSectioncarrying a float array as payload.FloatSegment TheFloatSegmentis an implementation of aSegmentcarrying in float value as payload.IntArraySection TheIntArraySectionis an implementation of aSectioncarrying an integer array as payload.IntSegment TheIntSegmentis an implementation of aSegmentcarrying an integer value as payload.InvertibleSectionDecorator<DECORATEE extends Section> AInvertibleSectionDecoratoris a transmission applying anInvertibleon outgoing bytes (as ofTransmission.transmitTo(java.io.OutputStream)or the like) and the inverse function on any incoming bytes.InvertibleSegmentDecorator<DECORATEE extends Segment> AInvertibleSegmentDecoratoris a transmission applying anInvertibleon outgoing bytes (as ofTransmission.transmitTo(java.io.OutputStream)or the like) and the inverse function on any incoming bytes.LengthSegment<REFERENCEE extends Transmission> AnLengthSegmentenriches aSegmentwith an allocation declaration computed from the referencedTransmission.LengthSegmentDecoratorSegment<DECORATEE extends Segment> AnLengthSegmentDecoratorSegmentenriches aSegmentwith an allocation declaration being prefixed to the enrichedSegment.LongArraySection TheLongArraySectionis an implementation of aSectioncarrying a long array as payload.LongSegment TheLongSegmentis an implementation of aSegmentcarrying in long value as payload.LoopbackPort TheLoopbackPortis an in-memory implementation of aPortwhich loops its output directly back to its input.LoopbackPortHub TheLoopbackPortHubis a plain implementation of aPortHubserving an infinite number ofLoopbackPortinstances: When callingLoopbackPortHub.toPort(String)and the such port is unknown, then it is created (and from then on known).MagicBytesSectionDecorator<DECORATEE extends Section> Magic bytes are usually found (somewhere) at the beginning of a file or a stream.MagicBytesSectionMultiplexer THeMagicBytesSectionMultiplexerdispatches a transmission to one of the aggregatedSectioninstances depending on the magic number provided by the transmission.MagicBytesSegment Magic bytes are usually found (somewhere) at the beginning of a file or a stream.MagicBytesSegmentDecorator<DECORATEE extends Segment> Magic bytes are usually found (somewhere) at the beginning of a file or a stream.MagicBytesSegmentMultiplexer THeMagicBytesSegmentMultiplexerdispatches a transmission to one of the aggregatedSegmentinstances depending on the magic number provided by the transmission.NullSegment NumberSegment TheNumberSegmentis an implementation of aSegmentcarrying in long an integer value with a configurable width (in bytes) as payload.PacketInputStream ThePacketInputStreamwraps anInputStreamand chunks any data to be written into packets with a sequence number and a block of data.PacketInputStream.Builder Builder to buildPacketInputStreaminstances.PacketOutputStream ThePacketOutputStreamwraps anOutputStreamand chunks any data to be written into packets with a sequence number, a block of data and a CRC checksum.PacketOutputStream.Builder Builder to buildStopAndWaitPacketInputStreaminstances.PropertiesSection ReadyToReceiveSectionDecorator<DECORATEE extends Section> TheReadyToReceiveSectionDecoratorclass implements a decorator providingReadyToReceiveTransmissionfunctionality for aSegment.ReadyToReceiveSectionDecorator.Builder<DECORATEE extends Section> Builder to buildReadyToReceiveSectionDecorator.ReadyToReceiveSegmentDecorator<DECORATEE extends Segment> TheReadyToReceiveSegmentDecoratorclass implements a decorator providingReadyToReceiveTransmissionfunctionality for aSegment.ReadyToReceiveSegmentDecorator.Builder<DECORATEE extends Segment> Builder to buildReadyToReceiveSegmentDecorator.ReadyToSendSectionDecorator<DECORATEE extends Section> TheReadyToSendSectionDecoratorclass implements a decorator providingReadyToSendTransmissionfunctionality for aSegment.ReadyToSendSectionDecorator.Builder<DECORATEE extends Section> Builder to buildReadyToSendSectionDecorator.ReadyToSendSegmentDecorator<DECORATEE extends Segment> TheReadyToSendSegmentDecoratorclass implements a decorator providingReadyToSendTransmissionfunctionality for aSegment.ReadyToSendSegmentDecorator.Builder<DECORATEE extends Segment> Builder to buildReadyToSendSegmentDecorator.ReceiveSegmentConsumerDaemon<SEGMENT extends Segment> A daemon handlingSegmentReceiver.onReceiveSegment(Segment, SegmentConsumer)asynchronous calls.ReceiveSegmentResultDaemon<SEGMENT extends Segment> A daemon handlingSegmentReceiver.onReceiveSegment(Segment)asynchronous calls.Schema The purpose of aSchemais automatically generate documentation of serial data.SectionComposite<ALLOC extends AllocSectionDecoratorSegment<CHILD>,CHILD extends Section> ASectionCompositeis aSectionconsisting ofSectionelements of a variable length each: EachSectionelement in the composite need not be of the same size.SegmentArraySection<ARRAY extends Segment> ASegmentArraySectionis aSegmentconsisting ofSegmentelements with each element of presumably different lengths ( in contrast to theFixedSegmentArraySection).SegmentComposite<CHILD extends Segment> SegmentPackager.DummySegmentPackager Dummy implementation of aSegmentPackagerjust passing through providedSegmentinstances.SegmentResult<SEGMENT extends Segment> ASegmentResultinstance is issued by theSerialReceiverto receive aTransmission's data asynchronously.SequenceInputStream SequenceNumberSegment Convenience class for theNumberSegmentusingTransmissionMetricssequence number related properties to configure theSequenceNumberSegment(being an accordingly configuredNumberSegment).SequenceOutputStream SequenceSection SerialSugar ShortArraySection TheShortArraySectionis an implementation of aSectioncarrying a short array as payload.ShortSegment TheShortSegmentis an implementation of aSegmentcarrying in short value as payload.StopAndWaitPacketInputStream TheStopAndWaitPacketInputStreamwraps anInputStreamand chunks any data to be written into packets with a sequence number and a block of data.StopAndWaitPacketInputStream.Builder Builder to buildStopAndWaitPacketInputStreaminstances.StopAndWaitPacketOutputStream TheStopAndWaitPacketOutputStreamwraps anOutputStreamand chunks any data to be written into packets with a sequence number, a block of data and a CRC checksum.StopAndWaitPacketOutputStream.Builder Builder to buildStopAndWaitPacketInputStreaminstances.StopAndWaitPacketStreamSectionDecorator<DECORATEE extends Section> AStopAndWaitPacketStreamSectionDecoratorchunks any outgoing stream (OutputStream) into blocks of definite length and reassembles any incoming streams (InputStream) from blocks of definite size into a contiguous stream.StopAndWaitPacketStreamSectionDecorator.Builder<DECORATEE extends Section> Builder to buildStopAndWaitSegmentDecorator.StopAndWaitPacketStreamSegmentDecorator<DECORATEE extends Segment> AStopAndWaitPacketStreamSegmentDecoratorchunks any outgoing stream (OutputStream) into blocks of definite length and reassembles any incoming streams (InputStream) from blocks of definite size into a contiguous stream.StopAndWaitPacketStreamSegmentDecorator.Builder<DECORATEE extends Segment> Builder to buildStopAndWaitSegmentDecorator.StopAndWaitSectionDecorator<DECORATEE extends Section> TheStopAndWaitSectionDecoratorclass implements a decorator providingStopAndWaitTransmissionfunctionality for aSection.StopAndWaitSectionDecorator.Builder<DECORATEE extends Section> Builder to buildStopAndWaitSegmentDecorator.StopAndWaitSegmentDecorator<DECORATEE extends Segment> TheStopAndWaitSegmentDecoratorclass implements a decorator providingStopAndWaitTransmissionfunctionality for aSegment.StopAndWaitSegmentDecorator.Builder<DECORATEE extends Segment> Builder to buildStopAndWaitSegmentDecorator.StringArraySection StringSection StringSegment StringSegment.Builder Builder to buildStringSegment.TransmissionMetrics TheTransmissionMetricsinterface represents common parameters required when configuring a transmission.TransmissionMetrics.Builder Builder to buildTransmissionMetrics.TransmitSegmentConsumerDaemon<SEGMENT extends Segment> A daemon handlingSegmentTransmitter.doTransmitSegment(Segment, SegmentConsumer)asynchronous calls.TransmitSegmentResultDaemon<SEGMENT extends Segment> A daemon handlingSegmentTransmitter.doTransmitSegment(Segment)asynchronous calls. -
Enum Summary Enum Description FlowControlType Defines the type of flow control.HandshakeProtocol Enumeration with the various protocol settings when receiving a transmission.MagicBytes TheMagicBytesenumeration provides various predefined magic bytes for common use cases. -
Exception Summary Exception Description BadCrcChecksumException Thrown in case a transmission's CRC checksum did not match the according calculated CRC checksum.BadCrcChecksumSequenceException Thrown in case aSequenceCRC checksum did not match the according calculated CRC checksum.BadMagicBytesException ABadMagicBytesExceptiondenotes bad (unexpected) magic bytes encountered while processing a transmission.BadMagicBytesSequenceException ABadMagicBytesSequenceExceptiondenotes bad (unexpected) magic bytes encountered while processing a transmissionSequence.FlowControlException Thrown in case a flow control failed.FlowControlRetryException Thrown in case a flow control failed due t a timeout.FlowControlTimeoutException Thrown in case a flow control failed due t a timeout.NoSuchPortExcpetion Thrown in case there is no such port found.SerialException Base exception for this package.SerialRuntimeException Base runtime exception for this package.TransmissionException Thrown in case a givenTransmissioncannot be processed.TransmissionSequenceException Thrown in case a givenSequencecannot be processed.