Uses of Package
org.refcodes.serial
-
Classes in org.refcodes.serial used by org.refcodes.serialClassDescriptionAn
AbstractArrayTransmissionis aTransmissionconsisting ofTransmissionelements (an array of elements).An abstract implementation of bijective and inverse functions applied to the decoratee's transmitting and receiving methods.AAbstractCrcTransmissionDecoratorwraps aTransmissioninstance and enriches theTransmissionwith a CRC checksum.TheAbstractErrorCorrectionTransmissionDecoratorclass implements a decorator providing base functionality for an error correctionTransmission.An abstract implementation of bijective and inverse functions applied to the decoratee's transmitting and receiving methods.TheAbstractLengthDecoratorSegmentdecorates a decoratee with a length prefix.Magic bytes are usually found (somewhere) at the beginning of a file or a stream.Magic bytes are usually found (somewhere) at the beginning of a file or a stream.TheAbstractMagicBytesTransmissionMultiplexerdispatches a transmission to one of the aggregatedTransmissioninstances depending on the magic number provided by the transmission.An abstract implementation of aSectionwith payload.An abstract implementation of aSegmentwith payload.AAbstractPortis a basePortimplementation.TheAbstractReadyToReceiveTransmissionDecoratorclass implements a decorator providingReadyToReceiveTransmissionfunctionality for aTransmission.TheAbstractReadyToSendTransmissionDecoratorclass implements a decorator providingReadyToSendTransmissionfunctionality for aTransmission.TheAbstractReferenceeLengthSegmentrepresents a allocated length value as of the referencedTransmissionelement's length.AAbstractStopAndWaitPacketStreamTransmissionDecoratorwraps aTransmissioninstance and enriches theTransmissionwith packet-stream functionality.TheAbstractStopAndWaitTransmissionDecoratorclass implements a decorator providingStopAndWaitTransmissionfunctionality for aTransmission.AAbstractTransmissionCompositeis aTransmissionconsisting ofTransmissionelements with each element.An abstract implementation of aTransmissiondecorating anotherTransmission.Provides an accessor for a acknowledge magic bytes property.Provides a builder method for a acknowledge magic bytes property returning the builder for applying multiple build operations.Provides a mutator for a acknowledge magic bytes property.Provides an accessor for a acknowledge retry number.Provides a builder method for a acknowledge retry number returning the builder for applying multiple build operations.Provides a mutator for a acknowledge retry number.Provides an accessor for aSegmentPackagerACK property.Provides a builder method for aSegmentPackagerACK property returning the builder for applying multiple build operations.Provides a mutator for aSegmentPackagerACK property.Provides an accessor for a acknowledge timeout in milliseconds property.Provides a builder method for the acknowledge timeout property returning the builder for applying multiple build operations.Provides a mutator for a acknowledge timeout in milliseconds property.Provides an accessor for a allocation length property.Provides a builder method for a allocation length property returning the builder for applying multiple build operations.Provides a mutator for a allocation length property.Provides a allocation length property.AnAllocSectionDecoratorSegmentenriches anSectionwith an allocation declaration being prefixed to the enrichedSection.AnAllocSegmentBodyprovides anSegmentwith an allocation length.AnAllocSegmentHeadprovides the allocation length for aAllocSegmentBody.TheAsciizSegmentis an implementation of aSegmentcarrying an ASCII encodedStringas payload, terminated by a 0 ("zero") indicating its end.TheAssertMagicBytesSectionDecoratorextends theMagicBytesSectionDecoratorand enforces the configured magic bytes to match the received magic bytes (as ofAssertMagicBytesSectionDecorator.fromTransmission(Sequence, int, int)andAssertMagicBytesSectionDecorator.receiveFrom(java.io.InputStream, int, java.io.OutputStream)or the like).TheAssertMagicBytesSegmentextends theMagicBytesSegmentand enforces the configured magic bytes to match the received magic bytes (as ofSegment.fromTransmission(Sequence)andSegment.SegmentMixin.receiveFrom(java.io.InputStream, java.io.OutputStream)or the like).TheAssertMagicBytesSegmentDecoratorextends theMagicBytesSegmentDecoratorand enforces the configured magic bytes to match the received magic bytes (as ofSegment.fromTransmission(Sequence)andAssertMagicBytesSegmentDecorator.receiveFrom(java.io.InputStream, java.io.OutputStream)or the like).ABadMagicBytesExceptiondenotes bad (unexpected) magic bytes encountered while processing a transmission.TheBooleanArraySectionis an implementation of aSectioncarrying a boolean array as payload.TheBooleanSegmentis an implementation of aSegmentcarrying in boolean value as value.TheBoundedSequenceDecoratordecorates aSequencewhilst bounding its size to a given maximum size (to be set viaBoundedSequenceDecorator.setLength(int)) .TheBreakerSectionDecoratoris aDecoratorSectionbuild to test error detection and error correctionTransmissionimplementations such as theCrcSectionDecoratoror theStopAndWaitSectionDecorator.TheBreakerSegmentDecoratoris aDecoratorSegmentbuild to test error detection and error correctionTransmissionimplementations such as theCrcSegmentDecoratoror theStopAndWaitSegmentDecorator.TheByteArraySectionis an implementation of aSectioncarrying a byte array as payload.AByteArraySequenceimplements theSequenceinterface by using chunks of byte arrays, therewith reducing array copy operations when working with byte fields.TheByteSegmentis an implementation of aSegmentcarrying in byte value as payload.TheCharArraySectionis an implementation of aPayloadSectioncarrying a char array as payload.TheCharSectionis an implementation of aSectioncarrying a char value as payload.ACipherSectionDecoratoris a transmission applying anInvertibleon outgoing bytes (as ofTransmission.transmitTo(java.io.OutputStream)or the like) and the inverse function on any incoming bytes.ACipherSegmentDecoratoris a transmission applying anInvertibleon outgoing bytes (as ofTransmission.transmitTo(java.io.OutputStream)or the like) and the inverse function on any incoming bytes.Provides an accessor for a CTS ("clear-to-send") magic bytes property.Provides a builder method for a CTS ("clear-to-send") magic bytes property returning the builder for applying multiple build operations.Provides a mutator for a CTS ("clear-to-send") magic bytes property.Provides an accessor for a CTS ("clear-to-send") retry number.Provides a builder method for a CTS ("clear-to-send") retry number returning the builder for applying multiple build operations.Provides a mutator for a CTS ("clear-to-send") retry number.Provides an accessor for aSegmentPackagerCTS ("clear-to-send") property.Provides a builder method for aSegmentPackagerCTS ("clear-to-send") property returning the builder for applying multiple build operations.Provides a mutator for aSegmentPackagerCTS ("clear-to-send") property.Provides an accessor for a CTS ("clear-to-send") timeout in milliseconds property.Provides a builder method for a the CTS ("clear-to-send") timeout property returning the builder for applying multiple build operations.Provides a mutator for a CTS ("clear-to-send") timeout in milliseconds property.AComplexTypeSegmenttakes a POJO (a data structure) and creates from its content aSegmentrepresenting the POJO's structure.ACrcSegmentPackagerenriches aSegmentwith a CRC checksum.TheDecoratorSectioninterface provided means to access a decoratedTransmissionwith the means of aSection.TheDecoratorSegmentinterface provided means to access a decoratedTransmissionwith the means of aSegment.TheDoubleArraySectionis an implementation of aSectioncarrying a double array as payload.TheDoubleSegmentis an implementation of aSegmentcarrying in double value as payload.TheDynamicTypeSectionrepresents aSectionwhich's internal raw data is created from provided types at runtime and which's internal raw data is used to create provided types at runtime.TheDynamicTypeSegmentrepresents aSegmentwhich's internal raw data is created from provided types at runtime and which's internal raw data is used to create provided types at runtime.heDynamicTypeTransmissionrepresents aTransmissionwhich's internal raw data is created from provided types at runtime and which's internal raw data is used to create provided types at runtime.Provides an accessor for a end of string byte property.Provides a builder method for a end of string byte property returning the builder for applying multiple build operations.Provides a mutator for a end of string byte property.Provides an accessor for a ENQ ("enquiry") timeout in milliseconds property.Provides a builder method for a the ENQ ("enquiry") timeout property returning the builder for applying multiple build operations.Provides a mutator for a ENQ ("enquiry") timeout in milliseconds property.TheEnumSegmentis an implementation of aSegmentcarrying an enumeration value as payload.TheErrorCorrectionTransmissionrepresents the base error correction transmission definition.AFileSectionrepresents aFileon the file system and can be used to receive or to transmit aFile.TheFixedLengthSequenceSegmentis aSegmentrepresenting aSequenceof a fixed length (as of the arguments passed to one of its constructors).AFixedSegmentArraySectionis aSectionconsisting ofSegmentelements with each element of the same (uniform) length (in contrast to theSegmentArraySection).TheFloatArraySectionis an implementation of aSectioncarrying a float array as payload.TheFloatSegmentis an implementation of aSegmentcarrying in float value as payload.Thrown in case a flow control failed.Thrown in case a flow control failed due t a timeout.Defines the type of flow control.Provides an accessor for a handshake magic bytes property.Provides a builder method for a handshake magic bytes property returning the builder for applying multiple build operations.Provides a mutator for a handshake magic bytes property.Enumeration with the various protocol settings when receiving a transmission.Provides an accessor for an input return stream property.Provides a mutator for an input return stream property.Provides a mutator for an input return stream property.TheIntArraySectionis an implementation of aSectioncarrying an integer array as payload.TheIntSegmentis an implementation of aSegmentcarrying an integer value as payload.AInvertibleSectionDecoratoris a transmission applying anInvertibleon outgoing bytes (as ofTransmission.transmitTo(java.io.OutputStream)or the like) and the inverse function on any incoming bytes.AInvertibleSegmentDecoratoris a transmission applying anInvertibleon outgoing bytes (as ofTransmission.transmitTo(java.io.OutputStream)or the like) and the inverse function on any incoming bytes.Provides an accessor for a IO heuristics TTL (time to live) in milliseconds property.Provides a builder method for the IO heuristics TTL (time to live) property returning the builder for applying multiple build operations.Provides a mutator for a IO heuristics TTL (time to live) in milliseconds property.AnLengthSegmentenriches aSegmentwith an allocation declaration computed from the referencedTransmission.AnLengthSegmentDecoratorSegmentenriches aSegmentwith an allocation declaration being prefixed to the enrichedSegment.Provides an accessor for a length width (in bytes) property.Provides a builder method for a length width (in bytes) property returning the builder for applying multiple build operations.Provides a mutator for a length width (in bytes) property.TheLongArraySectionis an implementation of aSectioncarrying a long array as payload.TheLongSegmentis an implementation of aSegmentcarrying in long value as payload.TheLoopbackPortis an in-memory implementation of aPortwhich loops its output directly back to its input.TheLoopbackPortHubis a plain implementation of aPortHubserving an infinite number ofLoopbackPortinstances: When callingLoopbackPortHub.toPort(String)and the such port is unknown, then it is created (and from then on known).TheMagicBytesenumeration provides various predefined magic bytes for common use cases.Provides an accessor for a magic byte array property.Provides a builder method for a magic byte array property returning the builder for applying multiple build operations.Provides a mutator for a magic byte array property.Provides a magic byte array property.Provides an accessor for a magic bytes length property.Provides a builder method for a magic bytes length property returning the builder for applying multiple build operations.Provides a mutator for a magic bytes length property.Magic bytes are usually found (somewhere) at the beginning of a file or a stream.THeMagicBytesSectionMultiplexerdispatches a transmission to one of the aggregatedSectioninstances depending on the magic number provided by the transmission.Magic bytes are usually found (somewhere) at the beginning of a file or a stream.Magic bytes are usually found (somewhere) at the beginning of a file or a stream.THeMagicBytesSegmentMultiplexerdispatches a transmission to one of the aggregatedSegmentinstances depending on the magic number provided by the transmission.TheNumberSegmentis an implementation of aSegmentcarrying an integer value with a configurable width (in bytes) as payload.Provides an accessor for an output return stream property.Provides a mutator for an output return stream property.Provides a mutator for an output return stream property.ThePacketInputStreamwraps anInputStreamand chunks any data to be written into packets with a sequence number and a block of data.Builder to buildPacketInputStreaminstances.Provides an accessor for a packet length width (in bytes) property.Provides a builder method for a packet length width (in bytes) property returning the builder for applying multiple build operations.Provides a mutator for a packet length width (in bytes) property.Provides an accessor for a packet magic bytes property.Provides a builder method for a packet magic bytes property returning the builder for applying multiple build operations.Provides a mutator for a packet magic bytes property.ThePacketOutputStreamwraps anOutputStreamand chunks any data to be written into packets with a sequence number, a block of data and a CRC checksum.Builder to buildStopAndWaitPacketInputStreaminstances.Provides an accessor for a packetSegmentPackagerproperty.Provides a builder method for a packetSegmentPackagerproperty returning the builder for applying multiple build operations.Provides a mutator for a packetSegmentPackagerproperty.ThePayloadSectioninterfaces defines aSectionwith a payload.ThePayloadSegmentinterfaces defines aSegmentwith a payload.APayloadTransmissionrepresents aTransmissioncarrying a payload (value).Provides an accessor for a ping magic bytes property.Provides a builder method for a ping magic bytes property returning the builder for applying multiple build operations.Provides a mutator for a ping magic bytes property.Provides an accessor for a ping retry number.Provides a builder method for a ping retry number returning the builder for applying multiple build operations.Provides a mutator for a ping retry number.Provides an accessor for a ping timeout in milliseconds property.Provides a builder method for the ping timeout property returning the builder for applying multiple build operations.Provides a mutator for a ping timeout in milliseconds property.Provides an accessor for a pong magic bytes property.Provides a builder method for a pong magic bytes property returning the builder for applying multiple build operations.Provides a mutator for a pong magic bytes property.APortenriches aSerialTransceiverwithPortMetricsdescribing theSerialTransceiver's physical properties.ThePortMetricsdescribe aPort's properties.Provides an accessor for aPortMetricsproperty.Provides a builder method for aPortMetricsproperty returning the builder for applying multiple build operations.Provides a mutator for aPortMetricsproperty.ThePortTestBenchprovides a test bench merely for diagnostic purposes.Provides an accessor for a RTR ("ready-to-receive") magic bytes property.Provides a builder method for a RTR ("ready-to-receive") magic bytes property returning the builder for applying multiple build operations.Provides a mutator for a RTR ("ready-to-receive") magic bytes property.Provides an accessor for a RTR ("ready-to-receive") retry number.Provides a builder method for a RTR ("ready-to-receive") retry number returning the builder for applying multiple build operations.Provides a mutator for a RTR ("ready-to-receive") retry number.TheReadyToReceiveSectionDecoratorclass implements a decorator providingReadyToReceiveTransmissionfunctionality for aSegment.Builder to buildReadyToReceiveSectionDecoratorinstances.TheReadyToReceiveSegmentDecoratorclass implements a decorator providingReadyToReceiveTransmissionfunctionality for aSegment.Builder to buildReadyToReceiveSegmentDecoratorinstances .Provides an accessor for aSegmentPackagerRTR ("ready-to-receive") property.Provides a builder method for aSegmentPackagerRTR ("ready-to-receive") property returning the builder for applying multiple build operations.Provides a mutator for aSegmentPackagerRTR ("ready-to-receive") property.Provides an accessor for a RTR ("ready-to-receive") timeout in milliseconds property.Provides a builder method for a the RTR ("ready-to-receive") timeout property returning the builder for applying multiple build operations.Provides a mutator for a RTR ("ready-to-receive") timeout in milliseconds property.TheReadyToReceiveTransmissioninterface defines functionality for achieving a RTR "software" handshake between a receiver having the active RTR ("ready-to-receive") role and a transmitter being CTS ("clear-to-send") where the transmitter waits for a RTR signal from the receiver (the receiver signals to be ready for receiving data by issuing an RTR signal to the transmitter):TRANSMITTER RECEIVER | | Wait till enquiry-timeout | | Send RTR magic-bytes for RTR magic-bytes |←-----RTR------| Try RTR retry-number of times | | Wait till RTR retry-timeout/retry Send payload upon RTR | | magic-bytes or break-out |----PAYLOAD---→| Receive payload upon enquiry-timeout | |Handshake specific signals are only transmitted through the return channel, the data channel is only used indirectly for handshaking by transporting the payload data in response to the return channel signals.Provides an accessor for a RTS ("ready-to-send") magic bytes property.Provides a builder method for a RTS ("ready-to-send") magic bytes property returning the builder for applying multiple build operations.Provides a mutator for a RTS ("ready-to-send") magic bytes property.Provides an accessor for a RTS ("ready-to-send") retry number.Provides a builder method for a RTS ("ready-to-send") retry number returning the builder for applying multiple build operations.Provides a mutator for a RTS ("ready-to-send") retry number.TheReadyToSendSectionDecoratorclass implements a decorator providingReadyToSendTransmissionfunctionality for aSegment.Builder to buildReadyToSendSectionDecoratorinstances.TheReadyToSendSegmentDecoratorclass implements a decorator providingReadyToSendTransmissionfunctionality for aSegment.Builder to buildReadyToSendSegmentDecoratorinstances.Provides an accessor for aSegmentPackagerRTS ("ready-to-send") property.Provides a builder method for aSegmentPackagerRTS ("ready-to-send") property returning the builder for applying multiple build operations.Provides a mutator for aSegmentPackagerRTS ("ready-to-send") property.Provides an accessor for a RTS ("ready-to-send") timeout in milliseconds property.Provides a builder method for a the RTS ("ready-to-send") timeout property returning the builder for applying multiple build operations.Provides a mutator for a RTS ("ready-to-send") timeout in milliseconds property.TheReadyToSendTransmissioninterface defines functionality for achieving an RTS "software" handshake between a transmitter having the active RTS ("ready-to-send") role and a receiver confirming being CTS ("clear-to-send") where the receiver waits for a RTS signal from the transmitter (the transmitter signals to be ready for sending data by issuing an RTS signal to the receiver).TheSectioninterface enables an implementing type to provide aSequencerepresentation of itself or to transmit itsSequencerepresentation through anOutputStream(with an optional feedbackInputStream) as ofTransmission.transmitTo(OutputStream, InputStream)and to initialize with aSequencerepresentation for itself or to receive aSequencerepresentation for itself through anInputStream(with an optional feedbackOutputStream) as ofSection.receiveFrom(InputStream, int, OutputStream).Default implementation of theSectioninterface providing an implementation of theSection.SectionMixin.receiveFrom(InputStream, int, OutputStream)method using theSection.fromTransmission(Sequence, int)method or theSection.fromTransmission(Sequence, int, int)method..TheSegmentinterface enables an implementing type to provide aSequencerepresentation of itself or to transmit itsSequencerepresentation through anOutputStream(with an optional feedbackInputStream) as ofTransmission.transmitTo(OutputStream, InputStream)and to initialize with aSequencerepresentation for itself or to receive aSequencerepresentation for itself through anInputStream(with an optional feedbackOutputStream) as ofSegment.receiveFrom(InputStream, OutputStream).Default implementation of theSegmentinterface providing an implementation of theSegment.SegmentMixin.receiveFrom(InputStream, OutputStream)method using theSegment.fromTransmission(Sequence)method or theSegment.fromTransmission(Sequence, int)method.ASegmentArraySectionis aSegmentconsisting ofSegmentelements with each element of presumably different lengths ( in contrast to theFixedSegmentArraySection).ASegmentConsumerconsumes aSegmentand is used to create lambda expressions used for asynchronous callback.TheSegmentDestinationis used to receiveSegmentinstances in a unified way.TheSegmentPackagerinterface defines methods to package (wrap) aSegmente.g. with aCrcSegmentDecorator.Dummy implementation of aSegmentPackagerjust passing through providedSegmentinstances.TheSegmentReceiveris used to receiveSegmentinstances in a unified way.ASegmentResultinstance is issued by theSerialReceiverto receive aTransmission's data asynchronously.TheSegmentSourceis used to sendSegmentinstances in a unified way.Combines theSegmentTransmitterandSegmentReceiverfunctionality in a single interface to be implemented by a single class so thatSegmentTransmitterandSegmentReceiverfunctionality can be provided by a single instance.TheSegmentTransmitteris used to transmitSegmentinstances in a unified way.ASequencerepresents a bytes container providing means to apply complex operations on that container's byte field.Provides an accessor for aSequenceproperty.Provides a builder method for a segment property returning the builder for applying multiple build operations.Provides a mutator for a segment property.Provides an accessor for a sequence number property.Provides a builder method for a sequence number property returning the builder for applying multiple build operations.Provides a mutator for a sequence number property.Provides an accessor for aConcatenateModeproperty.Provides a builder method for a sequence numberConcatenateModeproperty returning the builder for applying multiple build operations.Provides a mutator for a sequence numberConcatenateModeproperty.Provides an accessor for a sequence number initial value property.Provides a builder method for a sequence number initial value property returning the builder for applying multiple build operations.Provides a mutator for a sequence number initial value property.Convenience class for theNumberSegmentusingTransmissionMetricssequence number related properties to configure theSequenceNumberSegment(being an accordingly configuredNumberSegment).Provides an accessor for a sequence number width (in bytes) property.Provides a builder method for a sequence number width (in bytes) property returning the builder for applying multiple build operations.Provides a mutator for a sequence number width (in bytes) property.Base exception for this package.ASerialReceiveris used to read data from a serial port or the like.TheSerialSchemaOntologydescribes the terms used by the serialization data structures forSchemageneration.ASerialTransmitteris used to write data to a serial port or the like.TheShortArraySectionis an implementation of aSectioncarrying a short array as payload.TheShortSegmentis an implementation of aSegmentcarrying in short value as payload.TheStopAndWaitPacketInputStreamwraps anInputStreamand chunks any data to be written into packets with a sequence number and a block of data.Builder to buildStopAndWaitPacketInputStreaminstances.TheStopAndWaitPacketOutputStreamwraps anOutputStreamand chunks any data to be written into packets with a sequence number, a block of data and a CRC checksum.Builder to buildStopAndWaitPacketInputStreaminstances.AStopAndWaitPacketStreamSectionDecoratorchunks any outgoing stream (OutputStream) into blocks of definite length and reassembles any incoming streams (InputStream) from blocks of definite size into a contiguous stream.Builder to buildStopAndWaitSegmentDecoratorinstances.AStopAndWaitPacketStreamSegmentDecoratorchunks any outgoing stream (OutputStream) into blocks of definite length and reassembles any incoming streams (InputStream) from blocks of definite size into a contiguous stream.Builder to buildStopAndWaitSegmentDecoratorinstances.TheStopAndWaitPacketStreamTransmissioninterface defines the base functionality required by aTransmissioninstance for providing block stream functionality.TheStopAndWaitSectionDecoratorclass implements a decorator providingStopAndWaitTransmissionfunctionality for aSection.Builder to buildStopAndWaitSegmentDecoratorinstances.TheStopAndWaitSegmentDecoratorclass implements a decorator providingStopAndWaitTransmissionfunctionality for aSegment.Builder to buildStopAndWaitSegmentDecoratorinstances.TheStopAndWaitTransmissionis the most simple implementation of the ARQ (Automatic repeat request) protocol.Builder to buildStringSegmentinstances.TheTransmissioninterface enables an implementing type to provide aSequencerepresentation of itself or to transmit itsSequencerepresentation through anOutputStream(with an optional feedbackInputStream) as ofTransmission.transmitTo(OutputStream, InputStream).Default implementation of theTransmissioninterface providing an implementation of theTransmission.TransmissionMixin.transmitTo(OutputStream, InputStream)method using theTransmission.toSequence()method.Provides an accessor for aTransmissionproperty (as of the decorator pattern).Provides a builder method for aTransmissionproperty returning the builder for applying multiple build operations.Provides a mutator for aTransmissionproperty.Thrown in case a givenTransmissioncannot be processed.TheTransmissionMetricsinterface represents common parameters required when configuring a transmission.Builder to buildTransmissionMetrics.Provides an accessor for aTransmissionMetricsproperty.Provides a builder method for aTransmissionMetricsproperty returning the builder for applying multiple build operations.Provides a mutator for aTransmissionMetricsproperty.Provides an accessor for a transmission retry number.Provides a builder method for a transmission retry number returning the builder for applying multiple build operations.Provides a mutator for a transmission retry number.Thrown in case a givenSequencecannot be processed.Provides an accessor for a transmission timeout in milliseconds property.Provides a builder method for the transmission timeout property returning the builder for applying multiple build operations.Provides a mutator for a transmission timeout in milliseconds property.