Class AbstractArrayTransmission<ARRAY extends Transmission>

java.lang.Object
org.refcodes.serial.AbstractArrayTransmission<ARRAY>
Type Parameters:
ARRAY - The type of the array elements to be contained in this instance.
All Implemented Interfaces:
Serializable, org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.ArrayAccessor<ARRAY[]>, org.refcodes.mixin.ArrayAccessor.ArrayBuilder<ARRAY[],ArrayTransmission<ARRAY>>, org.refcodes.mixin.ArrayAccessor.ArrayMutator<ARRAY[]>, org.refcodes.mixin.ArrayAccessor.ArrayProperty<ARRAY[]>, org.refcodes.mixin.LengthAccessor, org.refcodes.mixin.Resetable, org.refcodes.schema.Schemable, ArrayTransmission<ARRAY>, Transmission
Direct Known Subclasses:
FixedSegmentArraySection, SegmentArraySection

public abstract class AbstractArrayTransmission<ARRAY extends Transmission> extends Object implements Transmission, ArrayTransmission<ARRAY>
An AbstractArrayTransmission is a Transmission consisting of Transmission elements (an array of elements).
See Also: