- java.lang.Object
-
- org.refcodes.serial.AbstractPayloadSection<T>
-
- Type Parameters:
T- The type of the body's payload.
- All Implemented Interfaces:
Serializable,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.LengthAccessor,org.refcodes.mixin.PayloadAccessor<T>,org.refcodes.mixin.PayloadAccessor.PayloadBuilder<T,PayloadTransmission<T>>,org.refcodes.mixin.PayloadAccessor.PayloadMutator<T>,org.refcodes.mixin.PayloadAccessor.PayloadProperty<T>,PayloadSection<T>,PayloadTransmission<T>,Section,Section.SectionMixin,Transmission,Transmission.TransmissionMixin
- Direct Known Subclasses:
BooleanArraySection,ByteArraySection,CharArraySection,CharSection,DoubleArraySection,FileSection,FloatArraySection,IntArraySection,LongArraySection,PropertiesSection,ShortArraySection,StringSection
public abstract class AbstractPayloadSection<T> extends Object implements PayloadSection<T>, Section.SectionMixin
An abstract implementation of aSectionwith payload.- See Also:
- Serialized Form
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.LengthAccessor
org.refcodes.mixin.LengthAccessor.LengthBuilder<B extends org.refcodes.mixin.LengthAccessor.LengthBuilder<B>>, org.refcodes.mixin.LengthAccessor.LengthMutator, org.refcodes.mixin.LengthAccessor.LengthProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.PayloadAccessor
org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P extends Object,B extends org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P,B>>, org.refcodes.mixin.PayloadAccessor.PayloadMutator<P extends Object>, org.refcodes.mixin.PayloadAccessor.PayloadProperty<P extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.serial.Section
Section.SectionMixin
-
Nested classes/interfaces inherited from interface org.refcodes.serial.Transmission
Transmission.TransmissionMixin
-
-
Constructor Summary
Constructors Modifier Constructor Description protectedAbstractPayloadSection()Empty constructor fur sub-classes.AbstractPayloadSection(String aAlias)Constructs an emptySectionto be initialized viaSection.fromTransmission(Sequence, int)orSection.fromTransmission(Sequence, int, int).AbstractPayloadSection(String aAlias, T aValue)Constructs aSectioninstance with the given value.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description booleanequals(Object obj)StringgetAlias()TgetPayload()inthashCode()voidsetPayload(T aValue)org.refcodes.struct.SimpleTypeMaptoSimpleTypeMap()Returns theSimpleTypeMaprepresentation of thisTransmission.StringtoString()-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface org.refcodes.serial.Section
fromTransmission, fromTransmission, fromTransmission, fromTransmission, receiveFrom, receiveFrom
-
Methods inherited from interface org.refcodes.serial.Section.SectionMixin
receiveFrom
-
Methods inherited from interface org.refcodes.serial.Transmission
getLength, toSchema, toTransmission, transmitTo, transmitTo
-
Methods inherited from interface org.refcodes.serial.Transmission.TransmissionMixin
transmitTo
-
-
-
-
Constructor Detail
-
AbstractPayloadSection
protected AbstractPayloadSection()
Empty constructor fur sub-classes.
-
AbstractPayloadSection
public AbstractPayloadSection(String aAlias)
Constructs an emptySectionto be initialized viaSection.fromTransmission(Sequence, int)orSection.fromTransmission(Sequence, int, int).- Parameters:
aAlias- The alias which identifies the content of this segment.
-
-
Method Detail
-
setPayload
public void setPayload(T aValue)
- Specified by:
setPayloadin interfaceorg.refcodes.mixin.PayloadAccessor.PayloadMutator<T>
-
getPayload
public T getPayload()
- Specified by:
getPayloadin interfaceorg.refcodes.mixin.PayloadAccessor<T>
-
getAlias
public String getAlias()
- Specified by:
getAliasin interfaceorg.refcodes.mixin.AliasAccessor
-
toSimpleTypeMap
public org.refcodes.struct.SimpleTypeMap toSimpleTypeMap()
Returns theSimpleTypeMaprepresentation of thisTransmission. In case this Transmission hasTransmissionchildren, then the children are queried as well and contained in the resultingSimpleTypeMap. The aliases of the accordingTransmissioninstances represent the resulting path to aTransmission's final simple type.- Specified by:
toSimpleTypeMapin interfaceTransmission- Returns:
- The
SimpleTypeMaprepresenting thisTransmissionand (if any) its children, with the according aliases forming the paths to theTransmission's values.
-
-