Interface ArrayTransmission<ARRAY extends Transmission>

    • Nested Class Summary

      • Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor

        org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasProperty
      • Nested classes/interfaces inherited from interface org.refcodes.mixin.ArrayAccessor

        org.refcodes.mixin.ArrayAccessor.ArrayBuilder<T extends Object,​B extends org.refcodes.mixin.ArrayAccessor.ArrayBuilder<T,​B>>, org.refcodes.mixin.ArrayAccessor.ArrayMutator<T extends Object>, org.refcodes.mixin.ArrayAccessor.ArrayProperty<T extends Object>
      • Nested classes/interfaces inherited from interface org.refcodes.mixin.LengthAccessor

        org.refcodes.mixin.LengthAccessor.LengthBuilder<B extends org.refcodes.mixin.LengthAccessor.LengthBuilder<B>>, org.refcodes.mixin.LengthAccessor.LengthMutator, org.refcodes.mixin.LengthAccessor.LengthProperty
    • Method Summary

      All Methods Instance Methods Default Methods 
      Modifier and Type Method Description
      default int getLength()
      Determines the overall length of this Transmission.
      default Schema toSchema()
      Retrieves the Schema representing the Transmission.
      default Sequence toSequence()
      Provides the Sequence representation of this Transmission.
      default org.refcodes.struct.SimpleTypeMap toSimpleTypeMap()
      Returns the SimpleTypeMap representation of this Transmission.
      • Methods inherited from interface org.refcodes.mixin.AliasAccessor

        getAlias
      • Methods inherited from interface org.refcodes.mixin.ArrayAccessor

        getArray
      • Methods inherited from interface org.refcodes.mixin.ArrayAccessor.ArrayBuilder

        withArray
      • Methods inherited from interface org.refcodes.mixin.ArrayAccessor.ArrayMutator

        setArray
      • Methods inherited from interface org.refcodes.mixin.ArrayAccessor.ArrayProperty

        letArray
    • Method Detail

      • toSimpleTypeMap

        default org.refcodes.struct.SimpleTypeMap toSimpleTypeMap()
        Returns the SimpleTypeMap representation of this Transmission. In case this Transmission has Transmission children, then the children are queried as well and contained in the resulting SimpleTypeMap. The aliases of the according Transmission instances represent the resulting path to a Transmission's final simple type.
        Specified by:
        toSimpleTypeMap in interface Transmission
        Returns:
        The SimpleTypeMap representing this Transmission and (if any) its children, with the according aliases forming the paths to the Transmission's values.
      • getLength

        default int getLength()
        Determines the overall length of this Transmission. In case of nested Transmission instances, all length values from all sub-segments are accumulated to the result as well.
        Specified by:
        getLength in interface org.refcodes.mixin.LengthAccessor
        Specified by:
        getLength in interface Transmission
        Returns:
        The (overall) length of the Transmission (including any sub-segments).