Module org.refcodes.serial
Package org.refcodes.serial
Interface ArrayTransmission<ARRAY extends Transmission>
- Type Parameters:
ARRAY- The type of the arrayTransmissionelements.
- All Superinterfaces:
org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.ArrayAccessor<ARRAY[]>,org.refcodes.mixin.ArrayAccessor.ArrayBuilder<ARRAY[],ArrayTransmission<ARRAY>>,org.refcodes.mixin.ArrayAccessor.ArrayMutator<ARRAY[]>,org.refcodes.mixin.ArrayAccessor.ArrayProperty<ARRAY[]>,org.refcodes.mixin.LengthAccessor,Serializable,Transmission
- All Known Subinterfaces:
ArraySection<ARRAY>,ArraySegment<SEGMENT>
- All Known Implementing Classes:
AbstractArrayTransmission,FixedSegmentArraySection,SegmentArraySection
public interface ArrayTransmission<ARRAY extends Transmission> extends Transmission, org.refcodes.mixin.ArrayAccessor.ArrayProperty<ARRAY[]>, org.refcodes.mixin.ArrayAccessor.ArrayBuilder<ARRAY[],ArrayTransmission<ARRAY>>, org.refcodes.mixin.AliasAccessor
A
ArrayTransmission is a Transmission with array
Transmission elements. When invoking toSimpleTypeMap() the
array nature is preserved by indexing each element of the array with the
array index.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.ArrayAccessor
org.refcodes.mixin.ArrayAccessor.ArrayBuilder<T extends Object,B extends org.refcodes.mixin.ArrayAccessor.ArrayBuilder<T,B>>, org.refcodes.mixin.ArrayAccessor.ArrayMutator<T extends Object>, org.refcodes.mixin.ArrayAccessor.ArrayProperty<T extends Object>Nested classes/interfaces inherited from interface org.refcodes.mixin.LengthAccessor
org.refcodes.mixin.LengthAccessor.LengthBuilder<B extends org.refcodes.mixin.LengthAccessor.LengthBuilder<B>>, org.refcodes.mixin.LengthAccessor.LengthMutator, org.refcodes.mixin.LengthAccessor.LengthPropertyNested classes/interfaces inherited from interface org.refcodes.serial.Transmission
Transmission.TransmissionMixin -
Method Summary
Modifier and Type Method Description default intgetLength()Determines the overall length of thisTransmission.default SchematoSchema()Retrieves theSchemarepresenting theTransmission.default org.refcodes.struct.SimpleTypeMaptoSimpleTypeMap()Returns theSimpleTypeMaprepresentation of thisTransmission.default SequencetoTransmission()Provides theSequencerepresentation of thisTransmission.Methods inherited from interface org.refcodes.mixin.AliasAccessor
getAliasMethods inherited from interface org.refcodes.mixin.ArrayAccessor
getArrayMethods inherited from interface org.refcodes.mixin.ArrayAccessor.ArrayBuilder
withArrayMethods inherited from interface org.refcodes.mixin.ArrayAccessor.ArrayMutator
setArrayMethods inherited from interface org.refcodes.mixin.ArrayAccessor.ArrayProperty
letArrayMethods inherited from interface org.refcodes.serial.Transmission
transmitTo, transmitTo, transmitTo
-
Method Details
-
toTransmission
Provides theSequencerepresentation of thisTransmission. In case of nestedTransmissioninstances, allSequencerepresentations from all sub-segments are accumulated to the result as well.- Specified by:
toTransmissionin interfaceTransmission- Returns:
- The according instance's
Sequence.
-
toSimpleTypeMap
default org.refcodes.struct.SimpleTypeMap toSimpleTypeMap()Returns theSimpleTypeMaprepresentation of thisTransmission. In case this Transmission hasTransmissionchildren, then the children are queried as well and contained in the resultingSimpleTypeMap. The aliases of the accordingTransmissioninstances represent the resulting path to aTransmission's final simple type.- Specified by:
toSimpleTypeMapin interfaceTransmission- Returns:
- The
SimpleTypeMaprepresenting thisTransmissionand (if any) its children, with the according aliases forming the paths to theTransmission's values.
-
toSchema
Retrieves theSchemarepresenting theTransmission. Retrieving aSchemais useful when analyzing and debugging data structures such as aAllocSectionDecoratorSegmentinstance to help document, learn and verify on the structure (as well as the content) of that veryAllocSectionDecoratorSegment.- Specified by:
toSchemain interfaceTransmission- Returns:
- The
Schemarepresentation of the implementing type for debugging and verification (or documentation) purposes.
-
getLength
default int getLength()Determines the overall length of thisTransmission. In case of nestedTransmissioninstances, all length values from all sub-segments are accumulated to the result as well.- Specified by:
getLengthin interfaceorg.refcodes.mixin.LengthAccessor- Specified by:
getLengthin interfaceTransmission- Returns:
- The (overall) length of the
Transmission(including any sub-segments).
-