- java.lang.Object
-
- org.refcodes.serial.AbstractPayloadSegment<Boolean>
-
- org.refcodes.serial.BooleanSegment
-
- All Implemented Interfaces:
Serializable,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.LengthAccessor,org.refcodes.mixin.PayloadAccessor<Boolean>,org.refcodes.mixin.PayloadAccessor.PayloadBuilder<Boolean,PayloadTransmission<Boolean>>,org.refcodes.mixin.PayloadAccessor.PayloadMutator<Boolean>,org.refcodes.mixin.PayloadAccessor.PayloadProperty<Boolean>,PayloadSegment<Boolean>,PayloadTransmission<Boolean>,Segment,Segment.SegmentMixin,Transmission,Transmission.TransmissionMixin
public class BooleanSegment extends AbstractPayloadSegment<Boolean> implements Segment
TheBooleanSegmentis an implementation of aSegmentcarrying in boolean value as value.- See Also:
- Serialized Form
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.LengthAccessor
org.refcodes.mixin.LengthAccessor.LengthBuilder<B extends org.refcodes.mixin.LengthAccessor.LengthBuilder<B>>, org.refcodes.mixin.LengthAccessor.LengthMutator, org.refcodes.mixin.LengthAccessor.LengthProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.PayloadAccessor
org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P extends Object,B extends org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P,B>>, org.refcodes.mixin.PayloadAccessor.PayloadMutator<P extends Object>, org.refcodes.mixin.PayloadAccessor.PayloadProperty<P extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.serial.Segment
Segment.SegmentMixin
-
Nested classes/interfaces inherited from interface org.refcodes.serial.Transmission
Transmission.TransmissionMixin
-
-
Field Summary
Fields Modifier and Type Field Description static intBYTES-
Fields inherited from class org.refcodes.serial.AbstractPayloadSegment
_alias, _payload
-
-
Constructor Summary
Constructors Constructor Description BooleanSegment()Constructs an emptyBooleanSegment.BooleanSegment(boolean aValue)Constructs aBooleanSegmentwith the given boolean payload.BooleanSegment(String aAlias)Constructs an emptyBooleanSegment.BooleanSegment(String aAlias, boolean aValue)Constructs aBooleanSegmentwith the given boolean payload.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description intfromTransmission(Sequence aSequence, int aOffset)(Re-)initializes this instance with the the givenSequencedata.intgetLength()Determines the overall length of thisTransmission.SchematoSchema()Retrieves theSchemarepresenting theTransmission.SequencetoTransmission()Provides theSequencerepresentation of thisTransmission.BooleanSegmentwithPayload(Boolean aValue)-
Methods inherited from class org.refcodes.serial.AbstractPayloadSegment
equals, getAlias, getPayload, hashCode, setPayload, toSimpleTypeMap, toString
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface org.refcodes.serial.Segment
fromTransmission, fromTransmission, fromTransmission, receiveFrom, receiveFrom
-
Methods inherited from interface org.refcodes.serial.Segment.SegmentMixin
receiveFrom
-
Methods inherited from interface org.refcodes.serial.Transmission
toSimpleTypeMap, transmitTo, transmitTo
-
Methods inherited from interface org.refcodes.serial.Transmission.TransmissionMixin
transmitTo
-
-
-
-
Field Detail
-
BYTES
public static final int BYTES
- See Also:
- Constant Field Values
-
-
Constructor Detail
-
BooleanSegment
public BooleanSegment()
Constructs an emptyBooleanSegment.
-
BooleanSegment
public BooleanSegment(boolean aValue)
Constructs aBooleanSegmentwith the given boolean payload.- Parameters:
aValue- The value (payload) to be contained by theBooleanSegment.
-
BooleanSegment
public BooleanSegment(String aAlias)
Constructs an emptyBooleanSegment.- Parameters:
aAlias- The alias which identifies the content of this segment.
-
BooleanSegment
public BooleanSegment(String aAlias, boolean aValue)
Constructs aBooleanSegmentwith the given boolean payload.- Parameters:
aAlias- The alias which identifies the content of this segment.aValue- The value (payload) to be contained by theBooleanSegment.
-
-
Method Detail
-
toTransmission
public Sequence toTransmission()
Provides theSequencerepresentation of thisTransmission. In case of nestedTransmissioninstances, allSequencerepresentations from all sub-segments are accumulated to the result as well.- Specified by:
toTransmissionin interfaceTransmission- Returns:
- The according instance's
Sequence.
-
fromTransmission
public int fromTransmission(Sequence aSequence, int aOffset) throws TransmissionException
(Re-)initializes this instance with the the givenSequencedata.- Specified by:
fromTransmissionin interfaceSegment- Parameters:
aSequence- TheSequencedata from which to (re-)initialize this instance.aOffset- The offset where to start processing the providedSequence.- Returns:
- The index after the last offset into the given
Sequenceprocessed by this method. - Throws:
TransmissionException- thrown in case a givenSequencecannot be processed.
-
getLength
public int getLength()
Determines the overall length of thisTransmission. In case of nestedTransmissioninstances, all length values from all sub-segments are accumulated to the result as well.- Specified by:
getLengthin interfaceorg.refcodes.mixin.LengthAccessor- Specified by:
getLengthin interfaceTransmission- Returns:
- The (overall) length of the
Transmission(including any sub-segments).
-
toSchema
public Schema toSchema()
Retrieves theSchemarepresenting theTransmission. Retrieving aSchemais useful when analyzing and debugging data structures such as aAllocSectionDecoratorSegmentinstance to help document, learn and verify on the structure (as well as the content) of that veryAllocSectionDecoratorSegment.- Specified by:
toSchemain interfaceTransmission- Returns:
- The
Schemarepresentation of the implementing type for debugging and verification (or documentation) purposes.
-
withPayload
public BooleanSegment withPayload(Boolean aValue)
- Specified by:
withPayloadin interfaceorg.refcodes.mixin.PayloadAccessor.PayloadBuilder<Boolean,PayloadTransmission<Boolean>>
-
-