Class ByteArraySection
java.lang.Object
org.refcodes.serial.AbstractPayloadSection<byte[]>
org.refcodes.serial.ByteArraySection
- All Implemented Interfaces:
Serializable, AliasAccessor, LengthAccessor, PayloadAccessor<byte[]>, PayloadAccessor.PayloadBuilder<byte[], PayloadTransmission<byte[]>>, PayloadAccessor.PayloadMutator<byte[]>, PayloadAccessor.PayloadProperty<byte[]>, Resetable, Diagnosable, Schemable<DiagnosticOptions>, PayloadSection<byte[]>, PayloadTransmission<byte[]>, Section, Section.SectionMixin, Transmission, Transmission.TransmissionMixin
The
ByteArraySection is an implementation of a Section
carrying a byte array as payload.- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface AliasAccessor
AliasAccessor.AliasBuilder<B>, AliasAccessor.AliasMutator, AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface LengthAccessor
LengthAccessor.LengthBuilder<B>, LengthAccessor.LengthMutator, LengthAccessor.LengthPropertyNested classes/interfaces inherited from interface PayloadAccessor
PayloadAccessor.PayloadBuilder<P,B>, PayloadAccessor.PayloadMutator<P>, PayloadAccessor.PayloadProperty<P> Nested classes/interfaces inherited from interface Section
Section.SectionMixinNested classes/interfaces inherited from interface Transmission
Transmission.TransmissionMixin -
Field Summary
Fields inherited from class AbstractPayloadSection
_alias, _payload -
Constructor Summary
ConstructorsConstructorDescriptionConstructs an emptyByteArraySection.ByteArraySection(byte[] aPayload) Constructs aByteArraySectionwith the given byte array payload.ByteArraySection(Byte[] aPayload) Constructs aByteArraySectionwith the given byte array payload.ByteArraySection(String aAlias) Instantiates the classByteArraySection.ByteArraySection(String aAlias, byte[] aPayload) Instantiates the classByteArraySection.ByteArraySection(String aAlias, Byte[] aPayload) Instantiates the classByteArraySection. -
Method Summary
Modifier and TypeMethodDescriptionvoidfromTransmission(Sequence aSequence, int aOffset, int aLength) (Re-)initializes this instance with the the givenSequencedata.intDetermines the overall length of thisTransmission.voidsetPayload(Byte[] aPayload) Convenience method to convert the array of wrapper types into its counterpart with primitive types before invokingAbstractPayloadSection.setPayload(Object).toSchema()Provides theSequencerepresentation of thisTransmission.toString()withPayload(byte[] aValue) withPayload(Byte[] aPayload) Convenience method to convert the array of wrapper types into its counterpart with primitive types before invokingwithPayload(byte[]).Methods inherited from class AbstractPayloadSection
equals, getAlias, getPayload, hashCode, reset, setPayload, toSimpleTypeTableMethods inherited from interface PayloadAccessor
getPayloadOrMethods inherited from interface PayloadAccessor.PayloadProperty
letPayloadMethods inherited from interface Section
fromTransmission, fromTransmission, fromTransmission, receiveFrom, receiveFromMethods inherited from interface Section.SectionMixin
receiveFromMethods inherited from interface Transmission
transmitTo, transmitToMethods inherited from interface Transmission.TransmissionMixin
transmitTo
-
Constructor Details
-
ByteArraySection
public ByteArraySection()Constructs an emptyByteArraySection. -
ByteArraySection
public ByteArraySection(byte[] aPayload) Constructs aByteArraySectionwith the given byte array payload.- Parameters:
aPayload- The payload to be contained by theSection.
-
ByteArraySection
Constructs aByteArraySectionwith the given byte array payload.- Parameters:
aPayload- The payload to be contained by theSection.
-
ByteArraySection
Instantiates the classByteArraySection.- Parameters:
aAlias- the alias- See Also:
-
ByteArraySection
Instantiates the classByteArraySection.- Parameters:
aAlias- the aliasaPayload- the payload- See Also:
-
ByteArraySection
Instantiates the classByteArraySection.- Parameters:
aAlias- the aliasaPayload- The payload to be contained by theSection.- See Also:
-
-
Method Details
-
toSequence
Provides theSequencerepresentation of thisTransmission. In case of nestedTransmissioninstances, allSequencerepresentations from all sub-segments are accumulated to the result as well. Caution, the Transmission (or its nestedTransmissioninstances) may be backed by the returnedSequence.- Returns:
- The according instance's
Sequence.
-
fromTransmission
public void fromTransmission(Sequence aSequence, int aOffset, int aLength) throws TransmissionException (Re-)initializes this instance with the the givenSequencedata.- Parameters:
aSequence- TheSequencedata from which to (re-)initialize this instance.aOffset- The offset where to start processing the providedSequence.aLength- The length of data assigned by theSequence.- Throws:
TransmissionException- thrown in case a givenSequencecannot be processed.
-
getLength
public int getLength()Determines the overall length of thisTransmission. In case of nestedTransmissioninstances, all length values from all sub-segments are accumulated to the result as well.- Returns:
- The (overall) length of the
Transmission(including any sub-segments).
-
toSchema
-
toString
- Overrides:
toStringin classAbstractPayloadSection<byte[]>
-
withPayload
-
setPayload
Convenience method to convert the array of wrapper types into its counterpart with primitive types before invokingAbstractPayloadSection.setPayload(Object).- Parameters:
aPayload- The payload with the wrapper types.
-
withPayload
Convenience method to convert the array of wrapper types into its counterpart with primitive types before invokingwithPayload(byte[]).- Parameters:
aPayload- The payload with the wrapper types.- Returns:
- This instance as of the builder pattern.
-