- java.lang.Object
-
- org.refcodes.serial.AbstractPayloadSection<byte[]>
-
- org.refcodes.serial.ByteArraySection
-
- All Implemented Interfaces:
Serializable,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.LengthAccessor,org.refcodes.mixin.PayloadAccessor<byte[]>,org.refcodes.mixin.PayloadAccessor.PayloadBuilder<byte[],PayloadTransmission<byte[]>>,org.refcodes.mixin.PayloadAccessor.PayloadMutator<byte[]>,org.refcodes.mixin.PayloadAccessor.PayloadProperty<byte[]>,PayloadSection<byte[]>,PayloadTransmission<byte[]>,Section,Section.SectionMixin,Transmission,Transmission.TransmissionMixin
public class ByteArraySection extends AbstractPayloadSection<byte[]> implements PayloadSection<byte[]>
TheByteArraySectionis an implementation of aSectioncarrying a byte array as payload.- See Also:
- Serialized Form
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.LengthAccessor
org.refcodes.mixin.LengthAccessor.LengthBuilder<B extends org.refcodes.mixin.LengthAccessor.LengthBuilder<B>>, org.refcodes.mixin.LengthAccessor.LengthMutator, org.refcodes.mixin.LengthAccessor.LengthProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.PayloadAccessor
org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P extends Object,B extends org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P,B>>, org.refcodes.mixin.PayloadAccessor.PayloadMutator<P extends Object>, org.refcodes.mixin.PayloadAccessor.PayloadProperty<P extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.serial.Section
Section.SectionMixin
-
Nested classes/interfaces inherited from interface org.refcodes.serial.Transmission
Transmission.TransmissionMixin
-
-
Field Summary
-
Fields inherited from class org.refcodes.serial.AbstractPayloadSection
_alias, _payload
-
-
Constructor Summary
Constructors Constructor Description ByteArraySection()Constructs an emptyByteArraySection.ByteArraySection(byte[] aPayload)Constructs aByteArraySectionwith the given byte array payload.ByteArraySection(Byte[] aPayload)Constructs aByteArraySectionwith the given byte array payload.ByteArraySection(String aAlias)Constructs an emptyByteArraySection.ByteArraySection(String aAlias, byte[] aPayload)Constructs aByteArraySectionwith the given byte array payload.ByteArraySection(String aAlias, Byte[] aPayload)Constructs aByteArraySectionwith the given byte array payload.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description voidfromTransmission(Sequence aSequence, int aOffset, int aLength)(Re-)initializes this instance with the the givenSequencedata.intgetLength()Determines the overall length of thisTransmission.voidsetPayload(Byte[] aPayload)Convenience method to convert the array of wrapper types into its counterpart with primitive types before invokingAbstractPayloadSection.setPayload(Object).SchematoSchema()Retrieves theSchemarepresenting theTransmission.StringtoString()SequencetoTransmission()Provides theSequencerepresentation of thisTransmission.ByteArraySectionwithPayload(byte[] aValue)ByteArraySectionwithPayload(Byte[] aPayload)Convenience method to convert the array of wrapper types into its counterpart with primitive types before invokingwithPayload(byte[]).-
Methods inherited from class org.refcodes.serial.AbstractPayloadSection
equals, getAlias, getPayload, hashCode, setPayload, toSimpleTypeMap
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface org.refcodes.serial.Section
fromTransmission, fromTransmission, fromTransmission, receiveFrom, receiveFrom
-
Methods inherited from interface org.refcodes.serial.Section.SectionMixin
receiveFrom
-
Methods inherited from interface org.refcodes.serial.Transmission
toSimpleTypeMap, transmitTo, transmitTo
-
Methods inherited from interface org.refcodes.serial.Transmission.TransmissionMixin
transmitTo
-
-
-
-
Constructor Detail
-
ByteArraySection
public ByteArraySection()
Constructs an emptyByteArraySection.
-
ByteArraySection
public ByteArraySection(byte[] aPayload)
Constructs aByteArraySectionwith the given byte array payload.- Parameters:
aPayload- The payload to be contained by theSection.
-
ByteArraySection
public ByteArraySection(Byte[] aPayload)
Constructs aByteArraySectionwith the given byte array payload.- Parameters:
aPayload- The payload to be contained by theSection.
-
ByteArraySection
public ByteArraySection(String aAlias)
Constructs an emptyByteArraySection.- Parameters:
aAlias- The alias which identifies the content of this segment.
-
ByteArraySection
public ByteArraySection(String aAlias, byte[] aPayload)
Constructs aByteArraySectionwith the given byte array payload.- Parameters:
aAlias- The alias which identifies the content of this segment.aPayload- The payload to be contained by theSection.
-
ByteArraySection
public ByteArraySection(String aAlias, Byte[] aPayload)
Constructs aByteArraySectionwith the given byte array payload.- Parameters:
aAlias- The alias which identifies the content of this segment.aPayload- The payload to be contained by theSection.
-
-
Method Detail
-
toTransmission
public Sequence toTransmission()
Provides theSequencerepresentation of thisTransmission. In case of nestedTransmissioninstances, allSequencerepresentations from all sub-segments are accumulated to the result as well.- Specified by:
toTransmissionin interfaceTransmission- Returns:
- The according instance's
Sequence.
-
fromTransmission
public void fromTransmission(Sequence aSequence, int aOffset, int aLength) throws TransmissionException
(Re-)initializes this instance with the the givenSequencedata.- Specified by:
fromTransmissionin interfaceSection- Parameters:
aSequence- TheSequencedata from which to (re-)initialize this instance.aOffset- The offset where to start processing the providedSequence.aLength- The length of data assigned by theSequence.- Throws:
TransmissionException- thrown in case a givenSequencecannot be processed.
-
getLength
public int getLength()
Determines the overall length of thisTransmission. In case of nestedTransmissioninstances, all length values from all sub-segments are accumulated to the result as well.- Specified by:
getLengthin interfaceorg.refcodes.mixin.LengthAccessor- Specified by:
getLengthin interfaceTransmission- Returns:
- The (overall) length of the
Transmission(including any sub-segments).
-
toSchema
public Schema toSchema()
Retrieves theSchemarepresenting theTransmission. Retrieving aSchemais useful when analyzing and debugging data structures such as aAllocSectionDecoratorSegmentinstance to help document, learn and verify on the structure (as well as the content) of that veryAllocSectionDecoratorSegment.- Specified by:
toSchemain interfaceTransmission- Returns:
- The
Schemarepresentation of the implementing type for debugging and verification (or documentation) purposes.
-
toString
public String toString()
- Overrides:
toStringin classAbstractPayloadSection<byte[]>
-
withPayload
public ByteArraySection withPayload(byte[] aValue)
- Specified by:
withPayloadin interfaceorg.refcodes.mixin.PayloadAccessor.PayloadBuilder<byte[],PayloadTransmission<byte[]>>
-
setPayload
public void setPayload(Byte[] aPayload)
Convenience method to convert the array of wrapper types into its counterpart with primitive types before invokingAbstractPayloadSection.setPayload(Object).- Parameters:
aPayload- The payload with the wrapper types.
-
withPayload
public ByteArraySection withPayload(Byte[] aPayload)
Convenience method to convert the array of wrapper types into its counterpart with primitive types before invokingwithPayload(byte[]).- Parameters:
aPayload- The payload with the wrapper types.- Returns:
- This instance as of the builder pattern.
-
-