- java.lang.Object
-
- org.refcodes.serial.AbstractPayloadSection<char[]>
-
- org.refcodes.serial.CharArraySection
-
- All Implemented Interfaces:
Serializable,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.EncodingAccessor<Charset>,org.refcodes.mixin.LengthAccessor,org.refcodes.mixin.PayloadAccessor<char[]>,org.refcodes.mixin.PayloadAccessor.PayloadBuilder<char[],PayloadTransmission<char[]>>,org.refcodes.mixin.PayloadAccessor.PayloadMutator<char[]>,org.refcodes.mixin.PayloadAccessor.PayloadProperty<char[]>,PayloadSection<char[]>,PayloadTransmission<char[]>,Section,Section.SectionMixin,Transmission,Transmission.TransmissionMixin
public class CharArraySection extends AbstractPayloadSection<char[]> implements PayloadSection<char[]>, org.refcodes.mixin.EncodingAccessor<Charset>
TheCharArraySectionis an implementation of aPayloadSectioncarrying a char array as payload.- See Also:
- Serialized Form
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.EncodingAccessor
org.refcodes.mixin.EncodingAccessor.EncodingBuilder<E extends Object,B extends org.refcodes.mixin.EncodingAccessor.EncodingBuilder<E,B>>, org.refcodes.mixin.EncodingAccessor.EncodingMutator<E extends Object>, org.refcodes.mixin.EncodingAccessor.EncodingProperty<E extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.LengthAccessor
org.refcodes.mixin.LengthAccessor.LengthBuilder<B extends org.refcodes.mixin.LengthAccessor.LengthBuilder<B>>, org.refcodes.mixin.LengthAccessor.LengthMutator, org.refcodes.mixin.LengthAccessor.LengthProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.PayloadAccessor
org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P extends Object,B extends org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P,B>>, org.refcodes.mixin.PayloadAccessor.PayloadMutator<P extends Object>, org.refcodes.mixin.PayloadAccessor.PayloadProperty<P extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.serial.Section
Section.SectionMixin
-
Nested classes/interfaces inherited from interface org.refcodes.serial.Transmission
Transmission.TransmissionMixin
-
-
Field Summary
-
Fields inherited from class org.refcodes.serial.AbstractPayloadSection
_alias, _payload
-
-
Constructor Summary
Constructors Constructor Description CharArraySection()Constructs an emptyCharArraySection.CharArraySection(char[] aPayload)Constructs aCharArraySectionwith the given char array payload.CharArraySection(Character[] aPayload)Constructs aCharArraySectionwith the given char array payload.CharArraySection(String aAlias)Constructs an emptyCharArraySection.CharArraySection(String aAlias, char[] aPayload)Constructs aCharArraySectionwith the given char array payload.CharArraySection(String aAlias, Character[] aPayload)Constructs aCharArraySectionwith the given char array payload.CharArraySection(String aAlias, Charset aCharset)Constructs an emptyCharArraySection.CharArraySection(String aAlias, Charset aCharset, char... aPayload)Constructs aCharArraySectionwith the given char array payload.CharArraySection(String aAlias, Charset aCharset, Character... aPayload)Constructs aCharArraySectionwith the given char array payload.CharArraySection(String aAlias, TransmissionMetrics aTransmissionMetrics)Constructs an according instance from the given configuration.CharArraySection(String aAlias, TransmissionMetrics aTransmissionMetrics, char... aValue)Constructs an according instance from the given configuration.CharArraySection(String aAlias, TransmissionMetrics aTransmissionMetrics, Character... aValue)Constructs an according instance from the given configuration.CharArraySection(Charset aCharset)Constructs an emptyCharArraySection.CharArraySection(Charset aCharset, char... aPayload)Constructs aCharArraySectionwith the given char array payload.CharArraySection(Charset aCharset, Character... aPayload)Constructs aCharArraySectionwith the given char array payload.CharArraySection(TransmissionMetrics aTransmissionMetrics)Constructs an according instance from the given configuration.CharArraySection(TransmissionMetrics aTransmissionMetrics, char... aValue)Constructs an according instance from the given configuration.CharArraySection(TransmissionMetrics aTransmissionMetrics, Character... aValue)Constructs an according instance from the given configuration.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description voidfromTransmission(Sequence aSequence, int aOffset, int aLength)(Re-)initializes this instance with the the givenSequencedata.CharsetgetEncoding()intgetLength()Determines the overall length of thisTransmission.voidsetPayload(Character[] aPayload)Convenience method to convert the array of wrapper types into its counterpart with primitive types before invokingAbstractPayloadSection.setPayload(Object).SchematoSchema()Retrieves theSchemarepresenting theTransmission.SequencetoSequence()Provides theSequencerepresentation of thisTransmission.StringtoString()CharArraySectionwithPayload(char[] aValue)CharArraySectionwithPayload(Character[] aPayload)Convenience method to convert the array of wrapper types into its counterpart with primitive types before invokingwithPayload(char[]).-
Methods inherited from class org.refcodes.serial.AbstractPayloadSection
equals, getAlias, getPayload, hashCode, setPayload, toSimpleTypeMap
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface org.refcodes.serial.Section
fromTransmission, fromTransmission, fromTransmission, receiveFrom, receiveFrom
-
Methods inherited from interface org.refcodes.serial.Section.SectionMixin
receiveFrom
-
Methods inherited from interface org.refcodes.serial.Transmission
toSimpleTypeMap, transmitTo, transmitTo
-
Methods inherited from interface org.refcodes.serial.Transmission.TransmissionMixin
transmitTo
-
-
-
-
Constructor Detail
-
CharArraySection
public CharArraySection(TransmissionMetrics aTransmissionMetrics)
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.
-
CharArraySection
public CharArraySection(TransmissionMetrics aTransmissionMetrics, char... aValue)
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.aValue- The payload to be contained by theCharArraySection.
-
CharArraySection
public CharArraySection(TransmissionMetrics aTransmissionMetrics, Character... aValue)
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.aValue- The payload to be contained by theCharArraySection.
-
CharArraySection
public CharArraySection(String aAlias, TransmissionMetrics aTransmissionMetrics)
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aAlias- The alias which identifies the content of this instance.aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.
-
CharArraySection
public CharArraySection(String aAlias, TransmissionMetrics aTransmissionMetrics, char... aValue)
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aAlias- The alias which identifies the content of this instance.aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.aValue- The payload to be contained by theCharArraySection.
-
CharArraySection
public CharArraySection(String aAlias, TransmissionMetrics aTransmissionMetrics, Character... aValue)
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aAlias- The alias which identifies the content of this instance.aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.aValue- The payload to be contained by theCharArraySection.
-
CharArraySection
public CharArraySection()
Constructs an emptyCharArraySection. Uses UTF-16 by default for encoding.
-
CharArraySection
public CharArraySection(Charset aCharset)
Constructs an emptyCharArraySection.- Parameters:
aCharset- The charset to be used for encoding.
-
CharArraySection
public CharArraySection(char[] aPayload)
Constructs aCharArraySectionwith the given char array payload. UsesTransmissionMetrics.DEFAULT_ENCODINGby default for encoding.- Parameters:
aPayload- The payload to be contained by thePayloadSection.
-
CharArraySection
public CharArraySection(Character[] aPayload)
Constructs aCharArraySectionwith the given char array payload. UsesTransmissionMetrics.DEFAULT_ENCODINGby default for encoding.- Parameters:
aPayload- The payload to be contained by thePayloadSection.
-
CharArraySection
public CharArraySection(Charset aCharset, char... aPayload)
Constructs aCharArraySectionwith the given char array payload. UsesTransmissionMetrics.DEFAULT_ENCODINGby default for encoding.- Parameters:
aCharset- The charset to be used for encoding.aPayload- The payload to be contained by thePayloadSection.
-
CharArraySection
public CharArraySection(Charset aCharset, Character... aPayload)
Constructs aCharArraySectionwith the given char array payload. UsesTransmissionMetrics.DEFAULT_ENCODINGby default for encoding.- Parameters:
aCharset- The charset to be used for encoding.aPayload- The payload to be contained by thePayloadSection.
-
CharArraySection
public CharArraySection(String aAlias)
Constructs an emptyCharArraySection. Uses UTF-16 by default for encoding.- Parameters:
aAlias- The alias which identifies the content of this segment.
-
CharArraySection
public CharArraySection(String aAlias, Charset aCharset)
Constructs an emptyCharArraySection.- Parameters:
aAlias- The alias which identifies the content of this segment.aCharset- The charset to be used for encoding.
-
CharArraySection
public CharArraySection(String aAlias, char[] aPayload)
Constructs aCharArraySectionwith the given char array payload. UsesTransmissionMetrics.DEFAULT_ENCODINGby default for encoding.- Parameters:
aAlias- The alias which identifies the content of this segment.aPayload- The payload to be contained by thePayloadSection.
-
CharArraySection
public CharArraySection(String aAlias, Character[] aPayload)
Constructs aCharArraySectionwith the given char array payload. UsesTransmissionMetrics.DEFAULT_ENCODINGby default for encoding.- Parameters:
aAlias- The alias which identifies the content of this segment.aPayload- The payload to be contained by thePayloadSection.
-
CharArraySection
public CharArraySection(String aAlias, Charset aCharset, char... aPayload)
Constructs aCharArraySectionwith the given char array payload. UsesTransmissionMetrics.DEFAULT_ENCODINGby default for encoding.- Parameters:
aAlias- The alias which identifies the content of this segment.aCharset- The charset to be used for encoding.aPayload- The payload to be contained by thePayloadSection.
-
CharArraySection
public CharArraySection(String aAlias, Charset aCharset, Character... aPayload)
Constructs aCharArraySectionwith the given char array payload. UsesTransmissionMetrics.DEFAULT_ENCODINGby default for encoding.- Parameters:
aAlias- The alias which identifies the content of this segment.aCharset- The charset to be used for encoding.aPayload- The payload to be contained by thePayloadSection.
-
-
Method Detail
-
withPayload
public CharArraySection withPayload(char[] aValue)
- Specified by:
withPayloadin interfaceorg.refcodes.mixin.PayloadAccessor.PayloadBuilder<char[],PayloadTransmission<char[]>>
-
toSequence
public Sequence toSequence()
Provides theSequencerepresentation of thisTransmission. In case of nestedTransmissioninstances, allSequencerepresentations from all sub-segments are accumulated to the result as well. Caution, the Transmission (or its nestedTransmissioninstances) may be backed by the returnedSequence.- Specified by:
toSequencein interfaceTransmission- Returns:
- The according instance's
Sequence.
-
fromTransmission
public void fromTransmission(Sequence aSequence, int aOffset, int aLength) throws TransmissionException
(Re-)initializes this instance with the the givenSequencedata.- Specified by:
fromTransmissionin interfaceSection- Parameters:
aSequence- TheSequencedata from which to (re-)initialize this instance.aOffset- The offset where to start processing the providedSequence.aLength- The length of data assigned by theSequence.- Throws:
TransmissionException- thrown in case a givenSequencecannot be processed.
-
getLength
public int getLength()
Determines the overall length of thisTransmission. In case of nestedTransmissioninstances, all length values from all sub-segments are accumulated to the result as well.- Specified by:
getLengthin interfaceorg.refcodes.mixin.LengthAccessor- Specified by:
getLengthin interfaceTransmission- Returns:
- The (overall) length of the
Transmission(including any sub-segments).
-
toSchema
public Schema toSchema()
Retrieves theSchemarepresenting theTransmission. Retrieving aSchemais useful when analyzing and debugging data structures such as aAllocSectionDecoratorSegmentinstance to help document, learn and verify on the structure (as well as the content) of that veryAllocSectionDecoratorSegment.- Specified by:
toSchemain interfaceTransmission- Returns:
- The
Schemarepresentation of the implementing type for debugging and verification (or documentation) purposes.
-
toString
public String toString()
- Overrides:
toStringin classAbstractPayloadSection<char[]>
-
getEncoding
public Charset getEncoding()
- Specified by:
getEncodingin interfaceorg.refcodes.mixin.EncodingAccessor<Charset>
-
setPayload
public void setPayload(Character[] aPayload)
Convenience method to convert the array of wrapper types into its counterpart with primitive types before invokingAbstractPayloadSection.setPayload(Object).- Parameters:
aPayload- The payload with the wrapper types.
-
withPayload
public CharArraySection withPayload(Character[] aPayload)
Convenience method to convert the array of wrapper types into its counterpart with primitive types before invokingwithPayload(char[]).- Parameters:
aPayload- The payload with the wrapper types.- Returns:
- This instance as of the builder pattern.
-
-