- java.lang.Object
-
- org.refcodes.serial.AbstractPayloadSegment<Double>
-
- org.refcodes.serial.DoubleSegment
-
- All Implemented Interfaces:
Serializable,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.LengthAccessor,org.refcodes.mixin.PayloadAccessor<Double>,org.refcodes.mixin.PayloadAccessor.PayloadBuilder<Double,PayloadTransmission<Double>>,org.refcodes.mixin.PayloadAccessor.PayloadMutator<Double>,org.refcodes.mixin.PayloadAccessor.PayloadProperty<Double>,PayloadSegment<Double>,PayloadTransmission<Double>,Segment,Segment.SegmentMixin,Transmission,Transmission.TransmissionMixin
public class DoubleSegment extends AbstractPayloadSegment<Double> implements Segment
TheDoubleSegmentis an implementation of aSegmentcarrying in double value as payload.- See Also:
- Serialized Form
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.LengthAccessor
org.refcodes.mixin.LengthAccessor.LengthBuilder<B extends org.refcodes.mixin.LengthAccessor.LengthBuilder<B>>, org.refcodes.mixin.LengthAccessor.LengthMutator, org.refcodes.mixin.LengthAccessor.LengthProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.PayloadAccessor
org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P extends Object,B extends org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P,B>>, org.refcodes.mixin.PayloadAccessor.PayloadMutator<P extends Object>, org.refcodes.mixin.PayloadAccessor.PayloadProperty<P extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.serial.Segment
Segment.SegmentMixin
-
Nested classes/interfaces inherited from interface org.refcodes.serial.Transmission
Transmission.TransmissionMixin
-
-
Constructor Summary
Constructors Constructor Description DoubleSegment()Constructs an emptyDoubleSegmentwith aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theSegment's value.DoubleSegment(Double aValue)Constructs aDoubleSegmentwith the given double value (payload) and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theSegment's value.DoubleSegment(Double aValue, org.refcodes.numerical.Endianess aEndianess)Constructs aDoubleSegmentwith the given double value (payload) and the givenEndianessfor the representation of theSegment's value.DoubleSegment(Double aValue, TransmissionMetrics aTransmissionMetrics)Constructs an according instance from the given configuration.DoubleSegment(String aAlias)Constructs an emptyDoubleSegmentwith aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theSegment's value.DoubleSegment(String aAlias, Double aValue)Constructs aDoubleSegmentwith the given double value (payload) and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theSegment's value.DoubleSegment(String aAlias, Double aValue, org.refcodes.numerical.Endianess aEndianess)Constructs aDoubleSegmentwith the given double value (payload) and the givenEndianessfor the representation of theSegment's value.DoubleSegment(String aAlias, Double aValue, TransmissionMetrics aTransmissionMetrics)Constructs an according instance from the given configuration.DoubleSegment(String aAlias, org.refcodes.numerical.Endianess aEndianess)Constructs an emptyDoubleSegmentwith the givenEndianess.DoubleSegment(String aAlias, TransmissionMetrics aTransmissionMetrics)Constructs an according instance from the given configuration.DoubleSegment(org.refcodes.numerical.Endianess aEndianess)Constructs an emptyDoubleSegmentwith the givenEndianess.DoubleSegment(TransmissionMetrics aTransmissionMetrics)Constructs an according instance from the given configuration.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description intfromTransmission(Sequence aSequence, int aOffset)(Re-)initializes this instance with the the givenSequencedata.intgetLength()Determines the overall length of thisTransmission.SchematoSchema()Retrieves theSchemarepresenting theTransmission.SequencetoSequence()Provides theSequencerepresentation of thisTransmission.DoubleSegmentwithPayload(Double aValue)-
Methods inherited from class org.refcodes.serial.AbstractPayloadSegment
equals, getAlias, getPayload, hashCode, setPayload, toSimpleTypeMap, toString
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface org.refcodes.serial.Segment
fromTransmission, fromTransmission, fromTransmission, receiveFrom, receiveFrom
-
Methods inherited from interface org.refcodes.serial.Segment.SegmentMixin
receiveFrom
-
Methods inherited from interface org.refcodes.serial.Transmission
toSimpleTypeMap, transmitTo, transmitTo
-
Methods inherited from interface org.refcodes.serial.Transmission.TransmissionMixin
transmitTo
-
-
-
-
Field Detail
-
ENDIANESS
public static final String ENDIANESS
- See Also:
- Constant Field Values
-
BYTES
public static final int BYTES
- See Also:
- Constant Field Values
-
-
Constructor Detail
-
DoubleSegment
public DoubleSegment(TransmissionMetrics aTransmissionMetrics)
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.
-
DoubleSegment
public DoubleSegment(Double aValue, TransmissionMetrics aTransmissionMetrics)
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aValue- The payload to be contained by theDoubleArraySection.aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.
-
DoubleSegment
public DoubleSegment(String aAlias, TransmissionMetrics aTransmissionMetrics)
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aAlias- The alias which identifies the content of this instance.aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.
-
DoubleSegment
public DoubleSegment(String aAlias, Double aValue, TransmissionMetrics aTransmissionMetrics)
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aAlias- The alias which identifies the content of this instance.aValue- The payload to be contained by theDoubleArraySection.aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.
-
DoubleSegment
public DoubleSegment()
Constructs an emptyDoubleSegmentwith aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theSegment's value.
-
DoubleSegment
public DoubleSegment(org.refcodes.numerical.Endianess aEndianess)
Constructs an emptyDoubleSegmentwith the givenEndianess.- Parameters:
aEndianess- TheEndianessto be used for payload values.
-
DoubleSegment
public DoubleSegment(Double aValue)
Constructs aDoubleSegmentwith the given double value (payload) and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theSegment's value.- Parameters:
aValue- The value (payload) to be contained by theSegment.
-
DoubleSegment
public DoubleSegment(Double aValue, org.refcodes.numerical.Endianess aEndianess)
Constructs aDoubleSegmentwith the given double value (payload) and the givenEndianessfor the representation of theSegment's value.- Parameters:
aValue- The value (payload) to be contained by theSegment.aEndianess- TheEndianessto be used for payload values.
-
DoubleSegment
public DoubleSegment(String aAlias)
Constructs an emptyDoubleSegmentwith aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theSegment's value.- Parameters:
aAlias- The alias which identifies the content of this segment.
-
DoubleSegment
public DoubleSegment(String aAlias, org.refcodes.numerical.Endianess aEndianess)
Constructs an emptyDoubleSegmentwith the givenEndianess.- Parameters:
aAlias- The alias which identifies the content of this segment.aEndianess- TheEndianessto be used for payload values.
-
DoubleSegment
public DoubleSegment(String aAlias, Double aValue)
Constructs aDoubleSegmentwith the given double value (payload) and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theSegment's value.- Parameters:
aAlias- The alias which identifies the content of this segment.aValue- The value (payload) to be contained by theSegment.
-
DoubleSegment
public DoubleSegment(String aAlias, Double aValue, org.refcodes.numerical.Endianess aEndianess)
Constructs aDoubleSegmentwith the given double value (payload) and the givenEndianessfor the representation of theSegment's value.- Parameters:
aAlias- The alias which identifies the content of this segment.aValue- The value (payload) to be contained by theSegment.aEndianess- TheEndianessto be used for payload values.
-
-
Method Detail
-
toSequence
public Sequence toSequence()
Provides theSequencerepresentation of thisTransmission. In case of nestedTransmissioninstances, allSequencerepresentations from all sub-segments are accumulated to the result as well. Caution, the Transmission (or its nestedTransmissioninstances) may be backed by the returnedSequence.- Specified by:
toSequencein interfaceTransmission- Returns:
- The according instance's
Sequence.
-
fromTransmission
public int fromTransmission(Sequence aSequence, int aOffset) throws TransmissionException
(Re-)initializes this instance with the the givenSequencedata.- Specified by:
fromTransmissionin interfaceSegment- Parameters:
aSequence- TheSequencedata from which to (re-)initialize this instance.aOffset- The offset where to start processing the providedSequence.- Returns:
- The index after the last offset into the given
Sequenceprocessed by this method. - Throws:
TransmissionException- thrown in case a givenSequencecannot be processed.
-
getLength
public int getLength()
Determines the overall length of thisTransmission. In case of nestedTransmissioninstances, all length values from all sub-segments are accumulated to the result as well.- Specified by:
getLengthin interfaceorg.refcodes.mixin.LengthAccessor- Specified by:
getLengthin interfaceTransmission- Returns:
- The (overall) length of the
Transmission(including any sub-segments).
-
toSchema
public Schema toSchema()
Retrieves theSchemarepresenting theTransmission. Retrieving aSchemais useful when analyzing and debugging data structures such as aAllocSectionDecoratorSegmentinstance to help document, learn and verify on the structure (as well as the content) of that veryAllocSectionDecoratorSegment.- Specified by:
toSchemain interfaceTransmission- Returns:
- The
Schemarepresentation of the implementing type for debugging and verification (or documentation) purposes.
-
withPayload
public DoubleSegment withPayload(Double aValue)
- Specified by:
withPayloadin interfaceorg.refcodes.mixin.PayloadAccessor.PayloadBuilder<Double,PayloadTransmission<Double>>
-
-