Class FixedSegmentArraySection<ARRAY extends Segment>
java.lang.Object
org.refcodes.serial.AbstractArrayTransmission<ARRAY>
org.refcodes.serial.FixedSegmentArraySection<ARRAY>
- Type Parameters:
ARRAY- The type of the array elements to be contained in this instance.
- All Implemented Interfaces:
Serializable,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.ArrayAccessor<ARRAY[]>,org.refcodes.mixin.ArrayAccessor.ArrayBuilder<ARRAY[],,ArrayTransmission<ARRAY>> org.refcodes.mixin.ArrayAccessor.ArrayMutator<ARRAY[]>,org.refcodes.mixin.ArrayAccessor.ArrayProperty<ARRAY[]>,org.refcodes.mixin.LengthAccessor,org.refcodes.mixin.Resetable,org.refcodes.schema.Schemable,ArraySection<ARRAY>,ArrayTransmission<ARRAY>,Section,Section.SectionMixin,Transmission,Transmission.TransmissionMixin
public class FixedSegmentArraySection<ARRAY extends Segment>
extends AbstractArrayTransmission<ARRAY>
implements ArraySection<ARRAY>
A
FixedSegmentArraySection is a Section consisting of
Segment elements with each element of the same (uniform) length (in
contrast to the SegmentArraySection). When using the
FixedSegmentArraySection, it is to be taken care of the uniform
Segment elements' lengths.- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.ArrayAccessor
org.refcodes.mixin.ArrayAccessor.ArrayBuilder<T,B extends org.refcodes.mixin.ArrayAccessor.ArrayBuilder<T, B>>, org.refcodes.mixin.ArrayAccessor.ArrayMutator<T>, org.refcodes.mixin.ArrayAccessor.ArrayProperty<T> Nested classes/interfaces inherited from interface org.refcodes.mixin.LengthAccessor
org.refcodes.mixin.LengthAccessor.LengthBuilder<B extends org.refcodes.mixin.LengthAccessor.LengthBuilder<B>>, org.refcodes.mixin.LengthAccessor.LengthMutator, org.refcodes.mixin.LengthAccessor.LengthPropertyNested classes/interfaces inherited from interface org.refcodes.serial.Section
Section.SectionMixinNested classes/interfaces inherited from interface org.refcodes.serial.Transmission
Transmission.TransmissionMixin -
Field Summary
Fields inherited from class org.refcodes.serial.AbstractArrayTransmission
_alias, _array, _sequenceableFactory -
Constructor Summary
ConstructorsConstructorDescriptionFixedSegmentArraySection(ARRAY... aSegments) Instantiates the classFixedSegmentArraySection.FixedSegmentArraySection(Class<ARRAY> aSegmentClass) Instantiates the classFixedSegmentArraySection.FixedSegmentArraySection(String aAlias, ARRAY... aSegments) Instantiates the classFixedSegmentArraySection.FixedSegmentArraySection(String aAlias, Class<ARRAY> aSegmentClass) Instantiates the classFixedSegmentArraySection.FixedSegmentArraySection(String aAlias, Collection<ARRAY> aSegments) Instantiates the classFixedSegmentArraySection.FixedSegmentArraySection(String aAlias, org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory) Instantiates the classFixedSegmentArraySection.FixedSegmentArraySection(String aAlias, org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory, ARRAY... aSegments) Instantiates the classFixedSegmentArraySection.FixedSegmentArraySection(String aAlias, org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory, Collection<ARRAY> aSegments) Instantiates the classFixedSegmentArraySection.FixedSegmentArraySection(Collection<ARRAY> aSegments) Instantiates the classFixedSegmentArraySection.FixedSegmentArraySection(org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory) Instantiates the classFixedSegmentArraySection.FixedSegmentArraySection(org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory, ARRAY... aSegments) Instantiates the classFixedSegmentArraySection.FixedSegmentArraySection(org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory, Collection<ARRAY> aSegments) Instantiates the classFixedSegmentArraySection. -
Method Summary
Modifier and TypeMethodDescriptionvoidfromTransmission(Sequence aSequence, int aOffset, int aLength) (Re-)initializes this instance with the the givenSequencedata.Methods inherited from class org.refcodes.serial.AbstractArrayTransmission
getAlias, getArray, getLength, reset, setArray, toSchema, toStringMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.mixin.AliasAccessor
getAliasMethods inherited from interface org.refcodes.mixin.ArrayAccessor
getArrayMethods inherited from interface org.refcodes.mixin.ArrayAccessor.ArrayMutator
setArrayMethods inherited from interface org.refcodes.mixin.ArrayAccessor.ArrayProperty
letArrayMethods inherited from interface org.refcodes.serial.ArrayTransmission
getLength, toSchema, toSequence, toSimpleTypeTableMethods inherited from interface org.refcodes.schema.Schemable
toSchemaMethods inherited from interface org.refcodes.serial.Section
fromTransmission, fromTransmission, fromTransmission, receiveFrom, receiveFromMethods inherited from interface org.refcodes.serial.Section.SectionMixin
receiveFromMethods inherited from interface org.refcodes.serial.Transmission
reset, transmitTo, transmitToMethods inherited from interface org.refcodes.serial.Transmission.TransmissionMixin
transmitTo
-
Constructor Details
-
FixedSegmentArraySection
Instantiates the classFixedSegmentArraySection.- Parameters:
aSegmentClass- the segment class- See Also:
-
FixedSegmentArraySection
Instantiates the classFixedSegmentArraySection.- Parameters:
aSegments- the segments- See Also:
-
FixedSegmentArraySection
Instantiates the classFixedSegmentArraySection.- Parameters:
aSegments- the segments- See Also:
-
FixedSegmentArraySection
Instantiates the classFixedSegmentArraySection.- Parameters:
aAlias- the aliasaSegmentClass- the segment class- See Also:
-
FixedSegmentArraySection
Instantiates the classFixedSegmentArraySection.- Parameters:
aAlias- the aliasaSegments- the segments- See Also:
-
FixedSegmentArraySection
Instantiates the classFixedSegmentArraySection.- Parameters:
aAlias- the aliasaSegments- the segments- See Also:
-
FixedSegmentArraySection
public FixedSegmentArraySection(String aAlias, org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory, Collection<ARRAY> aSegments) Instantiates the classFixedSegmentArraySection.- Parameters:
aAlias- the aliasaSegmentFactory- the segment factoryaSegments- the segments- See Also:
-
FixedSegmentArraySection
@SafeVarargs public FixedSegmentArraySection(String aAlias, org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory, ARRAY... aSegments) Instantiates the classFixedSegmentArraySection.- Parameters:
aAlias- the aliasaSegmentFactory- the segment factoryaSegments- the segments- See Also:
-
FixedSegmentArraySection
public FixedSegmentArraySection(String aAlias, org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory) Instantiates the classFixedSegmentArraySection.- Parameters:
aAlias- the aliasaSegmentFactory- the segment factory- See Also:
-
FixedSegmentArraySection
public FixedSegmentArraySection(org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory, Collection<ARRAY> aSegments) Instantiates the classFixedSegmentArraySection.- Parameters:
aSegmentFactory- the segment factoryaSegments- the segments- See Also:
-
FixedSegmentArraySection
@SafeVarargs public FixedSegmentArraySection(org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory, ARRAY... aSegments) Instantiates the classFixedSegmentArraySection.- Parameters:
aSegmentFactory- the segment factoryaSegments- the segments- See Also:
-
FixedSegmentArraySection
Instantiates the classFixedSegmentArraySection.- Parameters:
aSegmentFactory- the segment factory- See Also:
-
-
Method Details
-
withArray
- Specified by:
withArrayin interfaceorg.refcodes.mixin.ArrayAccessor.ArrayBuilder<ARRAY extends Segment[],ArrayTransmission<ARRAY extends Segment>> - Overrides:
withArrayin classAbstractArrayTransmission<ARRAY extends Segment>
-
fromTransmission
public void fromTransmission(Sequence aSequence, int aOffset, int aLength) throws TransmissionException (Re-)initializes this instance with the the givenSequencedata.- Specified by:
fromTransmissionin interfaceSection- Parameters:
aSequence- TheSequencedata from which to (re-)initialize this instance.aOffset- The offset where to start processing the providedSequence.aLength- The length of data assigned by theSequence.- Throws:
TransmissionException- thrown in case a givenSequencecannot be processed.
-