Module org.refcodes.serial
Package org.refcodes.serial
Class FixedSegmentArraySection<ARRAY extends Segment>
- java.lang.Object
-
- org.refcodes.serial.AbstractArrayTransmission<ARRAY>
-
- org.refcodes.serial.FixedSegmentArraySection<ARRAY>
-
- Type Parameters:
ARRAY- The type of the array elements to be contained in this instance.
- All Implemented Interfaces:
Serializable,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.ArrayAccessor<ARRAY[]>,org.refcodes.mixin.ArrayAccessor.ArrayBuilder<ARRAY[],ArrayTransmission<ARRAY>>,org.refcodes.mixin.ArrayAccessor.ArrayMutator<ARRAY[]>,org.refcodes.mixin.ArrayAccessor.ArrayProperty<ARRAY[]>,org.refcodes.mixin.LengthAccessor,ArraySection<ARRAY>,ArrayTransmission<ARRAY>,Section,Section.SectionMixin,Transmission,Transmission.TransmissionMixin
public class FixedSegmentArraySection<ARRAY extends Segment> extends AbstractArrayTransmission<ARRAY> implements ArraySection<ARRAY>
AFixedSegmentArraySectionis aSectionconsisting ofSegmentelements with each element of the same (uniform) length (in contrast to theSegmentArraySection). When using theFixedSegmentArraySection, it is to be taken care of the uniformSegmentelements' lengths.- See Also:
- Serialized Form
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.ArrayAccessor
org.refcodes.mixin.ArrayAccessor.ArrayBuilder<T extends Object,B extends org.refcodes.mixin.ArrayAccessor.ArrayBuilder<T,B>>, org.refcodes.mixin.ArrayAccessor.ArrayMutator<T extends Object>, org.refcodes.mixin.ArrayAccessor.ArrayProperty<T extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.LengthAccessor
org.refcodes.mixin.LengthAccessor.LengthBuilder<B extends org.refcodes.mixin.LengthAccessor.LengthBuilder<B>>, org.refcodes.mixin.LengthAccessor.LengthMutator, org.refcodes.mixin.LengthAccessor.LengthProperty
-
Nested classes/interfaces inherited from interface org.refcodes.serial.Section
Section.SectionMixin
-
Nested classes/interfaces inherited from interface org.refcodes.serial.Transmission
Transmission.TransmissionMixin
-
-
Field Summary
-
Fields inherited from class org.refcodes.serial.AbstractArrayTransmission
_alias, _array, _sequenceableFactory
-
-
Constructor Summary
Constructors Constructor Description FixedSegmentArraySection(ARRAY... aSegments)FixedSegmentArraySection(Class<ARRAY> aSegmentClass)FixedSegmentArraySection(String aAlias, ARRAY... aSegments)FixedSegmentArraySection(String aAlias, Class<ARRAY> aSegmentClass)FixedSegmentArraySection(String aAlias, Collection<ARRAY> aSegments)FixedSegmentArraySection(String aAlias, org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory)FixedSegmentArraySection(String aAlias, org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory, ARRAY... aSegments)FixedSegmentArraySection(String aAlias, org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory, Collection<ARRAY> aSegments)FixedSegmentArraySection(Collection<ARRAY> aSegments)FixedSegmentArraySection(org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory)FixedSegmentArraySection(org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory, ARRAY... aSegments)FixedSegmentArraySection(org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory, Collection<ARRAY> aSegments)
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description voidfromTransmission(Sequence aSequence, int aOffset, int aLength)(Re-)initializes this instance with the the givenSequencedata.FixedSegmentArraySection<ARRAY>withArray(ARRAY[] aValue)-
Methods inherited from class org.refcodes.serial.AbstractArrayTransmission
getAlias, getArray, getLength, setArray, toSchema, toString
-
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface org.refcodes.serial.ArrayTransmission
getLength, toSchema, toSequence, toSimpleTypeMap
-
Methods inherited from interface org.refcodes.serial.Section
fromTransmission, fromTransmission, fromTransmission, receiveFrom, receiveFrom
-
Methods inherited from interface org.refcodes.serial.Section.SectionMixin
receiveFrom
-
Methods inherited from interface org.refcodes.serial.Transmission
transmitTo, transmitTo
-
Methods inherited from interface org.refcodes.serial.Transmission.TransmissionMixin
transmitTo
-
-
-
-
Constructor Detail
-
FixedSegmentArraySection
public FixedSegmentArraySection(Collection<ARRAY> aSegments)
-
FixedSegmentArraySection
@SafeVarargs public FixedSegmentArraySection(ARRAY... aSegments)
-
FixedSegmentArraySection
public FixedSegmentArraySection(String aAlias, Class<ARRAY> aSegmentClass)
-
FixedSegmentArraySection
public FixedSegmentArraySection(String aAlias, Collection<ARRAY> aSegments)
-
FixedSegmentArraySection
@SafeVarargs public FixedSegmentArraySection(String aAlias, ARRAY... aSegments)
-
FixedSegmentArraySection
public FixedSegmentArraySection(String aAlias, org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory, Collection<ARRAY> aSegments)
-
FixedSegmentArraySection
@SafeVarargs public FixedSegmentArraySection(String aAlias, org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory, ARRAY... aSegments)
-
FixedSegmentArraySection
public FixedSegmentArraySection(String aAlias, org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory)
-
FixedSegmentArraySection
public FixedSegmentArraySection(org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory, Collection<ARRAY> aSegments)
-
FixedSegmentArraySection
@SafeVarargs public FixedSegmentArraySection(org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory, ARRAY... aSegments)
-
FixedSegmentArraySection
public FixedSegmentArraySection(org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory)
-
-
Method Detail
-
withArray
public FixedSegmentArraySection<ARRAY> withArray(ARRAY[] aValue)
- Specified by:
withArrayin interfaceorg.refcodes.mixin.ArrayAccessor.ArrayBuilder<ARRAY extends Segment[],ArrayTransmission<ARRAY extends Segment>>- Overrides:
withArrayin classAbstractArrayTransmission<ARRAY extends Segment>
-
fromTransmission
public void fromTransmission(Sequence aSequence, int aOffset, int aLength) throws TransmissionException
(Re-)initializes this instance with the the givenSequencedata.- Specified by:
fromTransmissionin interfaceSection- Parameters:
aSequence- TheSequencedata from which to (re-)initialize this instance.aOffset- The offset where to start processing the providedSequence.aLength- The length of data assigned by theSequence.- Throws:
TransmissionException- thrown in case a givenSequencecannot be processed.
-
-