- java.lang.Object
-
- org.refcodes.serial.AbstractPayloadSection<float[]>
-
- org.refcodes.serial.FloatArraySection
-
- All Implemented Interfaces:
Serializable,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.LengthAccessor,org.refcodes.mixin.PayloadAccessor<float[]>,org.refcodes.mixin.PayloadAccessor.PayloadBuilder<float[],PayloadTransmission<float[]>>,org.refcodes.mixin.PayloadAccessor.PayloadMutator<float[]>,org.refcodes.mixin.PayloadAccessor.PayloadProperty<float[]>,PayloadSection<float[]>,PayloadTransmission<float[]>,Section,Section.SectionMixin,Transmission,Transmission.TransmissionMixin
public class FloatArraySection extends AbstractPayloadSection<float[]> implements PayloadSection<float[]>
TheFloatArraySectionis an implementation of aSectioncarrying a float array as payload.- See Also:
- Serialized Form
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.LengthAccessor
org.refcodes.mixin.LengthAccessor.LengthBuilder<B extends org.refcodes.mixin.LengthAccessor.LengthBuilder<B>>, org.refcodes.mixin.LengthAccessor.LengthMutator, org.refcodes.mixin.LengthAccessor.LengthProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.PayloadAccessor
org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P extends Object,B extends org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P,B>>, org.refcodes.mixin.PayloadAccessor.PayloadMutator<P extends Object>, org.refcodes.mixin.PayloadAccessor.PayloadProperty<P extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.serial.Section
Section.SectionMixin
-
Nested classes/interfaces inherited from interface org.refcodes.serial.Transmission
Transmission.TransmissionMixin
-
-
Field Summary
Fields Modifier and Type Field Description static StringENDIANESS-
Fields inherited from class org.refcodes.serial.AbstractPayloadSection
_alias, _payload
-
-
Constructor Summary
Constructors Constructor Description FloatArraySection()Constructs an emptyFloatArraySectionwith aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theSection's value.FloatArraySection(float... aValue)Constructs aFloatArraySectionwith the given float array payload and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theSection's value.FloatArraySection(Float... aValue)Constructs aFloatArraySectionwith the given float array payload and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theSection's value.FloatArraySection(String aAlias)Constructs an emptyFloatArraySectionwith aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theSection's value.FloatArraySection(String aAlias, float... aValue)Constructs aFloatArraySectionwith the given float array payload and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theSection's value.FloatArraySection(String aAlias, Float... aValue)Constructs aFloatArraySectionwith the given float array payload and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theSection's value.FloatArraySection(String aAlias, org.refcodes.numerical.Endianess aEndianess)Constructs an emptyFloatArraySectionwith the givenEndianess.FloatArraySection(String aAlias, org.refcodes.numerical.Endianess aEndianess, float... aValue)Constructs aFloatArraySectionwith the given float array payload andEndianessfor the representation of theSection's value.FloatArraySection(String aAlias, org.refcodes.numerical.Endianess aEndianess, Float... aValue)Constructs aFloatArraySectionwith the given float array payload andEndianessfor the representation of theSection's value.FloatArraySection(String aAlias, TransmissionMetrics aTransmissionMetrics)Constructs an according instance from the given configuration.FloatArraySection(String aAlias, TransmissionMetrics aTransmissionMetrics, float... aValue)Constructs an according instance from the given configuration.FloatArraySection(String aAlias, TransmissionMetrics aTransmissionMetrics, Float... aValue)Constructs an according instance from the given configuration.FloatArraySection(org.refcodes.numerical.Endianess aEndianess)Constructs an emptyFloatArraySectionwith the givenEndianess.FloatArraySection(org.refcodes.numerical.Endianess aEndianess, float... aValue)Constructs aFloatArraySectionwith the given float array payload andEndianessfor the representation of theSection's value.FloatArraySection(org.refcodes.numerical.Endianess aEndianess, Float... aValue)Constructs aFloatArraySectionwith the given float array payload andEndianessfor the representation of theSection's value.FloatArraySection(TransmissionMetrics aTransmissionMetrics)Constructs an according instance from the given configuration.FloatArraySection(TransmissionMetrics aTransmissionMetrics, float... aValue)Constructs an according instance from the given configuration.FloatArraySection(TransmissionMetrics aTransmissionMetrics, Float... aValue)Constructs an according instance from the given configuration.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description voidfromTransmission(Sequence aSequence, int aOffset, int aLength)(Re-)initializes this instance with the the givenSequencedata.intgetLength()Determines the overall length of thisTransmission.voidsetPayload(Float[] aPayload)Convenience method to convert the array of wrapper types into its counterpart with primitive types before invokingAbstractPayloadSection.setPayload(Object).SchematoSchema()Retrieves theSchemarepresenting theTransmission.SequencetoSequence()Provides theSequencerepresentation of thisTransmission.StringtoString()FloatArraySectionwithPayload(float[] aValue)FloatArraySectionwithPayload(Float[] aPayload)Convenience method to convert the array of wrapper types into its counterpart with primitive types before invokingwithPayload(float[]).-
Methods inherited from class org.refcodes.serial.AbstractPayloadSection
equals, getAlias, getPayload, hashCode, setPayload, toSimpleTypeMap
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface org.refcodes.serial.Section
fromTransmission, fromTransmission, fromTransmission, receiveFrom, receiveFrom
-
Methods inherited from interface org.refcodes.serial.Section.SectionMixin
receiveFrom
-
Methods inherited from interface org.refcodes.serial.Transmission
toSimpleTypeMap, transmitTo, transmitTo
-
Methods inherited from interface org.refcodes.serial.Transmission.TransmissionMixin
transmitTo
-
-
-
-
Field Detail
-
ENDIANESS
public static final String ENDIANESS
- See Also:
- Constant Field Values
-
-
Constructor Detail
-
FloatArraySection
public FloatArraySection(TransmissionMetrics aTransmissionMetrics)
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.
-
FloatArraySection
public FloatArraySection(TransmissionMetrics aTransmissionMetrics, float... aValue)
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.aValue- The payload to be contained by theFloatArraySection.
-
FloatArraySection
public FloatArraySection(TransmissionMetrics aTransmissionMetrics, Float... aValue)
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.aValue- The payload to be contained by theFloatArraySection.
-
FloatArraySection
public FloatArraySection(String aAlias, TransmissionMetrics aTransmissionMetrics)
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aAlias- The alias which identifies the content of this instance.aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.
-
FloatArraySection
public FloatArraySection(String aAlias, TransmissionMetrics aTransmissionMetrics, float... aValue)
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aAlias- The alias which identifies the content of this instance.aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.aValue- The payload to be contained by theFloatArraySection.
-
FloatArraySection
public FloatArraySection(String aAlias, TransmissionMetrics aTransmissionMetrics, Float... aValue)
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aAlias- The alias which identifies the content of this instance.aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.aValue- The payload to be contained by theFloatArraySection.
-
FloatArraySection
public FloatArraySection()
Constructs an emptyFloatArraySectionwith aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theSection's value.
-
FloatArraySection
public FloatArraySection(org.refcodes.numerical.Endianess aEndianess)
Constructs an emptyFloatArraySectionwith the givenEndianess.- Parameters:
aEndianess- TheEndianessto be used for payload values.
-
FloatArraySection
public FloatArraySection(float... aValue)
Constructs aFloatArraySectionwith the given float array payload and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theSection's value.- Parameters:
aValue- The payload to be contained by theSection.
-
FloatArraySection
public FloatArraySection(Float... aValue)
Constructs aFloatArraySectionwith the given float array payload and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theSection's value.- Parameters:
aValue- The payload to be contained by theSection.
-
FloatArraySection
public FloatArraySection(org.refcodes.numerical.Endianess aEndianess, float... aValue)Constructs aFloatArraySectionwith the given float array payload andEndianessfor the representation of theSection's value.- Parameters:
aEndianess- TheEndianessto be used for payload values.aValue- The payload to be contained by theSection.
-
FloatArraySection
public FloatArraySection(org.refcodes.numerical.Endianess aEndianess, Float... aValue)Constructs aFloatArraySectionwith the given float array payload andEndianessfor the representation of theSection's value.- Parameters:
aEndianess- TheEndianessto be used for payload values.aValue- The payload to be contained by theSection.
-
FloatArraySection
public FloatArraySection(String aAlias)
Constructs an emptyFloatArraySectionwith aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theSection's value.- Parameters:
aAlias- The alias which identifies the content of this segment.
-
FloatArraySection
public FloatArraySection(String aAlias, org.refcodes.numerical.Endianess aEndianess)
Constructs an emptyFloatArraySectionwith the givenEndianess.- Parameters:
aAlias- The alias which identifies the content of this segment.aEndianess- TheEndianessto be used for payload values.
-
FloatArraySection
public FloatArraySection(String aAlias, float... aValue)
Constructs aFloatArraySectionwith the given float array payload and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theSection's value.- Parameters:
aAlias- The alias which identifies the content of this segment.aValue- The payload to be contained by theSection.
-
FloatArraySection
public FloatArraySection(String aAlias, Float... aValue)
Constructs aFloatArraySectionwith the given float array payload and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theSection's value.- Parameters:
aAlias- The alias which identifies the content of this segment.aValue- The payload to be contained by theSection.
-
FloatArraySection
public FloatArraySection(String aAlias, org.refcodes.numerical.Endianess aEndianess, float... aValue)
Constructs aFloatArraySectionwith the given float array payload andEndianessfor the representation of theSection's value.- Parameters:
aAlias- The alias which identifies the content of this segment.aEndianess- TheEndianessto be used for payload values.aValue- The payload to be contained by theSection.
-
FloatArraySection
public FloatArraySection(String aAlias, org.refcodes.numerical.Endianess aEndianess, Float... aValue)
Constructs aFloatArraySectionwith the given float array payload andEndianessfor the representation of theSection's value.- Parameters:
aAlias- The alias which identifies the content of this segment.aEndianess- TheEndianessto be used for payload values.aValue- The payload to be contained by theSection.
-
-
Method Detail
-
toSequence
public Sequence toSequence()
Provides theSequencerepresentation of thisTransmission. In case of nestedTransmissioninstances, allSequencerepresentations from all sub-segments are accumulated to the result as well. Caution, the Transmission (or its nestedTransmissioninstances) may be backed by the returnedSequence.- Specified by:
toSequencein interfaceTransmission- Returns:
- The according instance's
Sequence.
-
fromTransmission
public void fromTransmission(Sequence aSequence, int aOffset, int aLength) throws TransmissionException
(Re-)initializes this instance with the the givenSequencedata.- Specified by:
fromTransmissionin interfaceSection- Parameters:
aSequence- TheSequencedata from which to (re-)initialize this instance.aOffset- The offset where to start processing the providedSequence.aLength- The length of data assigned by theSequence.- Throws:
TransmissionException- thrown in case a givenSequencecannot be processed.
-
getLength
public int getLength()
Determines the overall length of thisTransmission. In case of nestedTransmissioninstances, all length values from all sub-segments are accumulated to the result as well.- Specified by:
getLengthin interfaceorg.refcodes.mixin.LengthAccessor- Specified by:
getLengthin interfaceTransmission- Returns:
- The (overall) length of the
Transmission(including any sub-segments).
-
toSchema
public Schema toSchema()
Retrieves theSchemarepresenting theTransmission. Retrieving aSchemais useful when analyzing and debugging data structures such as aAllocSectionDecoratorSegmentinstance to help document, learn and verify on the structure (as well as the content) of that veryAllocSectionDecoratorSegment.- Specified by:
toSchemain interfaceTransmission- Returns:
- The
Schemarepresentation of the implementing type for debugging and verification (or documentation) purposes.
-
toString
public String toString()
- Overrides:
toStringin classAbstractPayloadSection<float[]>
-
withPayload
public FloatArraySection withPayload(float[] aValue)
- Specified by:
withPayloadin interfaceorg.refcodes.mixin.PayloadAccessor.PayloadBuilder<float[],PayloadTransmission<float[]>>
-
setPayload
public void setPayload(Float[] aPayload)
Convenience method to convert the array of wrapper types into its counterpart with primitive types before invokingAbstractPayloadSection.setPayload(Object).- Parameters:
aPayload- The payload with the wrapper types.
-
withPayload
public FloatArraySection withPayload(Float[] aPayload)
Convenience method to convert the array of wrapper types into its counterpart with primitive types before invokingwithPayload(float[]).- Parameters:
aPayload- The payload with the wrapper types.- Returns:
- This instance as of the builder pattern.
-
-