- All Implemented Interfaces:
Serializable,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.LengthAccessor,org.refcodes.mixin.PayloadAccessor<Float>,org.refcodes.mixin.PayloadAccessor.PayloadBuilder<Float,PayloadTransmission<Float>>,org.refcodes.mixin.PayloadAccessor.PayloadMutator<Float>,org.refcodes.mixin.PayloadAccessor.PayloadProperty<Float>,PayloadSegment<Float>,PayloadTransmission<Float>,Segment,Segment.SegmentMixin,Transmission,Transmission.TransmissionMixin
public class FloatSegment extends AbstractPayloadSegment<Float> implements Segment
The
FloatSegment is an implementation of a Segment carrying
in float value as payload.- See Also:
- Serialized Form
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.LengthAccessor
org.refcodes.mixin.LengthAccessor.LengthBuilder<B extends org.refcodes.mixin.LengthAccessor.LengthBuilder<B>>, org.refcodes.mixin.LengthAccessor.LengthMutator, org.refcodes.mixin.LengthAccessor.LengthPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.PayloadAccessor
org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P extends Object,B extends org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P,B>>, org.refcodes.mixin.PayloadAccessor.PayloadMutator<P extends Object>, org.refcodes.mixin.PayloadAccessor.PayloadProperty<P extends Object>Nested classes/interfaces inherited from interface org.refcodes.serial.Segment
Segment.SegmentMixinNested classes/interfaces inherited from interface org.refcodes.serial.Transmission
Transmission.TransmissionMixin -
Field Summary
Fields inherited from class org.refcodes.serial.AbstractPayloadSegment
_alias, _payload -
Constructor Summary
Constructors Constructor Description FloatSegment()Constructs an emptyFloatSegmentwith aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theFloatSegment's value.FloatSegment(Float aValue)Constructs aFloatSegmentwith the given float value (payload) and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theFloatSegment's value.FloatSegment(Float aValue, org.refcodes.numerical.Endianess aEndianess)Constructs aFloatSegmentwith the given float value (payload) and the givenEndianessfor the representation of theFloatSegment's value.FloatSegment(Float aValue, TransmissionMetrics aTransmissionMetrics)Constructs an according instance from the given configuration.FloatSegment(String aAlias)Constructs an emptyFloatSegmentwith aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theFloatSegment's value.FloatSegment(String aAlias, Float aValue)Constructs aFloatSegmentwith the given float value (payload) and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theFloatSegment's value.FloatSegment(String aAlias, Float aValue, org.refcodes.numerical.Endianess aEndianess)Constructs aFloatSegmentwith the given float value (payload) and the givenEndianessfor the representation of theFloatSegment's value.FloatSegment(String aAlias, Float aValue, TransmissionMetrics aTransmissionMetrics)Constructs an according instance from the given configuration.FloatSegment(String aAlias, org.refcodes.numerical.Endianess aEndianess)Constructs an emptyFloatSegmentwith the givenEndianess.FloatSegment(String aAlias, TransmissionMetrics aTransmissionMetrics)Constructs an according instance from the given configuration.FloatSegment(org.refcodes.numerical.Endianess aEndianess)Constructs an emptyFloatSegmentwith the givenEndianess.FloatSegment(TransmissionMetrics aTransmissionMetrics)Constructs an according instance from the given configuration. -
Method Summary
Modifier and Type Method Description intfromTransmission(Sequence aSequence, int aOffset)(Re-)initializes this instance with the the givenSequencedata.intgetLength()Determines the overall length of thisTransmission.SchematoSchema()Retrieves theSchemarepresenting theTransmission.SequencetoTransmission()Provides theSequencerepresentation of thisTransmission.FloatSegmentwithPayload(Float aValue)Methods inherited from class org.refcodes.serial.AbstractPayloadSegment
equals, getAlias, getPayload, hashCode, setPayload, toSimpleTypeMap, toStringMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.mixin.PayloadAccessor
getPayloadOrMethods inherited from interface org.refcodes.mixin.PayloadAccessor.PayloadProperty
letPayloadMethods inherited from interface org.refcodes.serial.Segment
fromTransmission, fromTransmission, fromTransmission, receiveFrom, receiveFromMethods inherited from interface org.refcodes.serial.Segment.SegmentMixin
receiveFromMethods inherited from interface org.refcodes.serial.Transmission
toSimpleTypeMap, transmitTo, transmitToMethods inherited from interface org.refcodes.serial.Transmission.TransmissionMixin
transmitTo
-
Field Details
-
ENDIANESS
- See Also:
- Constant Field Values
-
BYTES
public static final int BYTES- See Also:
- Constant Field Values
-
-
Constructor Details
-
FloatSegment
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.
-
FloatSegment
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aValue- The payload to be contained by theDoubleArraySection.aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.
-
FloatSegment
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aAlias- The alias which identifies the content of this instance.aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.
-
FloatSegment
Constructs an according instance from the given configuration. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aAlias- The alias which identifies the content of this instance.aValue- The payload to be contained by theDoubleArraySection.aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.
-
FloatSegment
public FloatSegment()Constructs an emptyFloatSegmentwith aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theFloatSegment's value. -
FloatSegment
public FloatSegment(org.refcodes.numerical.Endianess aEndianess)Constructs an emptyFloatSegmentwith the givenEndianess.- Parameters:
aEndianess- TheEndianessto be used for payload values.
-
FloatSegment
Constructs aFloatSegmentwith the given float value (payload) and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theFloatSegment's value.- Parameters:
aValue- The value (payload) to be contained by theFloatSegment.
-
FloatSegment
Constructs aFloatSegmentwith the given float value (payload) and the givenEndianessfor the representation of theFloatSegment's value.- Parameters:
aValue- The value (payload) to be contained by theFloatSegment.aEndianess- TheEndianessto be used for payload values.
-
FloatSegment
Constructs an emptyFloatSegmentwith aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theFloatSegment's value.- Parameters:
aAlias- The alias which identifies the content of this segment.
-
FloatSegment
Constructs an emptyFloatSegmentwith the givenEndianess.- Parameters:
aAlias- The alias which identifies the content of this segment.aEndianess- TheEndianessto be used for payload values.
-
FloatSegment
Constructs aFloatSegmentwith the given float value (payload) and aTransmissionMetrics.DEFAULT_ENDIANESSendian representation of theFloatSegment's value.- Parameters:
aAlias- The alias which identifies the content of this segment.aValue- The value (payload) to be contained by theFloatSegment.
-
FloatSegment
Constructs aFloatSegmentwith the given float value (payload) and the givenEndianessfor the representation of theFloatSegment's value.- Parameters:
aAlias- The alias which identifies the content of this segment.aValue- The value (payload) to be contained by theFloatSegment.aEndianess- TheEndianessto be used for payload values.
-
-
Method Details
-
toTransmission
Provides theSequencerepresentation of thisTransmission. In case of nestedTransmissioninstances, allSequencerepresentations from all sub-segments are accumulated to the result as well.- Specified by:
toTransmissionin interfaceTransmission- Returns:
- The according instance's
Sequence.
-
fromTransmission
(Re-)initializes this instance with the the givenSequencedata.- Specified by:
fromTransmissionin interfaceSegment- Parameters:
aSequence- TheSequencedata from which to (re-)initialize this instance.aOffset- The offset where to start processing the providedSequence.- Returns:
- The index after the last offset into the given
Sequenceprocessed by this method. - Throws:
TransmissionException- thrown in case a givenSequencecannot be processed.
-
getLength
public int getLength()Determines the overall length of thisTransmission. In case of nestedTransmissioninstances, all length values from all sub-segments are accumulated to the result as well.- Specified by:
getLengthin interfaceorg.refcodes.mixin.LengthAccessor- Specified by:
getLengthin interfaceTransmission- Returns:
- The (overall) length of the
Transmission(including any sub-segments).
-
toSchema
Retrieves theSchemarepresenting theTransmission. Retrieving aSchemais useful when analyzing and debugging data structures such as aAllocSectionDecoratorSegmentinstance to help document, learn and verify on the structure (as well as the content) of that veryAllocSectionDecoratorSegment.- Specified by:
toSchemain interfaceTransmission- Returns:
- The
Schemarepresentation of the implementing type for debugging and verification (or documentation) purposes.
-
withPayload
- Specified by:
withPayloadin interfaceorg.refcodes.mixin.PayloadAccessor.PayloadBuilder<Float,PayloadTransmission<Float>>
-