Class FlowControlRetryException
java.lang.Object
java.lang.Throwable
java.lang.Exception
java.io.IOException
org.refcodes.exception.AbstractIOException
org.refcodes.serial.SerialException
org.refcodes.serial.TransmissionException
org.refcodes.serial.FlowControlException
org.refcodes.serial.FlowControlTimeoutException
org.refcodes.serial.FlowControlRetryException
- All Implemented Interfaces:
Serializable,org.refcodes.exception.ErrorCodeAccessor,org.refcodes.exception.Trap,org.refcodes.mixin.RetryNumberAccessor,org.refcodes.mixin.TimeoutMillisAccessor
public class FlowControlRetryException
extends FlowControlTimeoutException
implements org.refcodes.mixin.RetryNumberAccessor
Thrown in case a flow control failed due t a timeout.
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B extends org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B>>, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeMutator, org.refcodes.exception.ErrorCodeAccessor.ErrorCodePropertyNested classes/interfaces inherited from interface org.refcodes.mixin.RetryNumberAccessor
org.refcodes.mixin.RetryNumberAccessor.RetryNumberBuilder<B extends org.refcodes.mixin.RetryNumberAccessor.RetryNumberBuilder<B>>, org.refcodes.mixin.RetryNumberAccessor.RetryNumberMutator, org.refcodes.mixin.RetryNumberAccessor.RetryNumberPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.TimeoutMillisAccessor
org.refcodes.mixin.TimeoutMillisAccessor.TimeoutMillisBuilder<B extends org.refcodes.mixin.TimeoutMillisAccessor.TimeoutMillisBuilder<B>>, org.refcodes.mixin.TimeoutMillisAccessor.TimeoutMillisMutator, org.refcodes.mixin.TimeoutMillisAccessor.TimeoutMillisProperty -
Constructor Summary
ConstructorsConstructorDescriptionFlowControlRetryException(int aRetryNumber, long aTimeoutMillis, String aMessage) Instantiates the classFlowControlRetryException.FlowControlRetryException(int aRetryNumber, long aTimeoutMillis, String aMessage, String aErrorCode) Instantiates the classFlowControlRetryException.FlowControlRetryException(int aRetryNumber, long aTimeoutMillis, String aMessage, Throwable aCause) Instantiates the classFlowControlRetryException.FlowControlRetryException(int aRetryNumber, long aTimeoutMillis, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classFlowControlRetryException.FlowControlRetryException(int aRetryNumber, long aTimeoutMillis, Throwable aCause) Instantiates the classFlowControlRetryException.FlowControlRetryException(int aRetryNumber, long aTimeoutMillis, Throwable aCause, String aErrorCode) Instantiates the classFlowControlRetryException. -
Method Summary
Methods inherited from class org.refcodes.serial.FlowControlTimeoutException
getTimeoutMillisMethods inherited from class org.refcodes.exception.AbstractIOException
getErrorCodeMethods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.exception.Trap
getPatternArguments, toLocalizedMessage, toMessage, toMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
FlowControlRetryException
public FlowControlRetryException(int aRetryNumber, long aTimeoutMillis, String aMessage, String aErrorCode) Instantiates the classFlowControlRetryException.- Parameters:
aRetryNumber- The number of retries after which the exception occurred.aTimeoutMillis- the timeout millisaMessage- the messageaErrorCode- the error code- See Also:
-
FlowControlRetryException
public FlowControlRetryException(int aRetryNumber, long aTimeoutMillis, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classFlowControlRetryException.- Parameters:
aRetryNumber- The number of retries after which the exception occurred.aTimeoutMillis- the timeout millisaMessage- the messageaCause- the causeaErrorCode- the error code- See Also:
-
FlowControlRetryException
public FlowControlRetryException(int aRetryNumber, long aTimeoutMillis, String aMessage, Throwable aCause) Instantiates the classFlowControlRetryException.- Parameters:
aRetryNumber- The number of retries after which the exception occurred.aTimeoutMillis- the timeout millisaMessage- the messageaCause- the cause- See Also:
-
FlowControlRetryException
Instantiates the classFlowControlRetryException.- Parameters:
aRetryNumber- The number of retries after which the exception occurred.aTimeoutMillis- the timeout millisaMessage- the message- See Also:
-
FlowControlRetryException
public FlowControlRetryException(int aRetryNumber, long aTimeoutMillis, Throwable aCause, String aErrorCode) Instantiates the classFlowControlRetryException.- Parameters:
aRetryNumber- The number of retries after which the exception occurred.aTimeoutMillis- the timeout millisaCause- the causeaErrorCode- the error code- See Also:
-
FlowControlRetryException
Instantiates the classFlowControlRetryException.- Parameters:
aRetryNumber- The number of retries after which the exception occurred.aTimeoutMillis- the timeout millisaCause- the cause- See Also:
-
-
Method Details
-
getRetryNumber
public int getRetryNumber()The timeout attribute in milliseconds.- Specified by:
getRetryNumberin interfaceorg.refcodes.mixin.RetryNumberAccessor- Returns:
- An long integer with the timeout in milliseconds.
-