Class FlowControlRetryException

All Implemented Interfaces:
Serializable, org.refcodes.exception.ErrorCodeAccessor, org.refcodes.exception.Trap, org.refcodes.mixin.RetryNumberAccessor, org.refcodes.mixin.TimeoutInMsAccessor

public class FlowControlRetryException
extends FlowControlTimeoutException
implements org.refcodes.mixin.RetryNumberAccessor
Thrown in case a flow control failed due t a timeout.
See Also:
Serialized Form
  • Constructor Details

    • FlowControlRetryException

      public FlowControlRetryException​(int aRetryNumber, long aTimeoutInMs, String aMessage, String aErrorCode)
      Parameters:
      aRetryNumber - The number of retries after which the exception occurred.
    • FlowControlRetryException

      public FlowControlRetryException​(int aRetryNumber, long aTimeoutInMs, String aMessage, Throwable aCause, String aErrorCode)
      Parameters:
      aRetryNumber - The number of retries after which the exception occurred.
    • FlowControlRetryException

      public FlowControlRetryException​(int aRetryNumber, long aTimeoutInMs, String aMessage, Throwable aCause)
      Parameters:
      aRetryNumber - The number of retries after which the exception occurred.
    • FlowControlRetryException

      public FlowControlRetryException​(int aRetryNumber, long aTimeoutInMs, String aMessage)
      Parameters:
      aRetryNumber - The number of retries after which the exception occurred.
    • FlowControlRetryException

      public FlowControlRetryException​(int aRetryNumber, long aTimeoutInMs, Throwable aCause, String aErrorCode)
      Parameters:
      aRetryNumber - The number of retries after which the exception occurred.
    • FlowControlRetryException

      public FlowControlRetryException​(int aRetryNumber, long aTimeoutInMs, Throwable aCause)
      Parameters:
      aRetryNumber - The number of retries after which the exception occurred.
  • Method Details

    • getRetryNumber

      public int getRetryNumber()
      The timeout attribute in milliseconds.
      Specified by:
      getRetryNumber in interface org.refcodes.mixin.RetryNumberAccessor
      Returns:
      An integer with the timeout in milliseconds.