java.lang.Object
java.lang.Throwable
java.lang.Exception
java.io.IOException
org.refcodes.exception.AbstractIOException
org.refcodes.serial.SerialException
org.refcodes.serial.TransmissionException
org.refcodes.serial.FlowControlException
org.refcodes.serial.FlowControlTimeoutException
org.refcodes.serial.FlowControlRetryException
- All Implemented Interfaces:
Serializable,org.refcodes.exception.ErrorCodeAccessor,org.refcodes.exception.Trap,org.refcodes.mixin.RetryNumberAccessor,org.refcodes.mixin.TimeoutInMsAccessor
public class FlowControlRetryException extends FlowControlTimeoutException implements org.refcodes.mixin.RetryNumberAccessor
Thrown in case a flow control failed due t a timeout.
- See Also:
- Serialized Form
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B extends org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B>>, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeMutator, org.refcodes.exception.ErrorCodeAccessor.ErrorCodePropertyNested classes/interfaces inherited from interface org.refcodes.mixin.RetryNumberAccessor
org.refcodes.mixin.RetryNumberAccessor.RetryNumberBuilder<B extends org.refcodes.mixin.RetryNumberAccessor.RetryNumberBuilder<B>>, org.refcodes.mixin.RetryNumberAccessor.RetryNumberMutator, org.refcodes.mixin.RetryNumberAccessor.RetryNumberPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.TimeoutInMsAccessor
org.refcodes.mixin.TimeoutInMsAccessor.TimeoutInMsBuilder<B extends org.refcodes.mixin.TimeoutInMsAccessor.TimeoutInMsBuilder<B>>, org.refcodes.mixin.TimeoutInMsAccessor.TimeoutInMsMutator, org.refcodes.mixin.TimeoutInMsAccessor.TimeoutInMsProperty -
Constructor Summary
Constructors Constructor Description FlowControlRetryException(int aRetryNumber, long aTimeoutInMs, String aMessage)FlowControlRetryException(int aRetryNumber, long aTimeoutInMs, String aMessage, String aErrorCode)FlowControlRetryException(int aRetryNumber, long aTimeoutInMs, String aMessage, Throwable aCause)FlowControlRetryException(int aRetryNumber, long aTimeoutInMs, String aMessage, Throwable aCause, String aErrorCode)FlowControlRetryException(int aRetryNumber, long aTimeoutInMs, Throwable aCause)FlowControlRetryException(int aRetryNumber, long aTimeoutInMs, Throwable aCause, String aErrorCode) -
Method Summary
Modifier and Type Method Description intgetRetryNumber()The timeout attribute in milliseconds.Methods inherited from class org.refcodes.serial.FlowControlTimeoutException
getTimeoutInMsMethods inherited from class org.refcodes.exception.AbstractIOException
getErrorCodeMethods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toString
-
Constructor Details
-
FlowControlRetryException
public FlowControlRetryException(int aRetryNumber, long aTimeoutInMs, String aMessage, String aErrorCode)- Parameters:
aRetryNumber- The number of retries after which the exception occurred.
-
FlowControlRetryException
public FlowControlRetryException(int aRetryNumber, long aTimeoutInMs, String aMessage, Throwable aCause, String aErrorCode)- Parameters:
aRetryNumber- The number of retries after which the exception occurred.
-
FlowControlRetryException
public FlowControlRetryException(int aRetryNumber, long aTimeoutInMs, String aMessage, Throwable aCause)- Parameters:
aRetryNumber- The number of retries after which the exception occurred.
-
FlowControlRetryException
- Parameters:
aRetryNumber- The number of retries after which the exception occurred.
-
FlowControlRetryException
public FlowControlRetryException(int aRetryNumber, long aTimeoutInMs, Throwable aCause, String aErrorCode)- Parameters:
aRetryNumber- The number of retries after which the exception occurred.
-
FlowControlRetryException
- Parameters:
aRetryNumber- The number of retries after which the exception occurred.
-
-
Method Details
-
getRetryNumber
public int getRetryNumber()The timeout attribute in milliseconds.- Specified by:
getRetryNumberin interfaceorg.refcodes.mixin.RetryNumberAccessor- Returns:
- An integer with the timeout in milliseconds.
-