-
- All Known Subinterfaces:
MagicBytesLengthAccessor.MagicBytesLengthProperty
- All Known Implementing Classes:
AbstractMagicBytesTransmission,AbstractMagicBytesTransmissionDecorator,AssertMagicBytesSectionDecorator,AssertMagicBytesSegment,AssertMagicBytesSegmentDecorator,MagicBytesSectionDecorator,MagicBytesSegment,MagicBytesSegmentDecorator,TransmissionMetrics
public interface MagicBytesLengthAccessorProvides an accessor for a magic bytes length property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceMagicBytesLengthAccessor.MagicBytesLengthBuilder<B extends MagicBytesLengthAccessor.MagicBytesLengthBuilder<B>>Provides a builder method for a magic bytes length property returning the builder for applying multiple build operations.static interfaceMagicBytesLengthAccessor.MagicBytesLengthMutatorProvides a mutator for a magic bytes length property.static interfaceMagicBytesLengthAccessor.MagicBytesLengthPropertyProvides a magic bytes length property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description intgetMagicBytesLength()Retrieves the magic bytes length from the magic bytes magic bytes length property.
-