Module org.refcodes.serial
Package org.refcodes.serial
Interface PacketLengthWidthAccessor.PacketLengthWidthMutator
- All Known Subinterfaces:
PacketLengthWidthAccessor.PacketLengthWidthProperty
- All Known Implementing Classes:
TransmissionMetricsBuilder
- Enclosing interface:
- PacketLengthWidthAccessor
public static interface PacketLengthWidthAccessor.PacketLengthWidthMutator
Provides a mutator for a packet length width (in bytes) property.
-
Method Summary
Modifier and Type Method Description voidsetPacketLengthWidth(int aPacketLengthWidth)Sets the packet length width (in bytes) for the packet length width (in bytes) property.
-
Method Details
-
setPacketLengthWidth
void setPacketLengthWidth(int aPacketLengthWidth)Sets the packet length width (in bytes) for the packet length width (in bytes) property.- Parameters:
aPacketLengthWidth- The packet length width (in bytes) to be stored by the packet length width (in bytes) property.
-