Interface PacketMagicBytesAccessor.PacketMagicBytesMutator

All Known Subinterfaces:
PacketMagicBytesAccessor.PacketMagicBytesProperty
All Known Implementing Classes:
TransmissionMetricsBuilder
Enclosing interface:
PacketMagicBytesAccessor

public static interface PacketMagicBytesAccessor.PacketMagicBytesMutator
Provides a mutator for a packet magic bytes property.
  • Method Summary

    Modifier and Type Method Description
    void setPacketMagicBytes​(byte[] aPacketMagicBytes)
    Sets the magic bytes for the packet magic bytes property.
    default void setPacketMagicBytes​(String aPacketMagicBytes)
    Sets the magic bytes for the packet magic bytes property.
    default void setPacketMagicBytes​(String aPacketMagicBytes, Charset aEncoding)
    Sets the magic bytes for the packet magic bytes property.
  • Method Details

    • setPacketMagicBytes

      void setPacketMagicBytes​(byte[] aPacketMagicBytes)
      Sets the magic bytes for the packet magic bytes property.
      Parameters:
      aPacketMagicBytes - The magic bytes to be stored by the packet magic bytes property.
    • setPacketMagicBytes

      default void setPacketMagicBytes​(String aPacketMagicBytes)
      Sets the magic bytes for the packet magic bytes property. Uses TransmissionMetrics.DEFAULT_ENCODING for converting the String into a byte array.
      Parameters:
      aPacketMagicBytes - The magic bytes to be stored by the magic bytes property.
    • setPacketMagicBytes

      default void setPacketMagicBytes​(String aPacketMagicBytes, Charset aEncoding)
      Sets the magic bytes for the packet magic bytes property.
      Parameters:
      aPacketMagicBytes - The magic bytes to be stored by the magic bytes property.
      aEncoding - The string's bytes are converted using the given Charset.