- java.lang.Object
-
- org.refcodes.serial.AbstractPayloadSection<org.refcodes.properties.Properties>
-
- org.refcodes.serial.PropertiesSection
-
- All Implemented Interfaces:
Serializable,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.EncodingAccessor<Charset>,org.refcodes.mixin.LengthAccessor,org.refcodes.mixin.PayloadAccessor<org.refcodes.properties.Properties>,org.refcodes.mixin.PayloadAccessor.PayloadBuilder<org.refcodes.properties.Properties,PayloadTransmission<org.refcodes.properties.Properties>>,org.refcodes.mixin.PayloadAccessor.PayloadMutator<org.refcodes.properties.Properties>,org.refcodes.mixin.PayloadAccessor.PayloadProperty<org.refcodes.properties.Properties>,PayloadSection<org.refcodes.properties.Properties>,PayloadTransmission<org.refcodes.properties.Properties>,Section,Section.SectionMixin,Transmission,Transmission.TransmissionMixin
public class PropertiesSection extends AbstractPayloadSection<org.refcodes.properties.Properties> implements Section, org.refcodes.mixin.EncodingAccessor<Charset>
- See Also:
- Serialized Form
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.EncodingAccessor
org.refcodes.mixin.EncodingAccessor.EncodingBuilder<E extends Object,B extends org.refcodes.mixin.EncodingAccessor.EncodingBuilder<E,B>>, org.refcodes.mixin.EncodingAccessor.EncodingMutator<E extends Object>, org.refcodes.mixin.EncodingAccessor.EncodingProperty<E extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.LengthAccessor
org.refcodes.mixin.LengthAccessor.LengthBuilder<B extends org.refcodes.mixin.LengthAccessor.LengthBuilder<B>>, org.refcodes.mixin.LengthAccessor.LengthMutator, org.refcodes.mixin.LengthAccessor.LengthProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.PayloadAccessor
org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P extends Object,B extends org.refcodes.mixin.PayloadAccessor.PayloadBuilder<P,B>>, org.refcodes.mixin.PayloadAccessor.PayloadMutator<P extends Object>, org.refcodes.mixin.PayloadAccessor.PayloadProperty<P extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.serial.Section
Section.SectionMixin
-
Nested classes/interfaces inherited from interface org.refcodes.serial.Transmission
Transmission.TransmissionMixin
-
-
Field Summary
-
Fields inherited from class org.refcodes.serial.AbstractPayloadSection
_alias, _payload
-
-
Constructor Summary
Constructors Constructor Description PropertiesSection()Constructs an emptyPropertiesSectionusing UTF-8 encoding for the payload.PropertiesSection(String aAlias)Constructs an emptyPropertiesSectionusing UTF-8 encoding for the payload.PropertiesSection(String aAlias, Charset aCharset)Constructs aPropertiesSectionwith a payload expected to be encoded with the givenCharset.PropertiesSection(String aAlias, org.refcodes.properties.Properties aPayload)Constructs aPropertiesSectionwith the givenPropertiespayload being UTF-8 encoded.PropertiesSection(String aAlias, org.refcodes.properties.Properties aPayload, Charset aCharset)Constructs aPropertiesSectionwith the givenPropertiespayload being encoded with the givenCharset.PropertiesSection(String aAlias, org.refcodes.properties.Properties aPayload, TransmissionMetrics aTransmissionMetrics)Constructs aPropertiesSectionwith the givenPropertiespayload being encoded with the givenCharset.PropertiesSection(Charset aCharset)Constructs aPropertiesSectionwith a payload expected to be encoded with the givenCharset.PropertiesSection(org.refcodes.properties.Properties aPayload)Constructs aPropertiesSectionwith the givenPropertiespayload being UTF-8 encoded.PropertiesSection(org.refcodes.properties.Properties aPayload, Charset aCharset)Constructs aPropertiesSectionwith the givenPropertiespayload being encoded with the givenCharset.PropertiesSection(org.refcodes.properties.Properties aPayload, TransmissionMetrics aTransmissionMetrics)Constructs aPropertiesSectionwith the givenPropertiespayload being encoded with the givenCharset.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description booleanequals(Object obj)voidfromTransmission(Sequence aSequence, int aOffset, int aLength)(Re-)initializes this instance with the the givenSequencedata.CharsetgetEncoding()intgetLength()Determines the overall length of thisTransmission.inthashCode()SchematoSchema()Retrieves theSchemarepresenting theTransmission.SequencetoSequence()Provides theSequencerepresentation of thisTransmission.org.refcodes.struct.SimpleTypeMaptoSimpleTypeMap()Returns theSimpleTypeMaprepresentation of thisTransmission.PropertiesSectionwithPayload(org.refcodes.properties.Properties aValue)-
Methods inherited from class org.refcodes.serial.AbstractPayloadSection
getAlias, getPayload, setPayload, toString
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface org.refcodes.serial.Section
fromTransmission, fromTransmission, fromTransmission, receiveFrom, receiveFrom
-
Methods inherited from interface org.refcodes.serial.Section.SectionMixin
receiveFrom
-
Methods inherited from interface org.refcodes.serial.Transmission
transmitTo, transmitTo
-
Methods inherited from interface org.refcodes.serial.Transmission.TransmissionMixin
transmitTo
-
-
-
-
Constructor Detail
-
PropertiesSection
public PropertiesSection(org.refcodes.properties.Properties aPayload, TransmissionMetrics aTransmissionMetrics)Constructs aPropertiesSectionwith the givenPropertiespayload being encoded with the givenCharset. The properties from the payload are copied into thePropertiesSection. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aPayload- The payload to be contained by theSection.aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.
-
PropertiesSection
public PropertiesSection(String aAlias, org.refcodes.properties.Properties aPayload, TransmissionMetrics aTransmissionMetrics)
Constructs aPropertiesSectionwith the givenPropertiespayload being encoded with the givenCharset. The properties from the payload are copied into thePropertiesSection. The configuration attributes are taken from theTransmissionMetricsconfiguration object, though only those attributes are supported which are also supported by the other constructors!- Parameters:
aAlias- The alias which identifies the content of this segment.aPayload- The payload to be contained by theSection.aTransmissionMetrics- TheTransmissionMetricsto be used for configuring this instance.
-
PropertiesSection
public PropertiesSection()
Constructs an emptyPropertiesSectionusing UTF-8 encoding for the payload.
-
PropertiesSection
public PropertiesSection(org.refcodes.properties.Properties aPayload)
Constructs aPropertiesSectionwith the givenPropertiespayload being UTF-8 encoded. The properties from the payload are copied into thePropertiesSection.- Parameters:
aPayload- The payload to be contained by theSection.
-
PropertiesSection
public PropertiesSection(Charset aCharset)
Constructs aPropertiesSectionwith a payload expected to be encoded with the givenCharset.
-
PropertiesSection
public PropertiesSection(org.refcodes.properties.Properties aPayload, Charset aCharset)Constructs aPropertiesSectionwith the givenPropertiespayload being encoded with the givenCharset. The properties from the payload are copied into thePropertiesSection.
-
PropertiesSection
public PropertiesSection(String aAlias)
Constructs an emptyPropertiesSectionusing UTF-8 encoding for the payload.- Parameters:
aAlias- The alias which identifies the content of this segment.
-
PropertiesSection
public PropertiesSection(String aAlias, org.refcodes.properties.Properties aPayload)
Constructs aPropertiesSectionwith the givenPropertiespayload being UTF-8 encoded. The properties from the payload are copied into thePropertiesSection.- Parameters:
aAlias- The alias which identifies the content of this segment.aPayload- The payload to be contained by theSection.
-
PropertiesSection
public PropertiesSection(String aAlias, Charset aCharset)
Constructs aPropertiesSectionwith a payload expected to be encoded with the givenCharset.
-
PropertiesSection
public PropertiesSection(String aAlias, org.refcodes.properties.Properties aPayload, Charset aCharset)
Constructs aPropertiesSectionwith the givenPropertiespayload being encoded with the givenCharset. The properties from the payload are copied into thePropertiesSection.
-
-
Method Detail
-
toSequence
public Sequence toSequence()
Provides theSequencerepresentation of thisTransmission. In case of nestedTransmissioninstances, allSequencerepresentations from all sub-segments are accumulated to the result as well. Caution, the Transmission (or its nestedTransmissioninstances) may be backed by the returnedSequence.- Specified by:
toSequencein interfaceTransmission- Returns:
- The according instance's
Sequence.
-
fromTransmission
public void fromTransmission(Sequence aSequence, int aOffset, int aLength) throws TransmissionException
(Re-)initializes this instance with the the givenSequencedata.- Specified by:
fromTransmissionin interfaceSection- Parameters:
aSequence- TheSequencedata from which to (re-)initialize this instance.aOffset- The offset where to start processing the providedSequence.aLength- The length of data assigned by theSequence.- Throws:
TransmissionException- thrown in case a givenSequencecannot be processed.
-
getLength
public int getLength()
Determines the overall length of thisTransmission. In case of nestedTransmissioninstances, all length values from all sub-segments are accumulated to the result as well.- Specified by:
getLengthin interfaceorg.refcodes.mixin.LengthAccessor- Specified by:
getLengthin interfaceTransmission- Returns:
- The (overall) length of the
Transmission(including any sub-segments).
-
toSchema
public Schema toSchema()
Retrieves theSchemarepresenting theTransmission. Retrieving aSchemais useful when analyzing and debugging data structures such as aAllocSectionDecoratorSegmentinstance to help document, learn and verify on the structure (as well as the content) of that veryAllocSectionDecoratorSegment.- Specified by:
toSchemain interfaceTransmission- Returns:
- The
Schemarepresentation of the implementing type for debugging and verification (or documentation) purposes.
-
hashCode
public int hashCode()
- Overrides:
hashCodein classAbstractPayloadSection<org.refcodes.properties.Properties>
-
equals
public boolean equals(Object obj)
- Overrides:
equalsin classAbstractPayloadSection<org.refcodes.properties.Properties>
-
withPayload
public PropertiesSection withPayload(org.refcodes.properties.Properties aValue)
- Specified by:
withPayloadin interfaceorg.refcodes.mixin.PayloadAccessor.PayloadBuilder<org.refcodes.properties.Properties,PayloadTransmission<org.refcodes.properties.Properties>>
-
toSimpleTypeMap
public org.refcodes.struct.SimpleTypeMap toSimpleTypeMap()
Returns theSimpleTypeMaprepresentation of thisTransmission. In case this Transmission hasTransmissionchildren, then the children are queried as well and contained in the resultingSimpleTypeMap. The aliases of the accordingTransmissioninstances represent the resulting path to aTransmission's final simple type.- Specified by:
toSimpleTypeMapin interfaceTransmission- Overrides:
toSimpleTypeMapin classAbstractPayloadSection<org.refcodes.properties.Properties>- Returns:
- The
SimpleTypeMaprepresenting thisTransmissionand (if any) its children, with the according aliases forming the paths to theTransmission's values.
-
-