Class SegmentArraySection<ARRAY extends Segment>
java.lang.Object
org.refcodes.serial.AbstractArrayTransmission<ARRAY>
org.refcodes.serial.SegmentArraySection<ARRAY>
- Type Parameters:
ARRAY- The type of the array elements to be contained in this instance.
- All Implemented Interfaces:
Serializable,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.ArrayAccessor<ARRAY[]>,org.refcodes.mixin.ArrayAccessor.ArrayBuilder<ARRAY[],,ArrayTransmission<ARRAY>> org.refcodes.mixin.ArrayAccessor.ArrayMutator<ARRAY[]>,org.refcodes.mixin.ArrayAccessor.ArrayProperty<ARRAY[]>,org.refcodes.mixin.LengthAccessor,org.refcodes.mixin.Resetable,org.refcodes.schema.Schemable,ArraySection<ARRAY>,ArrayTransmission<ARRAY>,Section,Section.SectionMixin,Transmission,Transmission.TransmissionMixin
public class SegmentArraySection<ARRAY extends Segment>
extends AbstractArrayTransmission<ARRAY>
implements Section, ArraySection<ARRAY>
A
SegmentArraySection is a Segment consisting of
Segment elements with each element of presumably different lengths (
in contrast to the FixedSegmentArraySection).- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.ArrayAccessor
org.refcodes.mixin.ArrayAccessor.ArrayBuilder<T,B extends org.refcodes.mixin.ArrayAccessor.ArrayBuilder<T, B>>, org.refcodes.mixin.ArrayAccessor.ArrayMutator<T>, org.refcodes.mixin.ArrayAccessor.ArrayProperty<T> Nested classes/interfaces inherited from interface org.refcodes.mixin.LengthAccessor
org.refcodes.mixin.LengthAccessor.LengthBuilder<B extends org.refcodes.mixin.LengthAccessor.LengthBuilder<B>>, org.refcodes.mixin.LengthAccessor.LengthMutator, org.refcodes.mixin.LengthAccessor.LengthPropertyNested classes/interfaces inherited from interface org.refcodes.serial.Section
Section.SectionMixinNested classes/interfaces inherited from interface org.refcodes.serial.Transmission
Transmission.TransmissionMixin -
Field Summary
Fields inherited from class org.refcodes.serial.AbstractArrayTransmission
_alias, _array, _sequenceableFactory -
Constructor Summary
ConstructorsConstructorDescriptionSegmentArraySection(ARRAY... aSegments) Instantiates the classSegmentArraySection.SegmentArraySection(Class<ARRAY> aSegmentClass) Instantiates the classSegmentArraySection.SegmentArraySection(String aAlias, ARRAY... aSegments) Instantiates the classSegmentArraySection.SegmentArraySection(String aAlias, Class<ARRAY> aSegmentClass) Instantiates the classSegmentArraySection.SegmentArraySection(String aAlias, Collection<ARRAY> aSegments) Instantiates the classSegmentArraySection.SegmentArraySection(String aAlias, org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory) Instantiates the classSegmentArraySection.SegmentArraySection(String aAlias, org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory, ARRAY... aSegments) Instantiates the classSegmentArraySection.SegmentArraySection(String aAlias, org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory, Collection<ARRAY> aSegments) Instantiates the classSegmentArraySection.SegmentArraySection(Collection<ARRAY> aSegments) Instantiates the classSegmentArraySection.SegmentArraySection(org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory) Instantiates the classSegmentArraySection.SegmentArraySection(org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory, ARRAY... aSegments) Instantiates the classSegmentArraySection.SegmentArraySection(org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory, Collection<ARRAY> aSegments) Instantiates the classSegmentArraySection. -
Method Summary
Modifier and TypeMethodDescriptionvoidfromTransmission(Sequence aSequence, int aOffset, int aLength) (Re-)initializes this instance with the the givenSequencedata.Methods inherited from class org.refcodes.serial.AbstractArrayTransmission
getAlias, getArray, getLength, reset, setArray, toSchema, toStringMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.mixin.AliasAccessor
getAliasMethods inherited from interface org.refcodes.mixin.ArrayAccessor
getArrayMethods inherited from interface org.refcodes.mixin.ArrayAccessor.ArrayMutator
setArrayMethods inherited from interface org.refcodes.mixin.ArrayAccessor.ArrayProperty
letArrayMethods inherited from interface org.refcodes.serial.ArrayTransmission
getLength, toSchema, toSequence, toSimpleTypeTableMethods inherited from interface org.refcodes.schema.Schemable
toSchemaMethods inherited from interface org.refcodes.serial.Section
fromTransmission, fromTransmission, fromTransmission, receiveFrom, receiveFromMethods inherited from interface org.refcodes.serial.Section.SectionMixin
receiveFromMethods inherited from interface org.refcodes.serial.Transmission
reset, transmitTo, transmitToMethods inherited from interface org.refcodes.serial.Transmission.TransmissionMixin
transmitTo
-
Constructor Details
-
SegmentArraySection
Instantiates the classSegmentArraySection.- Parameters:
aSegmentClass- the segment class- See Also:
-
SegmentArraySection
Instantiates the classSegmentArraySection.- Parameters:
aSegments- the segments- See Also:
-
SegmentArraySection
Instantiates the classSegmentArraySection.- Parameters:
aSegments- the segments- See Also:
-
SegmentArraySection
Instantiates the classSegmentArraySection.- Parameters:
aAlias- the aliasaSegmentClass- the segment class- See Also:
-
SegmentArraySection
Instantiates the classSegmentArraySection.- Parameters:
aAlias- the aliasaSegments- the segments- See Also:
-
SegmentArraySection
Instantiates the classSegmentArraySection.- Parameters:
aAlias- the aliasaSegments- the segments- See Also:
-
SegmentArraySection
public SegmentArraySection(String aAlias, org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory, Collection<ARRAY> aSegments) Instantiates the classSegmentArraySection.- Parameters:
aAlias- the aliasaSegmentFactory- the segment factoryaSegments- the segments- See Also:
-
SegmentArraySection
@SafeVarargs public SegmentArraySection(String aAlias, org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory, ARRAY... aSegments) Instantiates the classSegmentArraySection.- Parameters:
aAlias- the aliasaSegmentFactory- the segment factoryaSegments- the segments- See Also:
-
SegmentArraySection
Instantiates the classSegmentArraySection.- Parameters:
aAlias- the aliasaSegmentFactory- the segment factory- See Also:
-
SegmentArraySection
public SegmentArraySection(org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory, Collection<ARRAY> aSegments) Instantiates the classSegmentArraySection.- Parameters:
aSegmentFactory- the segment factoryaSegments- the segments- See Also:
-
SegmentArraySection
@SafeVarargs public SegmentArraySection(org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory, ARRAY... aSegments) Instantiates the classSegmentArraySection.- Parameters:
aSegmentFactory- the segment factoryaSegments- the segments- See Also:
-
SegmentArraySection
Instantiates the classSegmentArraySection.- Parameters:
aSegmentFactory- the segment factory- See Also:
-
-
Method Details
-
withArray
- Specified by:
withArrayin interfaceorg.refcodes.mixin.ArrayAccessor.ArrayBuilder<ARRAY extends Segment[],ArrayTransmission<ARRAY extends Segment>> - Overrides:
withArrayin classAbstractArrayTransmission<ARRAY extends Segment>
-
fromTransmission
public void fromTransmission(Sequence aSequence, int aOffset, int aLength) throws TransmissionException (Re-)initializes this instance with the the givenSequencedata.- Specified by:
fromTransmissionin interfaceSection- Parameters:
aSequence- TheSequencedata from which to (re-)initialize this instance.aOffset- The offset where to start processing the providedSequence.aLength- The length of data assigned by theSequence.- Throws:
TransmissionException- thrown in case a givenSequencecannot be processed.
-