Class SegmentArraySection<ARRAY extends Segment>

java.lang.Object
org.refcodes.serial.AbstractArrayTransmission<ARRAY>
org.refcodes.serial.SegmentArraySection<ARRAY>
Type Parameters:
ARRAY - The type of the array elements to be contained in this instance.
All Implemented Interfaces:
Serializable, org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.ArrayAccessor<ARRAY[]>, org.refcodes.mixin.ArrayAccessor.ArrayBuilder<ARRAY[],​ArrayTransmission<ARRAY>>, org.refcodes.mixin.ArrayAccessor.ArrayMutator<ARRAY[]>, org.refcodes.mixin.ArrayAccessor.ArrayProperty<ARRAY[]>, org.refcodes.mixin.LengthAccessor, ArraySection<ARRAY>, ArrayTransmission<ARRAY>, Section, Section.SectionMixin, Transmission, Transmission.TransmissionMixin

public class SegmentArraySection<ARRAY extends Segment>
extends AbstractArrayTransmission<ARRAY>
implements Section, ArraySection<ARRAY>
A SegmentArraySection is a Segment consisting of Segment elements with each element of presumably different lengths ( in contrast to the FixedSegmentArraySection).
See Also:
Serialized Form
  • Constructor Details

    • SegmentArraySection

      public SegmentArraySection​(Class<ARRAY> aSegmentClass)
    • SegmentArraySection

      public SegmentArraySection​(Collection<ARRAY> aSegments)
    • SegmentArraySection

      @SafeVarargs public SegmentArraySection​(ARRAY... aSegments)
    • SegmentArraySection

      public SegmentArraySection​(String aAlias, Class<ARRAY> aSegmentClass)
    • SegmentArraySection

      public SegmentArraySection​(String aAlias, Collection<ARRAY> aSegments)
    • SegmentArraySection

      @SafeVarargs public SegmentArraySection​(String aAlias, ARRAY... aSegments)
    • SegmentArraySection

      public SegmentArraySection​(String aAlias, org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory, Collection<ARRAY> aSegments)
    • SegmentArraySection

      @SafeVarargs public SegmentArraySection​(String aAlias, org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory, ARRAY... aSegments)
    • SegmentArraySection

      public SegmentArraySection​(String aAlias, org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory)
    • SegmentArraySection

      public SegmentArraySection​(org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory, Collection<ARRAY> aSegments)
    • SegmentArraySection

      @SafeVarargs public SegmentArraySection​(org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory, ARRAY... aSegments)
    • SegmentArraySection

      public SegmentArraySection​(org.refcodes.factory.TypeFactory<ARRAY> aSegmentFactory)
  • Method Details