Module org.refcodes.serial
Package org.refcodes.serial
Interface SegmentConsumer<SEGMENT extends Segment>
-
- Type Parameters:
SEGMENT- TheSegmenttype being consumed.
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
@FunctionalInterface public interface SegmentConsumer<SEGMENT extends Segment>
ASegmentConsumerconsumes aSegmentand is used to create lambda expressions used for asynchronous callback.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description voidonSegment(SEGMENT aSegment)Callback consuming aSegment.
-