Interface SegmentSource

All Known Subinterfaces:
Port<PM>, SegmentTransceiver, SegmentTransmitter, SerialTransceiver, SerialTransmitter
All Known Implementing Classes:
AbstractPort, AbstractPortDecorator, CrossoverLoopbackPort, FullDuplexPacketPortDecorator, FullDuplexTxPortDecorator, LoopbackPort, TtyPort
Functional Interface:
This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.

@FunctionalInterface
public interface SegmentSource
The SegmentSource is used to send Segment instances in a unified way.