- All Known Subinterfaces:
Port<PM>,SegmentTransceiver,SegmentTransmitter,SerialTransceiver,SerialTransmitter
- All Known Implementing Classes:
AbstractPort,AbstractPortDecorator,CrossoverLoopbackPort,FullDuplexPacketPortDecorator,FullDuplexTxPortDecorator,LoopbackPort,TtyPort
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
@FunctionalInterface public interface SegmentSource
The
SegmentSource is used to send Segment instances in a
unified way.-
Method Summary
Modifier and Type Method Description <SEGMENT extends Segment>
voidtransmitSegment(SEGMENT aSegment)Transmits aAllocSectionDecoratorSegment(and blocks this thread) till all it'sSequencedata (as ofAbstractLengthDecoratorSegment.toTransmission()) has been sent.
-
Method Details
-
transmitSegment
Transmits aAllocSectionDecoratorSegment(and blocks this thread) till all it'sSequencedata (as ofAbstractLengthDecoratorSegment.toTransmission()) has been sent.- Type Parameters:
SEGMENT- TheSegmenttype describing theSegmentsubclass used.- Parameters:
aSegment- TheAllocSectionDecoratorSegment's data to be sent with.- Throws:
IOException- thrown in case of I/O issues (e.g. a timeout) while sending.
-