Uses of Class
org.refcodes.serial.MagicBytes
-
-
Uses of MagicBytes in org.refcodes.serial
Methods in org.refcodes.serial that return MagicBytes Modifier and Type Method Description static MagicBytesMagicBytes. valueOf(String name)Returns the enum constant of this type with the specified name.static MagicBytes[]MagicBytes. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in org.refcodes.serial with parameters of type MagicBytes Modifier and Type Method Description static byte[]MagicBytes. toMagicBytes(MagicBytes... aMagicBytes)Constructs magic bytes from the providedMagicByteselements to be concatenated to a single magic bytes sequence.
-