class |
BadCrcChecksumException |
Thrown in case a transmission's CRC checksum did not match the according
calculated CRC checksum.
|
class |
BadCrcChecksumSequenceException |
Thrown in case a Sequence CRC checksum did not match the according
calculated CRC checksum.
|
class |
BadMagicBytesException |
|
class |
BadMagicBytesSequenceException |
|
class |
FlowControlException |
Thrown in case a flow control failed.
|
class |
FlowControlRetryException |
Thrown in case a flow control failed due t a timeout.
|
class |
FlowControlTimeoutException |
Thrown in case a flow control failed due t a timeout.
|
class |
NoSuchPortExcpetion |
Thrown in case there is no such port found.
|
class |
TransmissionException |
|
class |
TransmissionSequenceException |
Thrown in case a given Sequence cannot be processed.
|