Uses of Class
org.refcodes.serial.SerialException
-
Uses of SerialException in org.refcodes.serial
Subclasses of SerialException in org.refcodes.serial Modifier and Type Class Description classBadCrcChecksumExceptionThrown in case a transmission's CRC checksum did not match the according calculated CRC checksum.classBadCrcChecksumSequenceExceptionThrown in case aSequenceCRC checksum did not match the according calculated CRC checksum.classBadMagicBytesExceptionABadMagicBytesExceptiondenotes bad (unexpected) magic bytes encountered while processing a transmission.classBadMagicBytesSequenceExceptionABadMagicBytesSequenceExceptiondenotes bad (unexpected) magic bytes encountered while processing a transmissionSequence.classFlowControlExceptionThrown in case a flow control failed.classFlowControlRetryExceptionThrown in case a flow control failed due t a timeout.classFlowControlTimeoutExceptionThrown in case a flow control failed due t a timeout.classNoSuchPortExcpetionThrown in case there is no such port found.classTransmissionExceptionThrown in case a given transmission cannot be processed.classTransmissionSequenceExceptionThrown in case a givenSequencecannot be processed.